{%- include 'datatable_header.j2' %}
{%- if "AEPg" in api %}
<h1>Endpoint Groups</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Configuration Issues</th>
    <th>Configuration State</th>
    <th>Exception Tag</th>
    <th>Flood On Encapsulation</th>
    <th>Forward Control</th>
    <th>Has Multicast Source</th>
    <th>Is Attribute Based EPG</th>
    <th>Is Shared Service Multicast Site EPG</th>
    <th>Match T</th>
    <th>PC Enforcement Preference</th>
    <th>PC Tag</th>
    <th>PC Tag Allocation Source</th>
    <th>Preference Gr Member</th>
    <th>Priority</th>
    <th>Scope</th>
    <th>Shutdown</th>
    <th>Trigger State</th>
    <th>TX Id</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>  
<tbody>
{%-     for epg in data_to_template['imdata'] %}
  <tr>
    <td>{{ epg.fvAEPg.attributes.name }}</td>
    <td>{{ epg.fvAEPg.attributes.nameAlias }}</td>
    <td>{{ epg.fvAEPg.attributes.descr }}</td>
    <td>{{ epg.fvAEPg.attributes.status }}</td>
    <td>{{ epg.fvAEPg.attributes.dn }}</td>
    <td>{{ epg.fvAEPg.attributes.uid }}</td>
    <td>{{ epg.fvAEPg.attributes.annotation }}</td>
    <td>{{ epg.fvAEPg.attributes.childAction }}</td>
    <td>{{ epg.fvAEPg.attributes.extMngdBy }}</td>
    <td>{{ epg.fvAEPg.attributes.lcOwn }}</td>
    <td>{{ epg.fvAEPg.attributes.monPolDn }}</td>
    <td>{{ epg.fvAEPg.attributes.userdom }}</td>
    <td>{{ epg.fvAEPg.attributes.configIssues }}</td>
    <td>{{ epg.fvAEPg.attributes.configSt }}</td>
    <td>{{ epg.fvAEPg.attributes.exceptionTag }}</td>
    <td>{{ epg.fvAEPg.attributes.floodOnEncap }}</td>
    <td>{{ epg.fvAEPg.attributes.fwdCtrl }}</td>
    <td>{{ epg.fvAEPg.attributes.hasMcastSource }}</td>
    <td>{{ epg.fvAEPg.attributes.isAttrBasedEPg }}</td>
    <td>{{ epg.fvAEPg.attributes.isSharedSrvMsiteEPg }}</td>
    <td>{{ epg.fvAEPg.attributes.matchT }}</td>
    <td>{{ epg.fvAEPg.attributes.pcEnfPref }}</td>
    <td>{{ epg.fvAEPg.attributes.pcTag }}</td>
    <td>{{ epg.fvAEPg.attributes.pcTagAllocSrc }}</td>
    <td>{{ epg.fvAEPg.attributes.prefGrMemb }}</td>
    <td>{{ epg.fvAEPg.attributes.prio }}</td>
    <td>{{ epg.fvAEPg.attributes.scope }}</td>
    <td>{{ epg.fvAEPg.attributes.shutdown }}</td>
    <td>{{ epg.fvAEPg.attributes.triggerSt }}</td>
    <td>{{ epg.fvAEPg.attributes.txId }}</td>
    <td>{{ epg.fvAEPg.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvBD" in api %}
<h1>Bridge Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Configuration Issues</th>
    <th>Optimize Wan Bandwidth</th>
    <th>ARP Flood</th>
    <th>Broadcast P</th>
    <th>Endpoint Clear</th>
    <th>Endpoint Move Detect Mode</th>
    <th>Host Based Routing</th>
    <th>Intersite BUM Traffic Allow</th>
    <th>Intersite L2 Stretch</th>
    <th>IP Learning</th>
    <th>IPv6 Multicast Allow</th>
    <th>Limit IP Learn To Subnets</th>
    <th>Link Local Address</th>
    <th>MAC</th>
    <th>Multicast Allow</th>
    <th>MTU</th>
    <th>Multicase Destination Packet Action</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>PC Tag</th>
    <th>Scope</th>
    <th>Segment</th>
    <th>Type</th>
    <th>Unicast Route</th>
    <th>Unknown MAC Unicast Action</th>
    <th>Unknown Multicast Action</th>
    <th>IPv6 Unknown Multicast Action</th>
    <th>Virtual MAC</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>  
<tbody>
{%-     for bd in data_to_template['imdata'] %}
  <tr>
    <td>{{ bd.fvBD.attributes.name }}</td>
    <td>{{ bd.fvBD.attributes.nameAlias }}</td>
    <td>{{ bd.fvBD.attributes.descr }}</td>
    <td>{{ bd.fvBD.attributes.status }}</td>
    <td>{{ bd.fvBD.attributes.dn }}</td>
    <td>{{ bd.fvBD.attributes.uid }}</td>
    <td>{{ bd.fvBD.attributes.annotation }}</td>
    <td>{{ bd.fvBD.attributes.childAction }}</td>
    <td>{{ bd.fvBD.attributes.extMngdBy }}</td>
    <td>{{ bd.fvBD.attributes.lcOwn }}</td>
    <td>{{ bd.fvBD.attributes.monPolDn }}</td>
    <td>{{ bd.fvBD.attributes.userdom }}</td>
    <td>{{ bd.fvBD.attributes.configIssues }}</td>
    <td>{{ bd.fvBD.attributes.OptimizeWanBandwidth }}</td>
    <td>{{ bd.fvBD.attributes.arpFlood }}</td>
    <td>{{ bd.fvBD.attributes.bcastP }}</td>
    <td>{{ bd.fvBD.attributes.epClear }}</td>
    <td>{{ bd.fvBD.attributes.epMoveDetectMode }}</td>
    <td>{{ bd.fvBD.attributes.hostBasedRouting }}</td>
    <td>{{ bd.fvBD.attributes.intersiteBumTrafficAllow }}</td>
    <td>{{ bd.fvBD.attributes.intersiteL2Stretch }}</td>
    <td>{{ bd.fvBD.attributes.ipLearning }}</td>
    <td>{{ bd.fvBD.attributes.ipv6McastAllow }}</td>
    <td>{{ bd.fvBD.attributes.limitIpLearnToSubnets }}</td>
    <td>{{ bd.fvBD.attributes.llAddr }}</td>
    <td>{{ bd.fvBD.attributes.mac }}</td>
    <td>{{ bd.fvBD.attributes.mcastAllow }}</td>
    <td>{{ bd.fvBD.attributes.mtu }}</td>
    <td>{{ bd.fvBD.attributes.multiDstPktAct }}</td>
    <td>{{ bd.fvBD.attributes.ownerKey }}</td>
    <td>{{ bd.fvBD.attributes.ownerTag }}</td>
    <td>{{ bd.fvBD.attributes.pcTag }}</td>
    <td>{{ bd.fvBD.attributes.scope }}</td>
    <td>{{ bd.fvBD.attributes.seg }}</td>
    <td>{{ bd.fvBD.attributes.type }}</td>
    <td>{{ bd.fvBD.attributes.unicastRoute }}</td>
    <td>{{ bd.fvBD.attributes.unkMacUcastAct }}</td>
    <td>{{ bd.fvBD.attributes.unkMcastAct }}</td>
    <td>{{ bd.fvBD.attributes.v6unkMcastAct }}</td>
    <td>{{ bd.fvBD.attributes.vmac }}</td>
    <td>{{ bd.fvBD.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvCtx" in api %}
<h1>Contexts</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Bridge Domain Enforced Enable</th>
    <th>IP Data Plane Learning</th>
    <th>Known Multicast Action</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>PC Enforce Directory</th>
    <th>PC Enforce Directory Updated</th>
    <th>PC Enforce Preference</th>
    <th>PC Tag</th>
    <th>Scope</th>
    <th>Seg</th>
    <th>VRF ID</th>
    <th>VRF Index</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>
<tbody>
{%-     for context in data_to_template['imdata'] %}
  <tr>
    <td>{{ context.fvCtx.attributes.name }}</td>
    <td>{{ context.fvCtx.attributes.nameAlias }}</td>
    <td>{{ context.fvCtx.attributes.descr }}</td>
    <td>{{ context.fvCtx.attributes.status }}</td>
    <td>{{ context.fvCtx.attributes.dn }}</td>
    <td>{{ context.fvCtx.attributes.uid }}</td>
    <td>{{ context.fvCtx.attributes.annotation }}</td>
    <td>{{ context.fvCtx.attributes.childAction }}</td>
    <td>{{ context.fvCtx.attributes.extMngdBy }}</td>
    <td>{{ context.fvCtx.attributes.lcOwn }}</td>
    <td>{{ context.fvCtx.attributes.monPolDn }}</td>
    <td>{{ context.fvCtx.attributes.userdom }}</td>
    <td>{{ context.fvCtx.attributes.bdEnforcedEnable }}</td>
    <td>{{ context.fvCtx.attributes.ipDataPlaneLearning }}</td>
    <td>{{ context.fvCtx.attributes.knwMcastAct }}</td>
    <td>{{ context.fvCtx.attributes.ownerKey }}</td>
    <td>{{ context.fvCtx.attributes.ownerTag }}</td>
    <td>{{ context.fvCtx.attributes.pcEnfDir }}</td>
    <td>{{ context.fvCtx.attributes.pcEnfDirUpdated }}</td>
    <td>{{ context.fvCtx.attributes.pcEnfPref }}</td>
    <td>{{ context.fvCtx.attributes.pcTag }}</td>
    <td>{{ context.fvCtx.attributes.scope }}</td>
    <td>{{ context.fvCtx.attributes.seg }}</td>
    <td>{{ context.fvCtx.attributes.vrfId }}</td>
    <td>{{ context.fvCtx.attributes.vrfIndex }}</td>
    <td>{{ context.fvCtx.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "Ap" in api %}
<h1>Application Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Priority</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>
<tbody>
{%-     for application_profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ application_profile.fvAp.attributes.name }}</td>
    <td>{{ application_profile.fvAp.attributes.nameAlias }}</td>
    <td>{{ application_profile.fvAp.attributes.descr }}</td>
    <td>{{ application_profile.fvAp.attributes.status }}</td>
    <td>{{ application_profile.fvAp.attributes.dn }}</td>
    <td>{{ application_profile.fvAp.attributes.uid }}</td>
    <td>{{ application_profile.fvAp.attributes.annotation }}</td>
    <td>{{ application_profile.fvAp.attributes.childAction }}</td>
    <td>{{ application_profile.fvAp.attributes.extMngdBy }}</td>
    <td>{{ application_profile.fvAp.attributes.lcOwn }}</td>
    <td>{{ application_profile.fvAp.attributes.monPolDn }}</td>
    <td>{{ application_profile.fvAp.attributes.userdom }}</td>
    <td>{{ application_profile.fvAp.attributes.ownerKey }}</td>
    <td>{{ application_profile.fvAp.attributes.ownerTag }}</td>
    <td>{{ application_profile.fvAp.attributes.prio }}</td>
    <td>{{ application_profile.fvAp.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "l3extOut" in api %}
<h1>L3Outs</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Priority</th>
    <th>Enforce Route Control</th>
    <th>Target DSCP</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>
<tbody>
{%-     for l3out in data_to_template['imdata'] %}
  <tr>
    <td>{{ l3out.l3extOut.attributes.name }}</td>
    <td>{{ l3out.l3extOut.attributes.nameAlias }}</td>
    <td>{{ l3out.l3extOut.attributes.descr }}</td>
    <td>{{ l3out.l3extOut.attributes.status }}</td>
    <td>{{ l3out.l3extOut.attributes.dn }}</td>
    <td>{{ l3out.l3extOut.attributes.uid }}</td>
    <td>{{ l3out.l3extOut.attributes.annotation }}</td>
    <td>{{ l3out.l3extOut.attributes.childAction }}</td>
    <td>{{ l3out.l3extOut.attributes.extMngdBy }}</td>
    <td>{{ l3out.l3extOut.attributes.lcOwn }}</td>
    <td>{{ l3out.l3extOut.attributes.monPolDn }}</td>
    <td>{{ l3out.l3extOut.attributes.userdom }}</td>
    <td>{{ l3out.l3extOut.attributes.ownerKey }}</td>
    <td>{{ l3out.l3extOut.attributes.ownerTag }}</td>
    <td>{{ l3out.l3extOut.attributes.prio }}</td>
    <td>{{ l3out.l3extOut.attributes.enforceRtctrl }}</td>
    <td>{{ l3out.l3extOut.attributes.targetDscp }}</td>
    <td>{{ l3out.l3extOut.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "l2extOut" in api %}
<h1>L2Outs</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>LC Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>Target DSCP</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>    
{%-     for l2out in data_to_template['imdata'] %}
  <tr>
    <td>{{ l2out.l2extOut.attributes.name }}</td>
    <td>{{ l2out.l2extOut.attributes.nameAlias }}</td>
    <td>{{ l2out.l2extOut.attributes.annotation }}</td>
    <td>{{ l2out.l2extOut.attributes.childAction }}</td>
    <td>{{ l2out.l2extOut.attributes.descr }}</td>
    <td>{{ l2out.l2extOut.attributes.dn }}</td>
    <td>{{ l2out.l2extOut.attributes.extMngdBy }}</td>
    <td>{{ l2out.l2extOut.attributes.lcOwn }}</td>
    <td>{{ l2out.l2extOut.attributes.modTs }}</td>
    <td>{{ l2out.l2extOut.attributes.monPolDn }}</td>
    <td>{{ l2out.l2extOut.attributes.ownerKey }}</td>
    <td>{{ l2out.l2extOut.attributes.ownerTag }}</td>
    <td>{{ l2out.l2extOut.attributes.status }}</td>
    <td>{{ l2out.l2extOut.attributes.targetDscp }}</td>
    <td>{{ l2out.l2extOut.attributes.uid }}</td>
    <td>{{ l2out.l2extOut.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvSubnet" in api %}
<h1>Subnets</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Config Issues</th>
    <th>Control</th>
    <th>Debug Message</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>IP</th>
    <th>IP Data Plane Learning</th>
    <th>LC Owner</th>
    <th>Monitoring Policy DN</th>
    <th>Preferred</th>
    <th>Scope</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
    <th>Virtual</th>
    <th>Last Modified</th>
  </tr>
</thead>
<tbody>    
{%-     for subnet in data_to_template['imdata'] %}
  <tr>
    <td>{{ subnet.fvSubnet.attributes.name }}</td>
    <td>{{ subnet.fvSubnet.attributes.nameAlias }}</td>
    <td>{{ subnet.fvSubnet.attributes.annotation }}</td>
    <td>{{ subnet.fvSubnet.attributes.childAction }}</td>
    <td>{{ subnet.fvSubnet.attributes.configIssues }}</td>
    <td>{{ subnet.fvSubnet.attributes.ctrl }}</td>
    <td>{{ subnet.fvSubnet.attributes.debugMessage }}</td>
    <td>{{ subnet.fvSubnet.attributes.descr }}</td>
    <td>{{ subnet.fvSubnet.attributes.dn }}</td>
    <td>{{ subnet.fvSubnet.attributes.extMngdBy }}</td>
    <td>{{ subnet.fvSubnet.attributes.ip }}</td>
    <td>{{ subnet.fvSubnet.attributes.ipDPLearning }}</td>
    <td>{{ subnet.fvSubnet.attributes.lcOwn }}</td>
    <td>{{ subnet.fvSubnet.attributes.monPolDn }}</td>
    <td>{{ subnet.fvSubnet.attributes.preferred }}</td>
    <td>{{ subnet.fvSubnet.attributes.scope }}</td>
    <td>{{ subnet.fvSubnet.attributes.status }}</td>
    <td>{{ subnet.fvSubnet.attributes.uid }}</td>
    <td>{{ subnet.fvSubnet.attributes.userdom }}</td>
    <td>{{ subnet.fvSubnet.attributes.virtual }}</td>
    <td>{{ subnet.fvSubnet.attributes.modTs }}</td>
</tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvCEp" in api %}
<h1>Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>MAC</th>
    <th>Annotation</th>
    <th>Base EPG DN</th>
    <th>Bridge Domain DN</th>
    <th>Child Action</th>
    <th>Container Name</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>ESG Use gDN</th>
    <th>Externally Managed By</th>
    <th>Full Fabric Path DN</th>
    <th>ID</th>
    <th>ID Endpoint DN</th>
    <th>LCC</th>
    <th>LC Owner</th>
    <th>Multicast Address</th>
    <th>Last Modified</th>
    <th>Monitor Policy DN</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
    <th>UUID</th>
    <th>VMM Source</th>
    <th>VRF DN</th>
  </tr>
</thead>
<tbody>    
{%-     for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.fvCEp.attributes.name }}</td>
    <td>{{ endpoint.fvCEp.attributes.nameAlias }}</td>
    <td>{{ endpoint.fvCEp.attributes.mac }}</td>
    <td>{{ endpoint.fvCEp.attributes.annotation }}</td>
    <td>{{ endpoint.fvCEp.attributes.baseEpgDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.bdDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.childAction }}</td>
    <td>{{ endpoint.fvCEp.attributes.contName }}</td>
    <td>{{ endpoint.fvCEp.attributes.dn }}</td>
    <td>{{ endpoint.fvCEp.attributes.encap }}</td>
    <td>{{ endpoint.fvCEp.attributes.esgUsegDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.extMngdBy }}</td>
    <td>{{ endpoint.fvCEp.attributes.fabricPathDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.id }}</td>
    <td>{{ endpoint.fvCEp.attributes.idepdn }}</td>
    <td>{{ endpoint.fvCEp.attributes.lcC }}</td>
    <td>{{ endpoint.fvCEp.attributes.lcOwn }}</td>
    <td>{{ endpoint.fvCEp.attributes.mcastAddr }}</td>
    <td>{{ endpoint.fvCEp.attributes.modTs }}</td>
    <td>{{ endpoint.fvCEp.attributes.monPolDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.status }}</td>
    <td>{{ endpoint.fvCEp.attributes.uid }}</td>
    <td>{{ endpoint.fvCEp.attributes.userdom }}</td>
    <td>{{ endpoint.fvCEp.attributes.uuid }}</td>
    <td>{{ endpoint.fvCEp.attributes.vmmSrc }}</td>
    <td>{{ endpoint.fvCEp.attributes.vrfDn }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fabricNode" in api %}
<h1>Fabric Nodes</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>AD St</th>
    <th>Address</th>
    <th>Annotation</th>
    <th>APIC Type</th>
    <th>Child Action</th>
    <th>Delayed Heartbeat</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Fabric State</th>
    <th>ID</th>
    <th>Last State Modified</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Node Type</th>
    <th>Role</th>
    <th>Serial</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
    <th>Vendor</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>  
{%-     for node in data_to_template['imdata'] %}
  <tr>
    <td>{{ node.fabricNode.attributes.name }}</td>
    <td>{{ node.fabricNode.attributes.nameAlias }}</td>
    <td>{{ node.fabricNode.attributes.adSt }}</td>
    <td>{{ node.fabricNode.attributes.address }}</td>
    <td>{{ node.fabricNode.attributes.annotation }}</td>
    <td>{{ node.fabricNode.attributes.apicType }}</td>
    <td>{{ node.fabricNode.attributes.childAction }}</td>
    <td>{{ node.fabricNode.attributes.delayedHeartbeat }}</td>
    <td>{{ node.fabricNode.attributes.dn }}</td>
    <td>{{ node.fabricNode.attributes.extMngdBy }}</td>
    <td>{{ node.fabricNode.attributes.fabricSt }}</td>
    <td>{{ node.fabricNode.attributes.id }}</td>
    <td>{{ node.fabricNode.attributes.lastStateModTs }}</td>
    <td>{{ node.fabricNode.attributes.lcOwn }}</td>
    <td>{{ node.fabricNode.attributes.modTs }}</td>
    <td>{{ node.fabricNode.attributes.model }}</td>
    <td>{{ node.fabricNode.attributes.monPolDn }}</td>
    <td>{{ node.fabricNode.attributes.nodeType }}</td>
    <td>{{ node.fabricNode.attributes.role }}</td>
    <td>{{ node.fabricNode.attributes.serial }}</td>
    <td>{{ node.fabricNode.attributes.status }}</td>
    <td>{{ node.fabricNode.attributes.uid }}</td>
    <td>{{ node.fabricNode.attributes.userdom }}</td>
    <td>{{ node.fabricNode.attributes.vendor }}</td>
    <td>{{ node.fabricNode.attributes.version }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "l1PhysIf" in api %}
<h1>Physical Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Admin State</th>
    <th>Auto Negotiate</th>
    <th>Breakout Map</th>
    <th>Bandwidth</th>
    <th>Child Action</th>
    <th>Delay</th>
    <th>Description</th>
    <th>DFE Delay MS</th>
    <th>DN</th>
    <th>Dot1q EtherType</th>
    <th>Eth PM Cfg Failed Bmp</th>
    <th>Eth PM Cfg Failed Timestamp</th>
    <th>Eth PM Cfg State</th>
    <th>FCOT Channel Number</th>
    <th>FEC Mode</th>
    <th>ID</th>
    <th>Inherited Bandwidth</th>
    <th>Is Reflective Relay Config Supported</th>
    <th>Layer</th>
    <th>Local Owner</th>
    <th>Link Debounce</th>
    <th>Link Flap Error Max</th>
    <th>Link Flap Error Seconds</th>
    <th>Link Log</th>
    <th>MDIX</th>
    <th>Medium</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>MTU</th>
    <th>Name</th>
    <th>Path S Description</th>
    <th>Port Physical Media Type</th>
    <th>Port T</th>
    <th>Priority Flow Control</th>
    <th>Reflective Relay Enable</th>
    <th>Router MAC</th>
    <th>SNMP Trap State</th>
    <th>Span Mode</th>
    <th>Speed</th>
    <th>Status</th>
    <th>Switching State</th>
    <th>Trunk Log</th>
    <th>Usage</th>
  </tr>
</thead>
<tbody>  
{%-     for outer_list in data_to_template %}
{%-         for interface in outer_list %}
  <tr>
    <td>{{ interface.l1PhysIf.attributes.adminSt }}</td>
    <td>{{ interface.l1PhysIf.attributes.autoNeg }}</td>
    <td>{{ interface.l1PhysIf.attributes.brkoutMap }}</td>
    <td>{{ interface.l1PhysIf.attributes.bw }}</td>
    <td>{{ interface.l1PhysIf.attributes.childAction }}</td>
    <td>{{ interface.l1PhysIf.attributes.delay }}</td>
    <td>{{ interface.l1PhysIf.attributes.descr }}</td>
    <td>{{ interface.l1PhysIf.attributes.dfeDelayMs }}</td>
    <td>{{ interface.l1PhysIf.attributes.dn }}</td>
    <td>{{ interface.l1PhysIf.attributes.dot1qEtherType }}</td>
    <td>{{ interface.l1PhysIf.attributes.ethpmCfgFailedBmp }}</td>
    <td>{{ interface.l1PhysIf.attributes.ethpmCfgFailedTs }}</td>
    <td>{{ interface.l1PhysIf.attributes.ethpmCfgState }}</td>
    <td>{{ interface.l1PhysIf.attributes.fcotChannelNumber }}</td>
    <td>{{ interface.l1PhysIf.attributes.fecMode }}</td>
    <td>{{ interface.l1PhysIf.attributes.id }}</td>
    <td>{{ interface.l1PhysIf.attributes.inhBw }}</td>
    <td>{{ interface.l1PhysIf.attributes.isReflectiveRelayCfgSupported }}</td>
    <td>{{ interface.l1PhysIf.attributes.layer }}</td>
    <td>{{ interface.l1PhysIf.attributes.lcOwn }}</td>
    <td>{{ interface.l1PhysIf.attributes.linkDebounce }}</td>
    <td>{{ interface.l1PhysIf.attributes.linkFlapErrorMax }}</td>
    <td>{{ interface.l1PhysIf.attributes.linkFlapErrorSeconds }}</td>
    <td>{{ interface.l1PhysIf.attributes.linkLog }}</td>
    <td>{{ interface.l1PhysIf.attributes.mdix }}</td>
    <td>{{ interface.l1PhysIf.attributes.medium }}</td>
    <td>{{ interface.l1PhysIf.attributes.modTs }}</td>
    <td>{{ interface.l1PhysIf.attributes.mode }}</td>
    <td>{{ interface.l1PhysIf.attributes.monPolDn }}</td>
    <td>{{ interface.l1PhysIf.attributes.mtu }}</td>
    <td>{{ interface.l1PhysIf.attributes.name }}</td>
    <td>{{ interface.l1PhysIf.attributes.pathSDescr }}</td>
    <td>{{ interface.l1PhysIf.attributes.portPhyMediaType }}</td>
    <td>{{ interface.l1PhysIf.attributes.portT }}</td>
    <td>{{ interface.l1PhysIf.attributes.prioFlowCtrl }}</td>
    <td>{{ interface.l1PhysIf.attributes.reflectiveRelayEn }}</td>
    <td>{{ interface.l1PhysIf.attributes.routerMac }}</td>
    <td>{{ interface.l1PhysIf.attributes.snmpTrapSt }}</td>
    <td>{{ interface.l1PhysIf.attributes.spanMode }}</td>
    <td>{{ interface.l1PhysIf.attributes.speed }}</td>
    <td>{{ interface.l1PhysIf.attributes.status }}</td>
    <td>{{ interface.l1PhysIf.attributes.switchingSt }}</td>
    <td>{{ interface.l1PhysIf.attributes.trunkLog }}</td>
    <td>{{ interface.l1PhysIf.attributes.usage }}</td>
  </tr>
{%-         endfor %}
{%-     endfor %}
</tbody>
</table>
{%- elif "infraAccPortP" in api %}
<h1>Leaf Interface Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraAccPortP.attributes.name }}</td>
    <td>{{ profile.infraAccPortP.attributes.nameAlias }}</td>
    <td>{{ profile.infraAccPortP.attributes.annotation }}</td>
    <td>{{ profile.infraAccPortP.attributes.childAction }}</td>
    <td>{{ profile.infraAccPortP.attributes.descr }}</td>
    <td>{{ profile.infraAccPortP.attributes.dn }}</td>
    <td>{{ profile.infraAccPortP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraAccPortP.attributes.lcOwn }}</td>
    <td>{{ profile.infraAccPortP.attributes.modTs }}</td>
    <td>{{ profile.infraAccPortP.attributes.monPolDn }}</td>
    <td>{{ profile.infraAccPortP.attributes.ownerKey }}</td>
    <td>{{ profile.infraAccPortP.attributes.ownerTag }}</td>
    <td>{{ profile.infraAccPortP.attributes.status }}</td>
    <td>{{ profile.infraAccPortP.attributes.uid }}</td>
    <td>{{ profile.infraAccPortP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraSpAccPortP" in api %}
<h1>Spine Interface Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraSpAccPortP.attributes.name }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.nameAlias }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.annotation }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.childAction }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.descr }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.dn }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.lcOwn }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.modTs }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.monPolDn }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.ownerKey }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.ownerTag }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.status }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.uid }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraNodeP" in api %}
<h1>Leaf Switch Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraNodeP.attributes.name }}</td>
    <td>{{ profile.infraNodeP.attributes.nameAlias }}</td>
    <td>{{ profile.infraNodeP.attributes.annotation }}</td>
    <td>{{ profile.infraNodeP.attributes.childAction }}</td>
    <td>{{ profile.infraNodeP.attributes.descr }}</td>
    <td>{{ profile.infraNodeP.attributes.dn }}</td>
    <td>{{ profile.infraNodeP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraNodeP.attributes.lcOwn }}</td>
    <td>{{ profile.infraNodeP.attributes.modTs }}</td>
    <td>{{ profile.infraNodeP.attributes.monPolDn }}</td>
    <td>{{ profile.infraNodeP.attributes.ownerKey }}</td>
    <td>{{ profile.infraNodeP.attributes.ownerTag }}</td>
    <td>{{ profile.infraNodeP.attributes.status }}</td>
    <td>{{ profile.infraNodeP.attributes.uid }}</td>
    <td>{{ profile.infraNodeP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraSpineP" in api %}
<h1>Spine Switch Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraSpineP.attributes.name }}</td>
    <td>{{ profile.infraSpineP.attributes.nameAlias }}</td>
    <td>{{ profile.infraSpineP.attributes.annotation }}</td>
    <td>{{ profile.infraSpineP.attributes.childAction }}</td>
    <td>{{ profile.infraSpineP.attributes.descr }}</td>
    <td>{{ profile.infraSpineP.attributes.dn }}</td>
    <td>{{ profile.infraSpineP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraSpineP.attributes.lcOwn }}</td>
    <td>{{ profile.infraSpineP.attributes.modTs }}</td>
    <td>{{ profile.infraSpineP.attributes.monPolDn }}</td>
    <td>{{ profile.infraSpineP.attributes.ownerKey }}</td>
    <td>{{ profile.infraSpineP.attributes.ownerTag }}</td>
    <td>{{ profile.infraSpineP.attributes.status }}</td>
    <td>{{ profile.infraSpineP.attributes.uid }}</td>
    <td>{{ profile.infraSpineP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvnsVlanInstP" in api %}
<h1>VLAN Pools</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Allocation Mode</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody> 
{%-     for pool in data_to_template['imdata'] %}
  <tr>
    <td>{{ pool.fvnsVlanInstP.attributes.name }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.nameAlias }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.allocMode }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.annotation }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.childAction }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.configIssues }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.descr }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.dn }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.extMngdBy }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.lcOwn }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.modTs }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.monPolDn }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.ownerKey }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.ownerTag }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.status }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.uid }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraAttEntityP" in api %}
<h1>Attachable Access Entity Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Allocation Mode</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody> 
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraAttEntityP.attributes.name }}</td>
    <td>{{ profile.infraAttEntityP.attributes.nameAlias }}</td>
    <td>{{ profile.infraAttEntityP.attributes.allocMode }}</td>
    <td>{{ profile.infraAttEntityP.attributes.annotation }}</td>
    <td>{{ profile.infraAttEntityP.attributes.childAction }}</td>
    <td>{{ profile.infraAttEntityP.attributes.configIssues }}</td>
    <td>{{ profile.infraAttEntityP.attributes.descr }}</td>
    <td>{{ profile.infraAttEntityP.attributes.dn }}</td>
    <td>{{ profile.infraAttEntityP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraAttEntityP.attributes.lcOwn }}</td>
    <td>{{ profile.infraAttEntityP.attributes.modTs }}</td>
    <td>{{ profile.infraAttEntityP.attributes.monPolDn }}</td>
    <td>{{ profile.infraAttEntityP.attributes.ownerKey }}</td>
    <td>{{ profile.infraAttEntityP.attributes.ownerTag }}</td>
    <td>{{ profile.infraAttEntityP.attributes.status }}</td>
    <td>{{ profile.infraAttEntityP.attributes.uid }}</td>
    <td>{{ profile.infraAttEntityP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "vzBrCP" in api %}
<h1>Contracts</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Access Privilege</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Intent</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Priority</th>
    <th>Re Evaluate All</th>
    <th>Scope</th>
    <th>Status</th>
    <th>Target DSCP</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>   
{%-     for contract in data_to_template['imdata'] %}
  <tr>
    <td>{{ contract.vzBrCP.attributes.name }}</td>
    <td>{{ contract.vzBrCP.attributes.nameAlias }}</td>
    <td>{{ contract.vzBrCP.attributes.accessPrivilege }}</td>
    <td>{{ contract.vzBrCP.attributes.annotation }}</td>
    <td>{{ contract.vzBrCP.attributes.childAction }}</td>
    <td>{{ contract.vzBrCP.attributes.configIssues }}</td>
    <td>{{ contract.vzBrCP.attributes.descr }}</td>
    <td>{{ contract.vzBrCP.attributes.dn }}</td>
    <td>{{ contract.vzBrCP.attributes.extMngdBy }}</td>
    <td>{{ contract.vzBrCP.attributes.intent }}</td>
    <td>{{ contract.vzBrCP.attributes.lcOwn }}</td>
    <td>{{ contract.vzBrCP.attributes.modTs }}</td>
    <td>{{ contract.vzBrCP.attributes.monPolDn }}</td>
    <td>{{ contract.vzBrCP.attributes.ownerKey }}</td>
    <td>{{ contract.vzBrCP.attributes.ownerTag }}</td>
    <td>{{ contract.vzBrCP.attributes.prio }}</td>
    <td>{{ contract.vzBrCP.attributes.reevaluateAll }}</td>
    <td>{{ contract.vzBrCP.attributes.scope }}</td>
    <td>{{ contract.vzBrCP.attributes.status }}</td>
    <td>{{ contract.vzBrCP.attributes.targetDscp }}</td>
    <td>{{ contract.vzBrCP.attributes.uid }}</td>
    <td>{{ contract.vzBrCP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "vzEntry" in api %}
<h1>Filters</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Access Privilege</th>
    <th>Annotation</th>
    <th>Apply To Fragments</th>
    <th>ARP Opc</th>
    <th>Child Action</th>
    <th>Destination From Port</th>
    <th>Destination To Port</th>
    <th>Description</th>
    <th>DN</th>
    <th>EtherType</th>
    <th>Externally Managed By</th>
    <th>ICMPv4 T</th>
    <th>ICMPv6 T</th>
    <th>Local Owner</th>
    <th>Match DSCP</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Protocol</th>
    <th>Source From Port</th>
    <th>Source To Port</th>
    <th>Stateful</th>
    <th>Status</th>
    <th>TCP Rules</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for entry in data_to_template['imdata'] %}
  <tr>
    <td>{{ entry.vzEntry.attributes.name }}</td>
    <td>{{ entry.vzEntry.attributes.nameAlias }}</td>
    <td>{{ entry.vzEntry.attributes.accessPrivilege }}</td>
    <td>{{ entry.vzEntry.attributes.annotation }}</td>
    <td>{{ entry.vzEntry.attributes.applyToFrag }}</td>
    <td>{{ entry.vzEntry.attributes.arpOpc }}</td>
    <td>{{ entry.vzEntry.attributes.childAction }}</td>
    <td>{{ entry.vzEntry.attributes.dFromPort }}</td>
    <td>{{ entry.vzEntry.attributes.dToPort }}</td>
    <td>{{ entry.vzEntry.attributes.descr }}</td>
    <td>{{ entry.vzEntry.attributes.dn }}</td>
    <td>{{ entry.vzEntry.attributes.etherT }}</td>
    <td>{{ entry.vzEntry.attributes.extMngdBy }}</td>
    <td>{{ entry.vzEntry.attributes.icmpv4T }}</td>
    <td>{{ entry.vzEntry.attributes.icmpv6T }}</td>
    <td>{{ entry.vzEntry.attributes.lcOwn }}</td>
    <td>{{ entry.vzEntry.attributes.matchDscp }}</td>
    <td>{{ entry.vzEntry.attributes.modTs }}</td>
    <td>{{ entry.vzEntry.attributes.monPolDn }}</td>
    <td>{{ entry.vzEntry.attributes.prot }}</td>
    <td>{{ entry.vzEntry.attributes.sFromPort }}</td>
    <td>{{ entry.vzEntry.attributes.sToPort }}</td>
    <td>{{ entry.vzEntry.attributes.stateful }}</td>
    <td>{{ entry.vzEntry.attributes.status }}</td>
    <td>{{ entry.vzEntry.attributes.tcpRules }}</td>
    <td>{{ entry.vzEntry.attributes.uid }}</td>
    <td>{{ entry.vzEntry.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "physDomP" in api %}
<h1>Physical Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody> 
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.physDomP.attributes.name }}</td>
    <td>{{ domain.physDomP.attributes.nameAlias }}</td>
    <td>{{ domain.physDomP.attributes.annotation }}</td>
    <td>{{ domain.physDomP.attributes.childAction }}</td>
    <td>{{ domain.physDomP.attributes.configIssues }}</td>
    <td>{{ domain.physDomP.attributes.dn }}</td>
    <td>{{ domain.physDomP.attributes.extMngdBy }}</td>
    <td>{{ domain.physDomP.attributes.lcOwn }}</td>
    <td>{{ domain.physDomP.attributes.modTs }}</td>
    <td>{{ domain.physDomP.attributes.monPolDn }}</td>
    <td>{{ domain.physDomP.attributes.ownerKey }}</td>
    <td>{{ domain.physDomP.attributes.ownerTag }}</td>
    <td>{{ domain.physDomP.attributes.status }}</td>
    <td>{{ domain.physDomP.attributes.uid }}</td>
    <td>{{ domain.physDomP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "l3extDomP" in api %}
<h1>L3 Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody> 
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.l3extDomP.attributes.name }}</td>
    <td>{{ domain.l3extDomP.attributes.nameAlias }}</td>
    <td>{{ domain.l3extDomP.attributes.annotation }}</td>
    <td>{{ domain.l3extDomP.attributes.childAction }}</td>
    <td>{{ domain.l3extDomP.attributes.configIssues }}</td>
    <td>{{ domain.l3extDomP.attributes.dn }}</td>
    <td>{{ domain.l3extDomP.attributes.extMngdBy }}</td>
    <td>{{ domain.l3extDomP.attributes.lcOwn }}</td>
    <td>{{ domain.l3extDomP.attributes.modTs }}</td>
    <td>{{ domain.l3extDomP.attributes.monPolDn }}</td>
    <td>{{ domain.l3extDomP.attributes.ownerKey }}</td>
    <td>{{ domain.l3extDomP.attributes.ownerTag }}</td>
    <td>{{ domain.l3extDomP.attributes.status }}</td>
    <td>{{ domain.l3extDomP.attributes.uid }}</td>
    <td>{{ domain.l3extDomP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "qosClass" in api %}
<h1>QOS Classes</h1>
<table id = "datatable">
<thead>
  <tr>
    <td>Name</th>
    <th>Name Alias</th>
    <th>Admin</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>MTU</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Priority</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</td>
  </tr>
</thead>
<tbody>  
{%-     for class in data_to_template['imdata'] %}
  <tr>
    <td>{{ class.qosClass.attributes.name }}</td>
    <td>{{ class.qosClass.attributes.nameAlias }}</td>
    <td>{{ class.qosClass.attributes.admin }}</td>
    <td>{{ class.qosClass.attributes.annotation }}</td>
    <td>{{ class.qosClass.attributes.childAction }}</td>
    <td>{{ class.qosClass.attributes.descr }}</td>
    <td>{{ class.qosClass.attributes.dn }}</td>
    <td>{{ class.qosClass.attributes.extMngdBy }}</td>
    <td>{{ class.qosClass.attributes.lcOwn }}</td>
    <td>{{ class.qosClass.attributes.modTs }}</td>
    <td>{{ class.qosClass.attributes.mtu }}</td>
    <td>{{ class.qosClass.attributes.ownerKey }}</td>
    <td>{{ class.qosClass.attributes.ownerTag }}</td>
    <td>{{ class.qosClass.attributes.prio }}</td>
    <td>{{ class.qosClass.attributes.status }}</td>
    <td>{{ class.qosClass.attributes.uid }}</td>
    <td>{{ class.qosClass.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "faultSummary" in api %}
<h1>Fault Summary</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Cause</th>
    <th>Child Action</th>
    <th>Code</th>
    <th>Count</th>
    <th>Description</th>
    <th>DN</th>
    <th>Domain</th>
    <th>Non Acknowledged</th>
    <th>Non Delegated</th>
    <th>Non Delegated And Non Acknowledged</th>
    <th>Rule</th>
    <th>Severity</th>
    <th>Status</th>
    <th>Subject</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>   
{%-     for fault in data_to_template['imdata'] %}
  <tr>
    <td>{{ fault.faultSummary.attributes.cause }}</td>
    <td>{{ fault.faultSummary.attributes.childAction }}</td>
    <td>{{ fault.faultSummary.attributes.code }}</td>
    <td>{{ fault.faultSummary.attributes.count }}</td>
    <td>{{ fault.faultSummary.attributes.descr }}</td>
    <td>{{ fault.faultSummary.attributes.dn }}</td>
    <td>{{ fault.faultSummary.attributes.domain }}</td>
    <td>{{ fault.faultSummary.attributes.nonAcked }}</td>
    <td>{{ fault.faultSummary.attributes.nonDelegated }}</td>
    <td>{{ fault.faultSummary.attributes.nonDelegatedAndNonAcked }}</td>
    <td>{{ fault.faultSummary.attributes.rule }}</td>
    <td>{{ fault.faultSummary.attributes.severity }}</td>
    <td>{{ fault.faultSummary.attributes.status }}</td>
    <td>{{ fault.faultSummary.attributes.subject }}</td>
    <td>{{ fault.faultSummary.attributes.type }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "aaaModLR" in api %}
<h1>Audit Log</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Affected</th>
    <th>Cause</th>
    <th>Change Set</th>
    <th>Child Action</th>
    <th>Client Tag</th>
    <th>Code</th>
    <th>Created</th>
    <th>Description</th>
    <th>DN</th>
    <th>IND</th>
    <th>Last Modified</th>
    <th>Session ID</th>
    <th>Severity</th>
    <th>Status</th>
    <th>Trigger</th>
    <th>TX ID</th>
    <th>User</th>
  </tr>
</thead>
<tbody>    
{%-     for log in data_to_template['imdata'] %}
  <tr>
    <td>{{ log.aaaModLR.attributes.id }}</td>
    <td>{{ log.aaaModLR.attributes.affected }}</td>
    <td>{{ log.aaaModLR.attributes.cause }}</td>
    <td>{{ log.aaaModLR.attributes.changeSet }}</td>
    <td>{{ log.aaaModLR.attributes.childAction }}</td>
    <td>{{ log.aaaModLR.attributes.clientTag }}</td>
    <td>{{ log.aaaModLR.attributes.code }}</td>
    <td>{{ log.aaaModLR.attributes.created }}</td>
    <td>{{ log.aaaModLR.attributes.descr }}</td>
    <td>{{ log.aaaModLR.attributes.dn }}</td>
    <td>{{ log.aaaModLR.attributes.ind }}</td>
    <td>{{ log.aaaModLR.attributes.modTs }}</td>
    <td>{{ log.aaaModLR.attributes.sessionId }}</td>
    <td>{{ log.aaaModLR.attributes.severity }}</td>
    <td>{{ log.aaaModLR.attributes.status }}</td>
    <td>{{ log.aaaModLR.attributes.trig }}</td>
    <td>{{ log.aaaModLR.attributes.txId }}</td>
    <td>{{ log.aaaModLR.attributes.user }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvIp" in api %}
<h1>IP Addresses</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>IP Address</th>
    <th>Annotation</th>
    <th>Base EPG DN</th>
    <th>Bridge Domain DN</th>
    <th>Child Action</th>
    <th>Created</th>
    <th>Debug MAC Message</th>
    <th>ESG Use gDN</th>
    <th>Externally Managed By</th>
    <th>Fabric Path DN</th>
    <th>Flags</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>DN</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
    <th>VRF DN</th>
  </tr>
</thead>
<tbody>   
{%-     for ip in data_to_template['imdata'] %}
  <tr>
    <td>{{ ip.fvIp.attributes.addr }}</td>
    <td>{{ ip.fvIp.attributes.annotation }}</td>
    <td>{{ ip.fvIp.attributes.baseEpgDn }}</td>
    <td>{{ ip.fvIp.attributes.bdDn }}</td>
    <td>{{ ip.fvIp.attributes.childAction }}</td>
    <td>{{ ip.fvIp.attributes.createTs }}</td>
    <td>{{ ip.fvIp.attributes.debugMACMessage }}</td>
    <td>{{ ip.fvIp.attributes.esgUsegDn }}</td>
    <td>{{ ip.fvIp.attributes.extMngdBy }}</td>
    <td>{{ ip.fvIp.attributes.fabricPathDn }}</td>
    <td>{{ ip.fvIp.attributes.flags }}</td>
    <td>{{ ip.fvIp.attributes.lcOwn }}</td>
    <td>{{ ip.fvIp.attributes.modTs }}</td>
    <td>{{ ip.fvIp.attributes.monPolDn }}</td>
    <td>{{ ip.fvIp.attributes.dn }}</td>
    <td>{{ ip.fvIp.attributes.status }}</td>
    <td>{{ ip.fvIp.attributes.uid }}</td>
    <td>{{ ip.fvIp.attributes.userdom }}</td>
    <td>{{ ip.fvIp.attributes.vrfDn }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eventRecord" in api %}
<h1>Events</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Affected</th>
    <th>Cause</th>
    <th>Change Set</th>
    <th>Child Action</th>
    <th>Code</th>
    <th>Created</th>
    <th>Description</th>
    <th>DN</th>
    <th>IND</th>
    <th>Last Modified</th>
    <th>Severity</th>
    <th>Status</th>
    <th>Trigger</th>
    <th>TX ID</th>
    <th>User</th>
  </tr>
</thead>
<tbody> 
{%-     for event in data_to_template['imdata'] %}
  <tr>
    <td>{{ event.eventRecord.attributes.id }}</td>
    <td>{{ event.eventRecord.attributes.affected }}</td>
    <td>{{ event.eventRecord.attributes.cause }}</td>
    <td>{{ event.eventRecord.attributes.changeSet }}</td>
    <td>{{ event.eventRecord.attributes.childAction }}</td>
    <td>{{ event.eventRecord.attributes.code }}</td>
    <td>{{ event.eventRecord.attributes.created }}</td>
    <td>{{ event.eventRecord.attributes.descr }}</td>
    <td>{{ event.eventRecord.attributes.dn }}</td>
    <td>{{ event.eventRecord.attributes.ind }}</td>
    <td>{{ event.eventRecord.attributes.modTs }}</td>
    <td>{{ event.eventRecord.attributes.severity }}</td>
    <td>{{ event.eventRecord.attributes.status }}</td>
    <td>{{ event.eventRecord.attributes.trig }}</td>
    <td>{{ event.eventRecord.attributes.txId }}</td>
    <td>{{ event.eventRecord.attributes.user }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "licenseEntitlement" in api %}
<h1>License Entitlements</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Auth Status</th>
    <th>Child Action</th>
    <th>Count</th>
    <th>Description</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Status</th>
    <th>Tag</th>
    <th>Version</th>
  </tr>
</thead>
<tbody> 
{%-     for license in data_to_template['imdata'] %}
  <tr>
    <td>{{ license.licenseEntitlement.attributes.name }}</th>
    <th>{{ license.licenseEntitlement.attributes.authStatus }}</th>
    <th>{{ license.licenseEntitlement.attributes.childAction }}</th>
    <th>{{ license.licenseEntitlement.attributes.count }}</th>
    <th>{{ license.licenseEntitlement.attributes.descr }}</th>
    <th>{{ license.licenseEntitlement.attributes.dn }}</th>
    <th>{{ license.licenseEntitlement.attributes.lcOwn }}</th>
    <th>{{ license.licenseEntitlement.attributes.modTs }}</th>
    <th>{{ license.licenseEntitlement.attributes.status }}</th>
    <th>{{ license.licenseEntitlement.attributes.tag }}</th>
    <th>{{ license.licenseEntitlement.attributes.version }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "bgpRRNodePEp" in api %}
<h1>BGP Route Reflectors</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>POD ID</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>
{%-     for rr in data_to_template['imdata'] %}
  <tr>
    <td>{{ rr.bgpRRNodePEp.attributes.name }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.nameAlias }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.annotation }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.childAction }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.descr }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.dn }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.extMngdBy }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.id }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.lcOwn }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.modTs }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.monPolDn }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.podId }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.status }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.uid }}</td>
    <td>{{ rr.bgpRRNodePEp.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraPortS" in api %}
<h1>Interface Policies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>Type</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>
{%-     for policy in data_to_template['imdata'] %}
  <tr>
{%-         if "infraSHPortS" in policy%}
    <td>{{ policy.infraSHPortS.attributes.name }}</td>
    <td>{{ policy.infraSHPortS.attributes.nameAlias }}</td>
    <td>{{ policy.infraSHPortS.attributes.annotation }}</td>
    <td>{{ policy.infraSHPortS.attributes.childAction }}</td>
    <td>{{ policy.infraSHPortS.attributes.descr }}</td>
    <td>{{ policy.infraSHPortS.attributes.dn }}</td>
    <td>{{ policy.infraSHPortS.attributes.extMngdBy }}</td>
    <td>{{ policy.infraSHPortS.attributes.lcOwn }}</td>
    <td>{{ policy.infraSHPortS.attributes.modTs }}</td>
    <td>{{ policy.infraSHPortS.attributes.monPolDn }}</td>
    <td>{{ policy.infraSHPortS.attributes.ownerKey }}</td>
    <td>{{ policy.infraSHPortS.attributes.ownerTag }}</td>
    <td>{{ policy.infraSHPortS.attributes.status }}</td>
    <td>{{ policy.infraSHPortS.attributes.type }}</td>
    <td>{{ policy.infraSHPortS.attributes.uid }}</td>
    <td>N/A</td>
{%-         else %}
    <td>{{ policy.infraHPortS.attributes.name }}</td>
    <td>{{ policy.infraHPortS.attributes.nameAlias }}</td>
    <td>{{ policy.infraHPortS.attributes.annotation }}</td>
    <td>{{ policy.infraHPortS.attributes.childAction }}</td>
    <td>{{ policy.infraHPortS.attributes.descr }}</td>
    <td>{{ policy.infraHPortS.attributes.dn }}</td>
    <td>{{ policy.infraHPortS.attributes.extMngdBy }}</td>
    <td>{{ policy.infraHPortS.attributes.lcOwn }}</td>
    <td>{{ policy.infraHPortS.attributes.modTs }}</td>
    <td>{{ policy.infraHPortS.attributes.monPolDn }}</td>
    <td>{{ policy.infraHPortS.attributes.ownerKey }}</td>
    <td>{{ policy.infraHPortS.attributes.ownerTag }}</td>
    <td>{{ policy.infraHPortS.attributes.status }}</td>
    <td>{{ policy.infraHPortS.attributes.type }}</td>
    <td>{{ policy.infraHPortS.attributes.uid }}</td>
    <td>{{ policy.infraHPortS.attributes.userdom }}</td>
{%-         endif %}
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraProfile" in api %}
<h1>Interface Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>Type</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for policy in data_to_template['imdata'] %}
{%-         if policy.infraAccPortP %}
  <tr>
    <td>{{ policy.infraAccPortP.attributes.name }}</td>
    <td>{{ policy.infraAccPortP.attributes.nameAlias }}</td>
    <td>{{ policy.infraAccPortP.attributes.annotation }}</td>
    <td>{{ policy.infraAccPortP.attributes.childAction }}</td>
    <td>{{ policy.infraAccPortP.attributes.descr }}</td>
    <td>{{ policy.infraAccPortP.attributes.dn }}</td>
    <td>{{ policy.infraAccPortP.attributes.extMngdBy }}</td>
    <td>{{ policy.infraAccPortP.attributes.lcOwn }}</td>
    <td>{{ policy.infraAccPortP.attributes.modTs }}</td>
    <td>{{ policy.infraAccPortP.attributes.monPolDn }}</td>
    <td>{{ policy.infraAccPortP.attributes.ownerKey }}</td>
    <td>{{ policy.infraAccPortP.attributes.ownerTag }}</td>
    <td>{{ policy.infraAccPortP.attributes.status }}</td>
    <td>{{ policy.infraAccPortP.attributes.type }}</td>
    <td>{{ policy.infraAccPortP.attributes.uid }}</td>
    <td>{{ policy.infraAccPortP.attributes.userdom }}</td>
  </tr>
{%-         endif %}
{%-         if policy.infraAttEntityP %}
  <tr>
    <td>{{ policy.infraAttEntityP.attributes.name }}</td>
    <td>{{ policy.infraAttEntityP.attributes.nameAlias }}</td>
    <td>{{ policy.infraAttEntityP.attributes.annotation }}</td>
    <td>{{ policy.infraAttEntityP.attributes.childAction }}</td>
    <td>{{ policy.infraAttEntityP.attributes.descr }}</td>
    <td>{{ policy.infraAttEntityP.attributes.dn }}</td>
    <td>{{ policy.infraAttEntityP.attributes.extMngdBy }}</td>
    <td>{{ policy.infraAttEntityP.attributes.lcOwn }}</td>
    <td>{{ policy.infraAttEntityP.attributes.modTs }}</td>
    <td>{{ policy.infraAttEntityP.attributes.monPolDn }}</td>
    <td>{{ policy.infraAttEntityP.attributes.ownerKey }}</td>
    <td>{{ policy.infraAttEntityP.attributes.ownerTag }}</td>
    <td>{{ policy.infraAttEntityP.attributes.status }}</td>
    <td>{{ policy.infraAttEntityP.attributes.type }}</td>
    <td>{{ policy.infraAttEntityP.attributes.uid }}</td>
    <td>{{ policy.infraAttEntityP.attributes.userdom }}</td>
  </tr>
{%-         endif %}
{%-         if policy.infraFexP %}
  <tr>
    <td>{{ policy.infraFexP.attributes.name }}</td>
    <td>{{ policy.infraFexP.attributes.nameAlias }}</td>
    <td>{{ policy.infraFexP.attributes.annotation }}</td>
    <td>{{ policy.infraFexP.attributes.childAction }}</td>
    <td>{{ policy.infraFexP.attributes.descr }}</td>
    <td>{{ policy.infraFexP.attributes.dn }}</td>
    <td>{{ policy.infraFexP.attributes.extMngdBy }}</td>
    <td>{{ policy.infraFexP.attributes.lcOwn }}</td>
    <td>{{ policy.infraFexP.attributes.modTs }}</td>
    <td>{{ policy.infraFexP.attributes.monPolDn }}</td>
    <td>{{ policy.infraFexP.attributes.ownerKey }}</td>
    <td>{{ policy.infraFexP.attributes.ownerTag }}</td>
    <td>{{ policy.infraFexP.attributes.status }}</td>
    <td>{{ policy.infraFexP.attributes.type }}</td>
    <td>{{ policy.infraFexP.attributes.uid }}</td>
    <td>{{ policy.infraFexP.attributes.userdom }}</td>
  </tr>
{%-         endif %}
{%-         if policy.infraFuncP %}
  <tr>
    <td>{{ policy.infraFuncP.attributes.name }}</td>
    <td>{{ policy.infraFuncP.attributes.nameAlias }}</td>
    <td>{{ policy.infraFuncP.attributes.annotation }}</td>
    <td>{{ policy.infraFuncP.attributes.childAction }}</td>
    <td>{{ policy.infraFuncP.attributes.descr }}</td>
    <td>{{ policy.infraFuncP.attributes.dn }}</td>
    <td>{{ policy.infraFuncP.attributes.extMngdBy }}</td>
    <td>{{ policy.infraFuncP.attributes.lcOwn }}</td>
    <td>{{ policy.infraFuncP.attributes.modTs }}</td>
    <td>{{ policy.infraFuncP.attributes.monPolDn }}</td>
    <td>{{ policy.infraFuncP.attributes.ownerKey }}</td>
    <td>{{ policy.infraFuncP.attributes.ownerTag }}</td>
    <td>{{ policy.infraFuncP.attributes.status }}</td>
    <td>{{ policy.infraFuncP.attributes.type }}</td>
    <td>{{ policy.infraFuncP.attributes.uid }}</td>
    <td>{{ policy.infraFuncP.attributes.userdom }}</td>
  </tr>
{%-         endif %}
{%-         if policy.infraNodeP %}
  <tr>
    <td>{{ policy.infraNodeP.attributes.name }}</td>
    <td>{{ policy.infraNodeP.attributes.nameAlias }}</td>
    <td>{{ policy.infraNodeP.attributes.annotation }}</td>
    <td>{{ policy.infraNodeP.attributes.childAction }}</td>
    <td>{{ policy.infraNodeP.attributes.descr }}</td>
    <td>{{ policy.infraNodeP.attributes.dn }}</td>
    <td>{{ policy.infraNodeP.attributes.extMngdBy }}</td>
    <td>{{ policy.infraNodeP.attributes.lcOwn }}</td>
    <td>{{ policy.infraNodeP.attributes.modTs }}</td>
    <td>{{ policy.infraNodeP.attributes.monPolDn }}</td>
    <td>{{ policy.infraNodeP.attributes.ownerKey }}</td>
    <td>{{ policy.infraNodeP.attributes.ownerTag }}</td>
    <td>{{ policy.infraNodeP.attributes.status }}</td>
    <td>{{ policy.infraNodeP.attributes.type }}</td>
    <td>{{ policy.infraNodeP.attributes.uid }}</td>
    <td>{{ policy.infraNodeP.attributes.userdom }}</td>
  </tr>
{%-         endif %}
{%-         if policy.infraPodP %}
  <tr>
    <td>{{ policy.infraPodP.attributes.name }}</td>
    <td>{{ policy.infraPodP.attributes.nameAlias }}</td>
    <td>{{ policy.infraPodP.attributes.annotation }}</td>
    <td>{{ policy.infraPodP.attributes.childAction }}</td>
    <td>{{ policy.infraPodP.attributes.descr }}</td>
    <td>{{ policy.infraPodP.attributes.dn }}</td>
    <td>{{ policy.infraPodP.attributes.extMngdBy }}</td>
    <td>{{ policy.infraPodP.attributes.lcOwn }}</td>
    <td>{{ policy.infraPodP.attributes.modTs }}</td>
    <td>{{ policy.infraPodP.attributes.monPolDn }}</td>
    <td>{{ policy.infraPodP.attributes.ownerKey }}</td>
    <td>{{ policy.infraPodP.attributes.ownerTag }}</td>
    <td>{{ policy.infraPodP.attributes.status }}</td>
    <td>{{ policy.infraPodP.attributes.type }}</td>
    <td>{{ policy.infraPodP.attributes.uid }}</td>
    <td>{{ policy.infraPodP.attributes.userdom }}</td>
  </tr>
{%-         endif %}
{%-         if policy.infraSpAccPortP %}
  <tr>
    <td>{{ policy.infraSpAccPortP.attributes.name }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.nameAlias }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.annotation }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.childAction }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.descr }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.dn }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.extMngdBy }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.lcOwn }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.modTs }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.monPolDn }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.ownerKey }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.ownerTag }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.status }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.type }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.uid }}</td>
    <td>{{ policy.infraSpAccPortP.attributes.userdom }}</td>
  </tr>
{%-         endif %}
{%-         if policy.infraSpineP %}
  <tr>
    <td>{{ policy.infraSpineP.attributes.name }}</td>
    <td>{{ policy.infraSpineP.attributes.nameAlias }}</td>
    <td>{{ policy.infraSpineP.attributes.annotation }}</td>
    <td>{{ policy.infraSpineP.attributes.childAction }}</td>
    <td>{{ policy.infraSpineP.attributes.descr }}</td>
    <td>{{ policy.infraSpineP.attributes.dn }}</td>
    <td>{{ policy.infraSpineP.attributes.extMngdBy }}</td>
    <td>{{ policy.infraSpineP.attributes.lcOwn }}</td>
    <td>{{ policy.infraSpineP.attributes.modTs }}</td>
    <td>{{ policy.infraSpineP.attributes.monPolDn }}</td>
    <td>{{ policy.infraSpineP.attributes.ownerKey }}</td>
    <td>{{ policy.infraSpineP.attributes.ownerTag }}</td>
    <td>{{ policy.infraSpineP.attributes.status }}</td>
    <td>{{ policy.infraSpineP.attributes.type }}</td>
    <td>{{ policy.infraSpineP.attributes.uid }}</td>
    <td>{{ policy.infraSpineP.attributes.userdom }}</td>
  </tr>
{%-         endif %}
{%-     endfor %}
</tbody>
</table>
{%- elif "fabricPod" in api %}
<h1>Fabric Pods</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Pod Type</th>
    <th>Status</th>
  </tr>
</thead>
<tbody> 
{%-     for pod in data_to_template['imdata'] %}
  <tr>
    <td>{{ pod.fabricPod.attributes.id }}</td>
    <td>{{ pod.fabricPod.attributes.childAction }}</td>
    <td>{{ pod.fabricPod.attributes.dn }}</td>
    <td>{{ pod.fabricPod.attributes.lcOwn }}</td>
    <td>{{ pod.fabricPod.attributes.modTs }}</td>
    <td>{{ pod.fabricPod.attributes.monPolDn }}</td>
    <td>{{ pod.fabricPod.attributes.podType }}</td>
    <td>{{ pod.fabricPod.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fabricPath" in api %}
{%-     if "Ep" in api %}
{%-         if "Cont" in api %}
<h1>Fabric Path Endpoint Containers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Node ID</th>
    <th>DN</th>
    <th>Child Action</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody> 
{%-             for container in data_to_template['imdata'] %}
  <tr>
    <td>{{ container.fabricPathEpCont.attributes.nodeId }}</td>
    <td>{{ container.fabricPathEpCont.attributes.dn }}</td>
    <td>{{ container.fabricPathEpCont.attributes.childAction }}</td>
    <td>{{ container.fabricPathEpCont.attributes.lcOwn }}</td>
    <td>{{ container.fabricPathEpCont.attributes.modTs }}</td>
    <td>{{ container.fabricPathEpCont.attributes.monPolDn }}</td>
    <td>{{ container.fabricPathEpCont.attributes.status }}</td>
  </tr>
{%-             endfor %}
</tbody>
</table>
{%-         else %}
<h1>Fabric Path Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Lag Type</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Path Type</th>
    <th>Status</th>
  </tr>
</thead>
<tbody> 
{%-             for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.fabricPathEp.attributes.name }}</td>
    <td>{{ endpoint.fabricPathEp.attributes.childAction }}</td>
    <td>{{ endpoint.fabricPathEp.attributes.descr }}</td>
    <td>{{ endpoint.fabricPathEp.attributes.dn }}</td>
    <td>{{ endpoint.fabricPathEp.attributes.lagT }}</td>
    <td>{{ endpoint.fabricPathEp.attributes.lcOwn }}</td>
    <td>{{ endpoint.fabricPathEp.attributes.modTs }}</td>
    <td>{{ endpoint.fabricPathEp.attributes.monPolDn }}</td>
    <td>{{ endpoint.fabricPathEp.attributes.pathT }}</td>
    <td>{{ endpoint.fabricPathEp.attributes.status }}</td>
  </tr>
{%-             endfor %}
</tbody>
</table>
{%-         endif %}
{%-     else %}
<h1>Fabric Paths</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Node 1</th>
    <th>Node 2</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Updated</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody> 
{%-         for path in data_to_template['imdata'] %}
  <tr>
    <td>{{ path.fabricPath.attributes.n1 }}</td>
    <td>{{ path.fabricPath.attributes.n2 }}</td>
    <td>{{ path.fabricPath.attributes.childAction }}</td>
    <td>{{ path.fabricPath.attributes.dn }}</td>
    <td>{{ path.fabricPath.attributes.lcOwn }}</td>
    <td>{{ path.fabricPath.attributes.modTs }}</td>
    <td>{{ path.fabricPath.attributes.monPolDn }}</td>
    <td>{{ path.fabricPath.attributes.status }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "rtctrlSubjP" in api %}
<h1>Prefix List</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Status</th>
    <th>UID</th>
    <th>Used Domain</th>
  </tr>
</thead>
<tbody>
{%-     for outer_list in data_to_template %}
{%-         for prefix_list in outer_list %}
  <tr>
    <td>{{ prefix_list.rtctrlSubjP.attributes.annotation }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.childAction }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.description }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.dn }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.extMngdBy }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.lcOwn }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.modTs }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.name }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.nameAlias }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.status }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.uid }}</td>
    <td>{{ prefix_list.rtctrlSubjP.attributes.userdom }}</td>
  </tr>
{%-         endfor %}
{%-     endfor %}
</tbody>
</table>
{%- elif "rtctrlMatchRtDest" in api %}
<h1>Prefix List Detailed</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Aggregate</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>fromPfxLen</th>
    <th>IP</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Status</th>
    <th>toPfxLen</th>
    <th>Type</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for outer_list in data_to_template %}
{%-         for prefix_list_detailed in outer_list %}
  <tr>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.aggregate }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.annotation }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.childAction }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.descr }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.dn }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.extMngdBy }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.fromPfxLen }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.ip }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.lcOwn }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.modTs }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.name }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.nameAlias }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.status }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.toPfxLen }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.type }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.uid }}</td>
    <td>{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.userdom }}</td>
  </tr>
{%-         endfor %}
{%-     endfor %}
</tbody>
</table>
{%- elif "Tenant" in api %}
<h1>Tenants</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>User Domain</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>  
<tbody>
{%-     for tenant in data_to_template['imdata'] %}
  <tr>
    <td>{{ tenant.fvTenant.attributes.name }}</td>
    <td>{{ tenant.fvTenant.attributes.nameAlias }}</td>
    <td>{{ tenant.fvTenant.attributes.descr }}</td>
    <td>{{ tenant.fvTenant.attributes.status }}</td>
    <td>{{ tenant.fvTenant.attributes.dn }}</td>
    <td>{{ tenant.fvTenant.attributes.uid }}</td>
    <td>{{ tenant.fvTenant.attributes.annotation }}</td>
    <td>{{ tenant.fvTenant.attributes.childAction }}</td>
    <td>{{ tenant.fvTenant.attributes.extMngdBy }}</td>
    <td>{{ tenant.fvTenant.attributes.lcOwn }}</td>
    <td>{{ tenant.fvTenant.attributes.monPolDn }}</td>
    <td>{{ tenant.fvTenant.attributes.ownerKey }}</td>
    <td>{{ tenant.fvTenant.attributes.ownerTag }}</td>
    <td>{{ tenant.fvTenant.attributes.userdom }}</td>
    <td>{{ tenant.fvTenant.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "aaaUser" in api %}
<h1>Users</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Account Status</th>
    <th>Annotation</th>
    <th>Cert Attribute</th>
    <th>Child Action</th>
    <th>Clear Password History</th>
    <th>Description</th>
    <th>DN</th>
    <th>Email</th>
    <th>Expiration</th>
    <th>Expires</th>
    <th>Externally Managed By</th>
    <th>First Name</th>
    <th>Last Name</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>OTP Enable</th>
    <th>OTP Enforced</th>
    <th>OTP Key</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Phone</th>
    <th>Password Life Time</th>
    <th>Password Update Required</th>
    <th>RBAC String</th>
    <th>Restricted RBAC User</th>
    <th>Status</th>
    <th>UID</th>
    <th>UNIX User ID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>
{%-     for user in data_to_template['imdata'] %}
  <tr>
    <td>{{ user.aaaUser.attributes.name }}</td>
    <td>{{ user.aaaUser.attributes.nameAlias }}</td>
    <td>{{ user.aaaUser.attributes.accountStatus }}</td>
    <td>{{ user.aaaUser.attributes.annotation }}</td>
    <td>{{ user.aaaUser.attributes.certAttribute }}</td>
    <td>{{ user.aaaUser.attributes.childAction }}</td>
    <td>{{ user.aaaUser.attributes.clearPwdHistory }}</td>
    <td>{{ user.aaaUser.attributes.descr }}</td>
    <td>{{ user.aaaUser.attributes.dn }}</td>
    <td>{{ user.aaaUser.attributes.email }}</td>
    <td>{{ user.aaaUser.attributes.expiration }}</td>
    <td>{{ user.aaaUser.attributes.expires }}</td>
    <td>{{ user.aaaUser.attributes.extMngdBy }}</td>
    <td>{{ user.aaaUser.attributes.firstName }}</td>
    <td>{{ user.aaaUser.attributes.lastName }}</td>
    <td>{{ user.aaaUser.attributes.lcOwn }}</td>
    <td>{{ user.aaaUser.attributes.modTs }}</td>
    <td>{{ user.aaaUser.attributes.monPolDn }}</td>
    <td>{{ user.aaaUser.attributes.otpenable }}</td>
    <td>{{ user.aaaUser.attributes.otpenf }}</td>
    <td>{{ user.aaaUser.attributes.otpkey }}</td>
    <td>{{ user.aaaUser.attributes.ownerKey }}</td>
    <td>{{ user.aaaUser.attributes.ownerTag }}</td>
    <td>{{ user.aaaUser.attributes.phone }}</td>
    <td>{{ user.aaaUser.attributes.pwdLifeTime }}</td>
    <td>{{ user.aaaUser.attributes.pwdUpdateRequired }}</td>
    <td>{{ user.aaaUser.attributes.rbacString }}</td>
    <td>{{ user.aaaUser.attributes.restrictedRbacUser }}</td>
    <td>{{ user.aaaUser.attributes.status }}</td>
    <td>{{ user.aaaUser.attributes.uid }}</td>
    <td>{{ user.aaaUser.attributes.unixUserId }}</td>
    <td>{{ user.aaaUser.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "aaaDomain" in api %}
<h1>Security Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Restricted RBAC Domain</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.aaaDomain.attributes.name }}</td>
    <td>{{ domain.aaaDomain.attributes.nameAlias }}</td>
    <td>{{ domain.aaaDomain.attributes.annotation }}</td>
    <td>{{ domain.aaaDomain.attributes.childAction }}</td>
    <td>{{ domain.aaaDomain.attributes.descr }}</td>
    <td>{{ domain.aaaDomain.attributes.dn }}</td>
    <td>{{ domain.aaaDomain.attributes.extMngdBy }}</td>
    <td>{{ domain.aaaDomain.attributes.lcOwn }}</td>
    <td>{{ domain.aaaDomain.attributes.modTs }}</td>
    <td>{{ domain.aaaDomain.attributes.ownerKey }}</td>
    <td>{{ domain.aaaDomain.attributes.ownerTag }}</td>
    <td>{{ domain.aaaDomain.attributes.restrictedRbacDomain }}</td>
    <td>{{ domain.aaaDomain.attributes.status }}</td>
    <td>{{ domain.aaaDomain.attributes.uid }}</td>
    <td>{{ domain.aaaDomain.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "vzSubj" in api %}
<h1>Contract Subjects</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Access Privilege</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>Consumer Match T</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Priority</th>
    <th>Provider Match T</th>
    <th>Reverse Filter Ports</th>
    <th>Status</th>
    <th>Target DSCP</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>
{%-     for subject in data_to_template['imdata'] %}
  <tr>
    <td>{{ subject.vzSubj.attributes.name }}</td>
    <td>{{ subject.vzSubj.attributes.nameAlias }}</td>
    <td>{{ subject.vzSubj.attributes.accessPrivilege }}</td>
    <td>{{ subject.vzSubj.attributes.annotation }}</td>
    <td>{{ subject.vzSubj.attributes.childAction }}</td>
    <td>{{ subject.vzSubj.attributes.configIssues }}</td>
    <td>{{ subject.vzSubj.attributes.consMatchT }}</td>
    <td>{{ subject.vzSubj.attributes.descr }}</td>
    <td>{{ subject.vzSubj.attributes.dn }}</td>
    <td>{{ subject.vzSubj.attributes.extMngdBy }}</td>
    <td>{{ subject.vzSubj.attributes.lcOwn }}</td>
    <td>{{ subject.vzSubj.attributes.modTs }}</td>
    <td>{{ subject.vzSubj.attributes.monPolDn }}</td>
    <td>{{ subject.vzSubj.attributes.prio }}</td>
    <td>{{ subject.vzSubj.attributes.provMatchT }}</td>
    <td>{{ subject.vzSubj.attributes.revFltPorts }}</td>
    <td>{{ subject.vzSubj.attributes.status }}</td>
    <td>{{ subject.vzSubj.attributes.targetDscp }}</td>
    <td>{{ subject.vzSubj.attributes.uid }}</td>
    <td>{{ subject.vzSubj.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "topology/health" in api %}
<h1>Fabric Total Health</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Change</th>
    <th>Current</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Maximum Severity</th>
    <th>Last Modified</th>
    <th>Previous</th>
    <th>Status</th>
    <th>TW Score</th>
    <th>Updated</th>
  </tr>
</thead>
<tbody>
{%-     for score in data_to_template['imdata'] %}
  <tr>
    <td>{{ score.fabricHealthTotal.attributes.chng }}</td>
    <td>{{ score.fabricHealthTotal.attributes.cur }}</td>
    <td>{{ score.fabricHealthTotal.attributes.childAction }}</td>
    <td>{{ score.fabricHealthTotal.attributes.dn }}</td>
    <td>{{ score.fabricHealthTotal.attributes.lcOwn }}</td>
    <td>{{ score.fabricHealthTotal.attributes.maxSev }}</td>
    <td>{{ score.fabricHealthTotal.attributes.modTs }}</td>
    <td>{{ score.fabricHealthTotal.attributes.prev }}</td>
    <td>{{ score.fabricHealthTotal.attributes.status }}</td>
    <td>{{ score.fabricHealthTotal.attributes.twScore }}</td>
    <td>{{ score.fabricHealthTotal.attributes.updTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "pkiFabricNodeSSLCertificate" in api %}
<h1>Fabric Node SSL Certificates</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Authority Key Identifier</th>
    <th>Child Action</th>
    <th>Data</th>
    <th>Description</th>
    <th>DN</th>
    <th>Expired Certificate</th>
    <th>Invalid Issuer</th>
    <th>Invalid Signing CA For Certificate</th>
    <th>Invalid Subject Format</th>
    <th>Issuer</th>
    <th>Key Size</th>
    <th>Local Owner</th>
    <th>Message</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Node ID</th>
    <th>Node Type</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Public Key Algorithm</th>
    <th>Serial Number</th>
    <th>Signature Algorithm</th>
    <th>Status</th>
    <th>Subject</th>
    <th>Subject Key Identifier</th>
    <th>Valid Certificate</th>
    <th>Validity Not After</th>
    <th>Validity Not Before</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>
{%-     for cert in data_to_template['imdata'] %}
  <tr>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.name }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.nameAlias }}</th>
    <td>{{ cert.pkiFabricNodeSSLCertificate.attributes.authorityKeyIdentifier }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.childAction }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.data | replace("\n"," ") }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.descr }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.dn }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.expiredCertificate }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.invalidIssuer }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.invalidSigningCAForCertificate }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.invalidSubjectFormat }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.issuer }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.keySize }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.lcOwn }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.message }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.modTs }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.monPolDn }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.nodeId }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.nodeType }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.ownerKey }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.ownerTag }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.publicKeyAlgorithm }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.serialNumber }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.signatureAlgorithm }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.status }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.subject }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.subjectKeyIdentifier }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.validCertificate }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.validityNotAfter }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.validityNotBefore }}</th>
    <th>{{ cert.pkiFabricNodeSSLCertificate.attributes.version }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "tn-" and "health" in api %}
<h1>Tenant Health</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Change</th>
    <th>Current</th>
    <th>Previous</th>
    <th>TW Score</th>
    <th>Child Action</th>
    <th>Max Severity</th>
    <th>Last Modified</th>
    <th>Status</th>
    <th>Last Updated</th>
  </tr>
</thead>
<tbody>
{%-     for outer_list in data_to_template %}
{%-         for tenant in outer_list %}
  <tr>
    <td>{{ tenant.healthInst.attributes.dn }}</td>
    <td>{{ tenant.healthInst.attributes.chng }}</td>
    <td>{{ tenant.healthInst.attributes.cur }}</td>
    <td>{{ tenant.healthInst.attributes.prev }}</td>
    <td>{{ tenant.healthInst.attributes.twScore }}</td>
    <td>{{ tenant.healthInst.attributes.childAction }}</td>
    <td>{{ tenant.healthInst.attributes.maxSev }}</td>
    <td>{{ tenant.healthInst.attributes.modTs }}</td>
    <td>{{ tenant.healthInst.attributes.status }}</td>
    <td>{{ tenant.healthInst.attributes.updTs }}</td>
  </tr>
{%-         endfor %}
{%-     endfor %}
</tbody>
</table>
{%- elif "firmwareCtrlrRunning" in api %}
<h1>Fabric Membership</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>Internal Label</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Status</th>
    <th>TPM In Use</th>
    <th>Timestamp</th>
    <th>Type</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>
{%-     for member in data_to_template['imdata'] %}
  <tr>
    <td>{{ member.firmwareCtrlrRunning.attributes.dn }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.childAction }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.descr }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.internalLabel }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.lcOwn }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.modTs }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.mode }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.status }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.tpmInUse }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.ts }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.type }}</td>
    <td>{{ member.firmwareCtrlrRunning.attributes.version }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "topSystem" in api %}
{%-     if "?" not in api %}
<h1>Top System</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Address</th>
    <th>Bootstrap State</th>
    <th>Child Action</th>
    <th>Cluster Time Diff</th>
    <th>Configuration Issues</th>
    <th>Control Plane MTU</th>
    <th>Current Time</th>
    <th>DN</th>
    <th>Enforce Subnet Check</th>
    <th>ETEP Address</th>
    <th>Fabric Domain</th>
    <th>Fabric ID</th>
    <th>Fabric MAC</th>
    <th>ID</th>
    <th>Inband Mgmt Address</th>
    <th>Inband Mgmt Address6</th>
    <th>Inband Mgmt Address6 Mask</th>
    <th>Inband Mgmt Address Mask</th>
    <th>Inband Mgmt Gateway</th>
    <th>Inband Mgmt Gateway6</th>
    <th>Last Reboot Time</th>
    <th>Last Reset Reason</th>
    <th>LC Own</th>
    <th>Modified Timestamp</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>Name Alias</th>
    <th>Node Type</th>
    <th>Out of Band Mgmt Address</th>
    <th>Out of Band Mgmt Address6</th>
    <th>Out of Band Mgmt Address6 Mask</th>
    <th>Out of Band Mgmt Address Mask</th>
    <th>Out of Band Mgmt Gateway</th>
    <th>Out of Band Mgmt Gateway6</th>
    <th>Pod ID</th>
    <th>Remote Network ID</th>
    <th>Remote Node</th>
    <th>RL Oper Pod ID</th>
    <th>RL Routable Mode</th>
    <th>RL Direct Mode</th>
    <th>Role</th>
    <th>Serial Number</th>
    <th>Server Type</th>
    <th>Site ID</th>
    <th>State</th>
    <th>Status</th>
    <th>System Uptime</th>
    <th>TEP Pool</th>
    <th>Unicast XR EP Learn Disable</th>
    <th>Version</th>
    <th>Virtual Mode</th>
  </tr>
</thead>
<tbody>
{%-         for topSystem in data_to_template['imdata'] %}
  <tr>
    <td>{{ topSystem.topSystem.attributes.name }}</td>
    <td>{{ topSystem.topSystem.attributes.address }}</td>
    <td>{{ topSystem.topSystem.attributes.bootstrapState }}</td>
    <td>{{ topSystem.topSystem.attributes.childAction }}</td>
    <td>{{ topSystem.topSystem.attributes.clusterTimeDiff }}</td>
    <td>{{ topSystem.topSystem.attributes.configIssues }}</td>
    <td>{{ topSystem.topSystem.attributes.controlPlaneMTU }}</td>
    <td>{{ topSystem.topSystem.attributes.currentTime }}</td>
    <td>{{ topSystem.topSystem.attributes.dn }}</td>
    <td>{{ topSystem.topSystem.attributes.enforceSubnetCheck }}</td>
    <td>{{ topSystem.topSystem.attributes.etepAddr }}</td>
    <td>{{ topSystem.topSystem.attributes.fabricDomain }}</td>
    <td>{{ topSystem.topSystem.attributes.fabricId }}</td>
    <td>{{ topSystem.topSystem.attributes.fabricMAC }}</td>
    <td>{{ topSystem.topSystem.attributes.id }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtAddr }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtAddr }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtAddr6Mask }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtAddrMask }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtGateway }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtGateway6 }}</td>
    <td>{{ topSystem.topSystem.attributes.lastRebootTime }}</td>
    <td>{{ topSystem.topSystem.attributes.lastResetReason }}</td>
    <td>{{ topSystem.topSystem.attributes.lcOwn }}</td>
    <td>{{ topSystem.topSystem.attributes.modTs }}</td>
    <td>{{ topSystem.topSystem.attributes.mode }}</td>
    <td>{{ topSystem.topSystem.attributes.monPolDn }}</td>
    <td>{{ topSystem.topSystem.attributes.nameAlias }}</td>
    <td>{{ topSystem.topSystem.attributes.nodeType }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtAddr }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtAddr6 }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtAddr6Mask }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtAddrMask }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtGateway }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtGateway6 }}</td>
    <td>{{ topSystem.topSystem.attributes.podId }}</td>
    <td>{{ topSystem.topSystem.attributes.remoteNetworkId }}</td>
    <td>{{ topSystem.topSystem.attributes.remoteNode }}</td>
    <td>{{ topSystem.topSystem.attributes.rlOperPodId }}</td>
    <td>{{ topSystem.topSystem.attributes.rlRoutableMode }}</td>
    <td>{{ topSystem.topSystem.attributes.rldirectMode }}</td>
    <td>{{ topSystem.topSystem.attributes.role }}</td>
    <td>{{ topSystem.topSystem.attributes.serial }}</td>
    <td>{{ topSystem.topSystem.attributes.serverType }}</td>
    <td>{{ topSystem.topSystem.attributes.siteId }}</td>
    <td>{{ topSystem.topSystem.attributes.state }}</td>
    <td>{{ topSystem.topSystem.attributes.status }}</td>
    <td>{{ topSystem.topSystem.attributes.systemUpTime }}</td>
    <td>{{ topSystem.topSystem.attributes.tepPool }}</td>
    <td>{{ topSystem.topSystem.attributes.unicastXrEpLearnDisable }}</td>
    <td>{{ topSystem.topSystem.attributes.version }}</td>
    <td>{{ topSystem.topSystem.attributes.virtualMode }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "infraWiNode" in api %}
<h1>Cluster Health</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Node Name</th>
    <th>Name</th>
    <th>Name Alias</th>
    <th>IP Address</th>
    <th>Admin State</th>
    <th>Annotation</th>
    <th>APIC Mode</th>
    <th>Chassis</th>
    <th>Child Action</th>
    <th>Control Sbst State</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Failover Status</th>
    <th>Health</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Member Serial Number</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Mutn Timestamp</th>
    <th>Operational State</th>
    <th>Pod ID</th>
    <th>Routable IP Address</th>
    <th>Status</th>
    <th>Target Member Serial Number</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>
{%-     for node in data_to_template['imdata'] %}
  <tr>
    <td>{{ node.infraWiNode.attributes.nodeName }}</td>
    <td>{{ node.infraWiNode.attributes.name }}</td>
    <td>{{ node.infraWiNode.attributes.nameAlias }}</td>
    <td>{{ node.infraWiNode.attributes.addr }}</td>
    <td>{{ node.infraWiNode.attributes.adminSt }}</td>
    <td>{{ node.infraWiNode.attributes.annotation }}</td>
    <td>{{ node.infraWiNode.attributes.apicMode }}</td>
    <td>{{ node.infraWiNode.attributes.chassis }}</td>
    <td>{{ node.infraWiNode.attributes.childAction }}</td>
    <td>{{ node.infraWiNode.attributes.cntrlSbstState }}</td>
    <td>{{ node.infraWiNode.attributes.dn }}</td>
    <td>{{ node.infraWiNode.attributes.extMngdBy }}</td>
    <td>{{ node.infraWiNode.attributes.failoverStatus }}</td>
    <td>{{ node.infraWiNode.attributes.health }}</td>
    <td>{{ node.infraWiNode.attributes.id }}</td>
    <td>{{ node.infraWiNode.attributes.lcOwn }}</td>
    <td>{{ node.infraWiNode.attributes.mbSn }}</td>
    <td>{{ node.infraWiNode.attributes.modTs }}</td>
    <td>{{ node.infraWiNode.attributes.monPolDn }}</td>
    <td>{{ node.infraWiNode.attributes.mutnTs }}</td>
    <td>{{ node.infraWiNode.attributes.operSt }}</td>
    <td>{{ node.infraWiNode.attributes.podId }}</td>
    <td>{{ node.infraWiNode.attributes.routableIpAddr }}</td>
    <td>{{ node.infraWiNode.attributes.status }}</td>
    <td>{{ node.infraWiNode.attributes.targetMbSn }}</td>
    <td>{{ node.infraWiNode.attributes.uid }}</td>
    <td>{{ node.infraWiNode.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "vnsMDev" in api %}
<h1>Device Packages</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Vendor</th>
    <th>Annotation</th>
    <th>Audit On Busy</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Function Mask</th>
    <th>Local Owner</th>
    <th>Managed</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>
{%-     for package in data_to_template['imdata'] %}
  <tr>
    <td>{{ package.vnsMDev.attributes.vendor }}</td>
    <td>{{ package.vnsMDev.attributes.annotation }}</td>
    <td>{{ package.vnsMDev.attributes.auditOnBusy }}</td>
    <td>{{ package.vnsMDev.attributes.childAction }}</td>
    <td>{{ package.vnsMDev.attributes.dn }}</td>
    <td>{{ package.vnsMDev.attributes.extMngdBy }}</td>
    <td>{{ package.vnsMDev.attributes.funcMask }}</td>
    <td>{{ package.vnsMDev.attributes.lcOwn }}</td>
    <td>{{ package.vnsMDev.attributes.managed }}</td>
    <td>{{ package.vnsMDev.attributes.modTs }}</td>
    <td>{{ package.vnsMDev.attributes.model }}</td>
    <td>{{ package.vnsMDev.attributes.monPolDn }}</td>
    <td>{{ package.vnsMDev.attributes.status }}</td>
    <td>{{ package.vnsMDev.attributes.uid }}</td>
    <td>{{ package.vnsMDev.attributes.userdom }}</td>
    <td>{{ package.vnsMDev.attributes.version }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "cnwAggrIf" in api %}
<h1>Cluster Aggregate Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Auto Negotiate</th>
    <th>Bandwidth</th>
    <th>Child Action</th>
    <th>Delay</th>
    <th>Description</th>
    <th>DN</th>
    <th>Dot1q Ether Type</th>
    <th>FCOT Channel Number</th>
    <th>ID</th>
    <th>Inherited Bandwidth</th>
    <th>Is Reflective Relay Config Supported</th>
    <th>Layer</th>
    <th>Local Owner</th>
    <th>Link Debounce</th>
    <th>Link Log</th>
    <th>MDIX</th>
    <th>Medium</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>MTU</th>
    <th>Oper State</th>
    <th>Path S Description</th>
    <th>Port T</th>
    <th>Priority Flow Control</th>
    <th>Reflective Relay Enable</th>
    <th>Router MAC</th>
    <th>SNMP Trap State</th>
    <th>Span Mode</th>
    <th>Speed</th>
    <th>Status</th>
    <th>Switching State</th>
    <th>Trunk Log</th>
    <th>Usage</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.cnwAggrIf.attributes.name }}</td>
    <td>{{ interface.cnwAggrIf.attributes.adminSt }}</td>
    <td>{{ interface.cnwAggrIf.attributes.autoNeg }}</td>
    <td>{{ interface.cnwAggrIf.attributes.bw }}</td>
    <td>{{ interface.cnwAggrIf.attributes.childAction }}</td>
    <td>{{ interface.cnwAggrIf.attributes.delay }}</td>
    <td>{{ interface.cnwAggrIf.attributes.descr }}</td>
    <td>{{ interface.cnwAggrIf.attributes.dn }}</td>
    <td>{{ interface.cnwAggrIf.attributes.dot1qEtherType }}</td>
    <td>{{ interface.cnwAggrIf.attributes.fcotChannelNumber }}</td>
    <td>{{ interface.cnwAggrIf.attributes.id }}</td>
    <td>{{ interface.cnwAggrIf.attributes.inhBw }}</td>
    <td>{{ interface.cnwAggrIf.attributes.isReflectiveRelayCfgSupported }}</td>
    <td>{{ interface.cnwAggrIf.attributes.layer }}</td>
    <td>{{ interface.cnwAggrIf.attributes.lcOwn }}</td>
    <td>{{ interface.cnwAggrIf.attributes.linkDebounce }}</td>
    <td>{{ interface.cnwAggrIf.attributes.linkLog }}</td>
    <td>{{ interface.cnwAggrIf.attributes.mdix }}</td>
    <td>{{ interface.cnwAggrIf.attributes.medium }}</td>
    <td>{{ interface.cnwAggrIf.attributes.modTs }}</td>
    <td>{{ interface.cnwAggrIf.attributes.mode }}</td>
    <td>{{ interface.cnwAggrIf.attributes.monPolDn }}</td>
    <td>{{ interface.cnwAggrIf.attributes.mtu }}</td>
    <td>{{ interface.cnwAggrIf.attributes.operSt }}</td>
    <td>{{ interface.cnwAggrIf.attributes.pathSDescr }}</td>
    <td>{{ interface.cnwAggrIf.attributes.portT }}</td>
    <td>{{ interface.cnwAggrIf.attributes.prioFlowCtrl }}</td>
    <td>{{ interface.cnwAggrIf.attributes.reflectiveRelayEn }}</td>
    <td>{{ interface.cnwAggrIf.attributes.routerMac }}</td>
    <td>{{ interface.cnwAggrIf.attributes.snmpTrapSt }}</td>
    <td>{{ interface.cnwAggrIf.attributes.spanMode }}</td>
    <td>{{ interface.cnwAggrIf.attributes.speed }}</td>
    <td>{{ interface.cnwAggrIf.attributes.status }}</td>
    <td>{{ interface.cnwAggrIf.attributes.switchingSt }}</td>
    <td>{{ interface.cnwAggrIf.attributes.trunkLog }}</td>
    <td>{{ interface.cnwAggrIf.attributes.usage }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "l3Inst" in api %}
<h1>Layer3 Interfaces </h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>BGP RD</th>
    <th>BGP RD Display</th>
    <th>Child Action</th>
    <th>Created Timestamp</th>
    <th>CTX PKey</th>
    <th>DN</th>
    <th>Domain ID</th>
    <th>Encapsulation</th>
    <th>GSDB CTX</th>
    <th>ID</th>
    <th>L3 VM Config Failed Bmp</th>
    <th>L3 VM Config Failed Timestamp</th>
    <th>L3 VM Config State</th>
    <th>Last Changed Timestamp</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>MPLS VPN Label Index</th>
    <th>Old Oper State Quality</th>
    <th>Oper State Quality</th>
    <th>Oper State</th>
    <th>Oui</th>
    <th>Pending</th>
    <th>Port CL Bmp</th>
    <th>Resource ID</th>
    <th>Scope</th>
    <th>Status</th>
    <th>v4 Tib ID</th>
    <th>v4 Tib Name</th>
    <th>v4 Tib Old Oper State Quality</th>
    <th>v4 Tib Oper State Quality</th>
    <th>v4 Tib Oper State</th>
    <th>v4 Tib Pending</th>
    <th>v4 Tib Valid</th>
    <th>v6 Tib ID</th>
    <th>v6 Tib Name</th>
    <th>v6 Tib Old Oper State Quality</th>
    <th>v6 Tib Oper State Quality</th>
    <th>v6 Tib Oper State</th>
    <th>v6 Tib Pending</th>
    <th>v6 Tib Valid</th>
    <th>VPN ID</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.l3Inst.attributes.name }}</td>
    <td>{{ interface.l3Inst.attributes.adminState }}</td>
    <td>{{ interface.l3Inst.attributes.bgpRd }}</td>
    <td>{{ interface.l3Inst.attributes.bgpRdDisp }}</td>
    <td>{{ interface.l3Inst.attributes.childAction }}</td>
    <td>{{ interface.l3Inst.attributes.createTs }}</td>
    <td>{{ interface.l3Inst.attributes.ctxPKey }}</td>
    <td>{{ interface.l3Inst.attributes.dn }}</td>
    <td>{{ interface.l3Inst.attributes.domainId }}</td>
    <td>{{ interface.l3Inst.attributes.encap }}</td>
    <td>{{ interface.l3Inst.attributes.gsdbCtx }}</td>
    <td>{{ interface.l3Inst.attributes.id }}</td>
    <td>{{ interface.l3Inst.attributes.l3vmCfgFailedBmp }}</td>
    <td>{{ interface.l3Inst.attributes.l3vmCfgFailedTs }}</td>
    <td>{{ interface.l3Inst.attributes.l3vmCfgState }}</td>
    <td>{{ interface.l3Inst.attributes.lastChgdTs }}</td>
    <td>{{ interface.l3Inst.attributes.lcOwn }}</td>
    <td>{{ interface.l3Inst.attributes.modTs }}</td>
    <td>{{ interface.l3Inst.attributes.monPolDn }}</td>
    <td>{{ interface.l3Inst.attributes.mplsVPNLabelIndex }}</td>
    <td>{{ interface.l3Inst.attributes.oldOperStQual }}</td>
    <td>{{ interface.l3Inst.attributes.operStQual }}</td>
    <td>{{ interface.l3Inst.attributes.operState }}</td>
    <td>{{ interface.l3Inst.attributes.oui }}</td>
    <td>{{ interface.l3Inst.attributes.pending }}</td>
    <td>{{ interface.l3Inst.attributes.prtclBmp }}</td>
    <td>{{ interface.l3Inst.attributes.resourceId }}</td>
    <td>{{ interface.l3Inst.attributes.scope }}</td>
    <td>{{ interface.l3Inst.attributes.status }}</td>
    <td>{{ interface.l3Inst.attributes.v4TibId }}</td>
    <td>{{ interface.l3Inst.attributes.v4TibName }}</td>
    <td>{{ interface.l3Inst.attributes.v4TibOldOperStQual }}</td>
    <td>{{ interface.l3Inst.attributes.v4TibOperStQual }}</td>
    <td>{{ interface.l3Inst.attributes.v4TibOperState }}</td>
    <td>{{ interface.l3Inst.attributes.v4TibPending }}</td>
    <td>{{ interface.l3Inst.attributes.v4TibValid }}</td>
    <td>{{ interface.l3Inst.attributes.v6TibId }}</td>
    <td>{{ interface.l3Inst.attributes.v6TibName }}</td>
    <td>{{ interface.l3Inst.attributes.v6TibOldOperStQual }}</td>
    <td>{{ interface.l3Inst.attributes.v6TibOperStQual }}</td>
    <td>{{ interface.l3Inst.attributes.v6TibOperState }}</td>
    <td>{{ interface.l3Inst.attributes.v6TibPending }}</td>
    <td>{{ interface.l3Inst.attributes.v6TibValid }}</td>
    <td>{{ interface.l3Inst.attributes.vpnId }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "actrlEntity" in api %}
<h1>Access Control Entities </h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Operational Error</th>
    <th>Operational State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for acl in data_to_template['imdata'] %}
  <tr>
    <td>{{ acl.actrlEntity.attributes.name }}</td>
    <td>{{ acl.actrlEntity.attributes.adminSt }}</td>
    <td>{{ acl.actrlEntity.attributes.childAction }}</td>
    <td>{{ acl.actrlEntity.attributes.dn }}</td>
    <td>{{ acl.actrlEntity.attributes.lcOwn }}</td>
    <td>{{ acl.actrlEntity.attributes.modTs }}</td>
    <td>{{ acl.actrlEntity.attributes.monPolDn }}</td>
    <td>{{ acl.actrlEntity.attributes.operErr }}</td>
    <td>{{ acl.actrlEntity.attributes.operSt }}</td>
    <td>{{ acl.actrlEntity.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "actrlInst" in api %}
<h1>Access Control Instances </h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Acc Control</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Log Clr Interval</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for acl in data_to_template['imdata'] %}
  <tr>
    <td>{{ acl.actrlInst.attributes.name }}</td>
    <td>{{ acl.actrlInst.attributes.accCtrl }}</td>
    <td>{{ acl.actrlInst.attributes.adminSt }}</td>
    <td>{{ acl.actrlInst.attributes.childAction }}</td>
    <td>{{ acl.actrlInst.attributes.ctrl }}</td>
    <td>{{ acl.actrlInst.attributes.dn }}</td>
    <td>{{ acl.actrlInst.attributes.lcOwn }}</td>
    <td>{{ acl.actrlInst.attributes.logClrIntvl }}</td>
    <td>{{ acl.actrlInst.attributes.modTs }}</td>
    <td>{{ acl.actrlInst.attributes.monPolDn }}</td>
    <td>{{ acl.actrlInst.attributes.operErr }}</td>
    <td>{{ acl.actrlInst.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "actrlRule" in api %}
<h1>Access Control Rules </h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Action</th>
    <th>Access Control Config Failed Bmp</th>
    <th>Access Control Config Failed Timestamp</th>
    <th>Access Control Config State</th>
    <th>Child Action</th>
    <th>Contract Name</th>
    <th>Destination PC Tag</th>
    <th>Description</th>
    <th>Direction</th>
    <th>DN</th>
    <th>Filter ID</th>
    <th>ID</th>
    <th>Intent</th>
    <th>Local Owner</th>
    <th>Mark DSCP</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Operational State</th>
    <th>Operational State Quality</th>
    <th>Priority</th>
    <th>QOS Group</th>
    <th>Source PC Tag</th>
    <th>Scope ID</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for acl in data_to_template['imdata'] %}
  <tr>
    <td>{{ acl.actrlRule.attributes.name }}</td>
    <td>{{ acl.actrlRule.attributes.nameAlias }}</td>
    <td>{{ acl.actrlRule.attributes.action }}</td>
    <td>{{ acl.actrlRule.attributes.actrlCfgFailedBmp }}</td>
    <td>{{ acl.actrlRule.attributes.actrlCfgFailedTs }}</td>
    <td>{{ acl.actrlRule.attributes.actrlCfgState }}</td>
    <td>{{ acl.actrlRule.attributes.childAction }}</td>
    <td>{{ acl.actrlRule.attributes.ctrctName }}</td>
    <td>{{ acl.actrlRule.attributes.dPcTag }}</td>
    <td>{{ acl.actrlRule.attributes.descr }}</td>
    <td>{{ acl.actrlRule.attributes.direction }}</td>
    <td>{{ acl.actrlRule.attributes.dn }}</td>
    <td>{{ acl.actrlRule.attributes.fltId }}</td>
    <td>{{ acl.actrlRule.attributes.id }}</td>
    <td>{{ acl.actrlRule.attributes.intent }}</td>
    <td>{{ acl.actrlRule.attributes.lcOwn }}</td>
    <td>{{ acl.actrlRule.attributes.markDscp }}</td>
    <td>{{ acl.actrlRule.attributes.modTs }}</td>
    <td>{{ acl.actrlRule.attributes.monPolDn }}</td>
    <td>{{ acl.actrlRule.attributes.operSt }}</td>
    <td>{{ acl.actrlRule.attributes.operStQual }}</td>
    <td>{{ acl.actrlRule.attributes.prio }}</td>
    <td>{{ acl.actrlRule.attributes.qosGrp }}</td>
    <td>{{ acl.actrlRule.attributes.sPcTag }}</td>
    <td>{{ acl.actrlRule.attributes.scopeId }}</td>
    <td>{{ acl.actrlRule.attributes.status }}</td>
    <td>{{ acl.actrlRule.attributes.type }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "actrlScope" in api %}
<h1>Access Control Scopes </h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Security Label</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for acl in data_to_template['imdata'] %}
  <tr>
    <td>{{ acl.actrlScope.attributes.name }}</td>
    <td>{{ acl.actrlScope.attributes.nameAlias }}</td>
    <td>{{ acl.actrlScope.attributes.childAction }}</td>
    <td>{{ acl.actrlScope.attributes.descr }}</td>
    <td>{{ acl.actrlScope.attributes.dn }}</td>
    <td>{{ acl.actrlScope.attributes.id }}</td>
    <td>{{ acl.actrlScope.attributes.lcOwn }}</td>
    <td>{{ acl.actrlScope.attributes.modTs }}</td>
    <td>{{ acl.actrlScope.attributes.monPolDn }}</td>
    <td>{{ acl.actrlScope.attributes.secLbl }}</td>
    <td>{{ acl.actrlScope.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "cnwPhysIf" in api %}
<h1>Cluster Physical Interfaces </h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Annotation</th>
    <th>Auto Negotiate</th>
    <th>Bandwidth</th>
    <th>Child Action</th>
    <th>Delay</th>
    <th>Description</th>
    <th>Device ID</th>
    <th>DN</th>
    <th>Dot1q Ether Type</th>
    <th>Externally Managed By</th>
    <th>FCOT Channel Number</th>
    <th>ID</th>
    <th>Inherited Bandwidth</th>
    <th>Is Reflective Relay Config Supported</th>
    <th>Layer</th>
    <th>Local Owner</th>
    <th>Link Debounce</th>
    <th>Link Log</th>
    <th>MDIX</th>
    <th>Medium</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>MTU</th>
    <th>Oper State</th>
    <th>Path S Description</th>
    <th>Port T</th>
    <th>Priority Flow Control</th>
    <th>Reflective Relay Enable</th>
    <th>Router MAC</th>
    <th>SNMP Trap State</th>
    <th>Span Mode</th>
    <th>Speed</th>
    <th>Status</th>
    <th>Switching State</th>
    <th>Trunk Log</th>
    <th>UID</th>
    <th>Usage</th>
    <th>User Domain</th>
    <th>Vendor ID</th>
    <th>Wiring Issues</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.cnwPhysIf.attributes.name }}</td>
    <td>{{ interface.cnwPhysIf.attributes.adminSt }}</td>
    <td>{{ interface.cnwPhysIf.attributes.annotation }}</td>
    <td>{{ interface.cnwPhysIf.attributes.autoNeg }}</td>
    <td>{{ interface.cnwPhysIf.attributes.bw }}</td>
    <td>{{ interface.cnwPhysIf.attributes.childAction }}</td>
    <td>{{ interface.cnwPhysIf.attributes.delay }}</td>
    <td>{{ interface.cnwPhysIf.attributes.descr }}</td>
    <td>{{ interface.cnwPhysIf.attributes.deviceId }}</td>
    <td>{{ interface.cnwPhysIf.attributes.dn }}</td>
    <td>{{ interface.cnwPhysIf.attributes.dot1qEtherType }}</td>
    <td>{{ interface.cnwPhysIf.attributes.extMngdBy }}</td>
    <td>{{ interface.cnwPhysIf.attributes.fcotChannelNumber }}</td>
    <td>{{ interface.cnwPhysIf.attributes.id }}</td>
    <td>{{ interface.cnwPhysIf.attributes.inhBw }}</td>
    <td>{{ interface.cnwPhysIf.attributes.isReflectiveRelayCfgSupported }}</td>
    <td>{{ interface.cnwPhysIf.attributes.layer }}</td>
    <td>{{ interface.cnwPhysIf.attributes.lcOwn }}</td>
    <td>{{ interface.cnwPhysIf.attributes.linkDebounce }}</td>
    <td>{{ interface.cnwPhysIf.attributes.linkLog }}</td>
    <td>{{ interface.cnwPhysIf.attributes.mdix }}</td>
    <td>{{ interface.cnwPhysIf.attributes.medium }}</td>
    <td>{{ interface.cnwPhysIf.attributes.modTs }}</td>
    <td>{{ interface.cnwPhysIf.attributes.mode }}</td>
    <td>{{ interface.cnwPhysIf.attributes.monPolDn }}</td>
    <td>{{ interface.cnwPhysIf.attributes.mtu }}</td>
    <td>{{ interface.cnwPhysIf.attributes.operSt }}</td>
    <td>{{ interface.cnwPhysIf.attributes.pathSDescr }}</td>
    <td>{{ interface.cnwPhysIf.attributes.portT }}</td>
    <td>{{ interface.cnwPhysIf.attributes.prioFlowCtrl }}</td>
    <td>{{ interface.cnwPhysIf.attributes.reflectiveRelayEn }}</td>
    <td>{{ interface.cnwPhysIf.attributes.routerMac }}</td>
    <td>{{ interface.cnwPhysIf.attributes.snmpTrapSt }}</td>
    <td>{{ interface.cnwPhysIf.attributes.spanMode }}</td>
    <td>{{ interface.cnwPhysIf.attributes.speed }}</td>
    <td>{{ interface.cnwPhysIf.attributes.status }}</td>
    <td>{{ interface.cnwPhysIf.attributes.switchingSt }}</td>
    <td>{{ interface.cnwPhysIf.attributes.trunkLog }}</td>
    <td>{{ interface.cnwPhysIf.attributes.uid }}</td>
    <td>{{ interface.cnwPhysIf.attributes.usage }}</td>
    <td>{{ interface.cnwPhysIf.attributes.userdom }}</td>
    <td>{{ interface.cnwPhysIf.attributes.vendorId }}</td>
    <td>{{ interface.cnwPhysIf.attributes.wiringIssues }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "compCtrlr" in api %}
<h1>Compute Controllers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Access Mode</th>
    <th>API Version</th>
    <th>AVE Switching Active</th>
    <th>AVE Time Out</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Control Knob</th>
    <th>Control rP Key</th>
    <th>Deploy Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Domain Name</th>
    <th>DVS Version</th>
    <th>Enable AVE</th>
    <th>Enable Tag</th>
    <th>Enable VM Folder</th>
    <th>EP Ret Time</th>
    <th>Host Or IP</th>
    <th>ID</th>
    <th>Inventory Start Timestamp</th>
    <th>Inventory Trigger State</th>
    <th>Issues</th>
    <th>Key</th>
    <th>Lag Policy Name</th>
    <th>Last Event Collector ID</th>
    <th>Last Event ID</th>
    <th>Last Event Timestamp</th>
    <th>Last Inventory State</th>
    <th>Last Inventory Timestamp</th>
    <th>Local Owner</th>
    <th>Max Worker Q Size</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Port</th>
    <th>Remote Error Message</th>
    <th>Remote Oper Issues</th>
    <th>Rev</th>
    <th>Root Cont Name</th>
    <th>Scope</th>
    <th>Ser</th>
    <th>Set Deploy Issues</th>
    <th>Set Remote Oper Issues</th>
    <th>Status</th>
    <th>Unset Deploy Issues</th>
    <th>Unset Remote Oper Issues</th>
    <th>User</th>
    <th>Vendor</th>
    <th>vSphere PHA</th>
    <th>vSphere Tag</th>
    <th>VXLAN Deploy Preferred</th>
  </tr>
</thead>
<tbody>
{%-     for controller in data_to_template['imdata'] %}
  <tr>
    <td>{{ controller.compCtrlr.attributes.name }}</td>
    <td>{{ controller.compCtrlr.attributes.nameAlias }}</td>
    <td>{{ controller.compCtrlr.attributes.accessMode }}</td>
    <td>{{ controller.compCtrlr.attributes.apiVer }}</td>
    <td>{{ controller.compCtrlr.attributes.aveSwitchingActive }}</td>
    <td>{{ controller.compCtrlr.attributes.aveTimeOut }}</td>
    <td>{{ controller.compCtrlr.attributes.childAction }}</td>
    <td>{{ controller.compCtrlr.attributes.cimcVersion }}</td>
    <td>{{ controller.compCtrlr.attributes.ctrlKnob }}</td>
    <td>{{ controller.compCtrlr.attributes.ctrlrPKey }}</td>
    <td>{{ controller.compCtrlr.attributes.deployIssues }}</td>
    <td>{{ controller.compCtrlr.attributes.descr }}</td>
    <td>{{ controller.compCtrlr.attributes.dn }}</td>
    <td>{{ controller.compCtrlr.attributes.domName }}</td>
    <td>{{ controller.compCtrlr.attributes.dvsVersion }}</td>
    <td>{{ controller.compCtrlr.attributes.enableAVE }}</td>
    <td>{{ controller.compCtrlr.attributes.enableTag }}</td>
    <td>{{ controller.compCtrlr.attributes.enableVmFolder }}</td>
    <td>{{ controller.compCtrlr.attributes.epRetTime }}</td>
    <td>{{ controller.compCtrlr.attributes.hostOrIp }}</td>
    <td>{{ controller.compCtrlr.attributes.id }}</td>
    <td>{{ controller.compCtrlr.attributes.inventoryStartTS }}</td>
    <td>{{ controller.compCtrlr.attributes.inventoryTrigSt }}</td>
    <td>{{ controller.compCtrlr.attributes.issues }}</td>
    <td>{{ controller.compCtrlr.attributes.key }}</td>
    <td>{{ controller.compCtrlr.attributes.lagPolicyName }}</td>
    <td>{{ controller.compCtrlr.attributes.lastEventCollectorId }}</td>
    <td>{{ controller.compCtrlr.attributes.lastEventId }}</td>
    <td>{{ controller.compCtrlr.attributes.lastEventTS }}</td>
    <td>{{ controller.compCtrlr.attributes.lastInventorySt }}</td>
    <td>{{ controller.compCtrlr.attributes.lastInventoryTS }}</td>
    <td>{{ controller.compCtrlr.attributes.lcOwn }}</td>
    <td>{{ controller.compCtrlr.attributes.maxWorkerQSize }}</td>
    <td>{{ controller.compCtrlr.attributes.modTs }}</td>
    <td>{{ controller.compCtrlr.attributes.mode }}</td>
    <td>{{ controller.compCtrlr.attributes.model }}</td>
    <td>{{ controller.compCtrlr.attributes.monPolDn }}</td>
    <td>{{ controller.compCtrlr.attributes.operSt }}</td>
    <td>{{ controller.compCtrlr.attributes.port }}</td>
    <td>{{ controller.compCtrlr.attributes.remoteErrMsg }}</td>
    <td>{{ controller.compCtrlr.attributes.remoteOperIssues }}</td>
    <td>{{ controller.compCtrlr.attributes.rev }}</td>
    <td>{{ controller.compCtrlr.attributes.rootContName }}</td>
    <td>{{ controller.compCtrlr.attributes.scope }}</td>
    <td>{{ controller.compCtrlr.attributes.ser }}</td>
    <td>{{ controller.compCtrlr.attributes.setDeployIssues }}</td>
    <td>{{ controller.compCtrlr.attributes.setRemoteOperIssues }}</td>
    <td>{{ controller.compCtrlr.attributes.status }}</td>
    <td>{{ controller.compCtrlr.attributes.unsetDeployIssues }}</td>
    <td>{{ controller.compCtrlr.attributes.unsetRemoteOperIssues }}</td>
    <td>{{ controller.compCtrlr.attributes.usr }}</td>
    <td>{{ controller.compCtrlr.attributes.vendor }}</td>
    <td>{{ controller.compCtrlr.attributes.vspherePHA }}</td>
    <td>{{ controller.compCtrlr.attributes.vsphereTag }}</td>
    <td>{{ controller.compCtrlr.attributes.vxlanDeplPref }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "compDom" in api %}
<h1>Compute Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Enable AVE</th>
    <th>ID</th>
    <th>Issues</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.compDom.attributes.name }}</td>
    <td>{{ domain.compDom.attributes.nameAlias }}</td>
    <td>{{ domain.compDom.attributes.childAction }}</td>
    <td>{{ domain.compDom.attributes.descr }}</td>
    <td>{{ domain.compDom.attributes.dn }}</td>
    <td>{{ domain.compDom.attributes.enableAVE }}</td>
    <td>{{ domain.compDom.attributes.id }}</td>
    <td>{{ domain.compDom.attributes.issues }}</td>
    <td>{{ domain.compDom.attributes.lcOwn }}</td>
    <td>{{ domain.compDom.attributes.modTs }}</td>
    <td>{{ domain.compDom.attributes.mode }}</td>
    <td>{{ domain.compDom.attributes.monPolDn }}</td>
    <td>{{ domain.compDom.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "compEpPD" in api %}
<h1>Compute Endpoint Policy Description</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Allocation Mode</th>
    <th>Bridge Domain DN</th>
    <th>Binding Type</th>
    <th>Block All Ports</th>
    <th>Configured Delimiter</th>
    <th>Child Action</th>
    <th>Class Preference</th>
    <th>Configuration Flags</th>
    <th>Controller Enabled</th>
    <th>Context DN</th>
    <th>Custom EPG Name</th>
    <th>Deployment Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>Encapsulation Allocated Key</th>
    <th>Encapsulation Changed</th>
    <th>Encapsulation Context</th>
    <th>Encapsulation Mode</th>
    <th>Encapsulation Mode Override</th>
    <th>EPG COS</th>
    <th>EPG COS Preference</th>
    <th>EPG P Key</th>
    <th>EPP DN</th>
    <th>Fault D Key</th>
    <th>Forged Transmit</th>
    <th>ID</th>
    <th>ID Consumer DN</th>
    <th>Inherited</th>
    <th>Instr Immediacy</th>
    <th>Intra Sec Conf</th>
    <th>Issues</th>
    <th>Lag Policy Name</th>
    <th>Load Balance Algorithm</th>
    <th>Local Owner</th>
    <th>MAC Change</th>
    <th>Multicast Address</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Netflow Direction</th>
    <th>Netflow Preferred</th>
    <th>Number Ports</th>
    <th>Oper Delimiter</th>
    <th>Oper Flags</th>
    <th>PC Enforced Preference</th>
    <th>Port Allocation</th>
    <th>Primary Encapsulation</th>
    <th>Primary Encapsulation Inner</th>
    <th>Prom Mode</th>
    <th>Remote Error Message</th>
    <th>Remote Oper Issues</th>
    <th>Res Immediacy</th>
    <th>Secondary Encapsulation Inner</th>
    <th>Stats Collection State</th>
    <th>Status</th>
    <th>Switching Mode</th>
    <th>TX ID</th>
    <th>Type</th>
    <th>Untagged</th>
    <th>Update Timestamp</th>
    <th>VNET Only</th>
    <th>VXVLAN Deploy Preference</th>
  </tr>
</thead>
<tbody>
{%-     for policy in data_to_template['imdata'] %}
  <tr>
    <td>{{ policy.compEpPD.attributes.name }}</td>
    <td>{{ policy.compEpPD.attributes.nameAlias }}</td>
    <td>{{ policy.compEpPD.attributes.allocMode }}</td>
    <td>{{ policy.compEpPD.attributes.bdDn }}</td>
    <td>{{ policy.compEpPD.attributes.bindingType }}</td>
    <td>{{ policy.compEpPD.attributes.blockAllPorts }}</td>
    <td>{{ policy.compEpPD.attributes.cfgdDelimiter }}</td>
    <td>{{ policy.compEpPD.attributes.childAction }}</td>
    <td>{{ policy.compEpPD.attributes.classPref }}</td>
    <td>{{ policy.compEpPD.attributes.configFlags }}</td>
    <td>{{ policy.compEpPD.attributes.crtrnEnabled }}</td>
    <td>{{ policy.compEpPD.attributes.ctxDn }}</td>
    <td>{{ policy.compEpPD.attributes.customEpgName }}</td>
    <td>{{ policy.compEpPD.attributes.deployIssues }}</td>
    <td>{{ policy.compEpPD.attributes.descr }}</td>
    <td>{{ policy.compEpPD.attributes.dn }}</td>
    <td>{{ policy.compEpPD.attributes.encap }}</td>
    <td>{{ policy.compEpPD.attributes.encapAllocKey }}</td>
    <td>{{ policy.compEpPD.attributes.encapChanged }}</td>
    <td>{{ policy.compEpPD.attributes.encapCtx }}</td>
    <td>{{ policy.compEpPD.attributes.encapMode }}</td>
    <td>{{ policy.compEpPD.attributes.encapModeOverride }}</td>
    <td>{{ policy.compEpPD.attributes.epgCos }}</td>
    <td>{{ policy.compEpPD.attributes.epgCosPref }}</td>
    <td>{{ policy.compEpPD.attributes.epgPKey }}</td>
    <td>{{ policy.compEpPD.attributes.eppDn }}</td>
    <td>{{ policy.compEpPD.attributes.faultDKey }}</td>
    <td>{{ policy.compEpPD.attributes.forgedTransmit }}</td>
    <td>{{ policy.compEpPD.attributes.id }}</td>
    <td>{{ policy.compEpPD.attributes.idConsumerDn }}</td>
    <td>{{ policy.compEpPD.attributes.inherited }}</td>
    <td>{{ policy.compEpPD.attributes.instrImedcy }}</td>
    <td>{{ policy.compEpPD.attributes.intraSecConf }}</td>
    <td>{{ policy.compEpPD.attributes.issues }}</td>
    <td>{{ policy.compEpPD.attributes.lagPolicyName }}</td>
    <td>{{ policy.compEpPD.attributes.lbAlgo }}</td>
    <td>{{ policy.compEpPD.attributes.lcOwn }}</td>
    <td>{{ policy.compEpPD.attributes.macChange }}</td>
    <td>{{ policy.compEpPD.attributes.mcastAddr }}</td>
    <td>{{ policy.compEpPD.attributes.modTs }}</td>
    <td>{{ policy.compEpPD.attributes.monPolDn }}</td>
    <td>{{ policy.compEpPD.attributes.netflowDir }}</td>
    <td>{{ policy.compEpPD.attributes.netflowPref }}</td>
    <td>{{ policy.compEpPD.attributes.numPorts }}</td>
    <td>{{ policy.compEpPD.attributes.operDelimiter }}</td>
    <td>{{ policy.compEpPD.attributes.operFlags }}</td>
    <td>{{ policy.compEpPD.attributes.pcEnfPref }}</td>
    <td>{{ policy.compEpPD.attributes.portAllocation }}</td>
    <td>{{ policy.compEpPD.attributes.primaryEncap }}</td>
    <td>{{ policy.compEpPD.attributes.primaryEncapInner }}</td>
    <td>{{ policy.compEpPD.attributes.promMode }}</td>
    <td>{{ policy.compEpPD.attributes.remoteErrMsg }}</td>
    <td>{{ policy.compEpPD.attributes.remoteOperIssues }}</td>
    <td>{{ policy.compEpPD.attributes.resImedcy }}</td>
    <td>{{ policy.compEpPD.attributes.secondaryEncapInner }}</td>
    <td>{{ policy.compEpPD.attributes.statsCollectionState }}</td>
    <td>{{ policy.compEpPD.attributes.status }}</td>
    <td>{{ policy.compEpPD.attributes.switchingMode }}</td>
    <td>{{ policy.compEpPD.attributes.txId }}</td>
    <td>{{ policy.compEpPD.attributes.type }}</td>
    <td>{{ policy.compEpPD.attributes.untagged }}</td>
    <td>{{ policy.compEpPD.attributes.updateTs }}</td>
    <td>{{ policy.compEpPD.attributes.vnetOnly }}</td>
    <td>{{ policy.compEpPD.attributes.vxlanDeplPref }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "compProv" in api %}
<h1>Compute Providers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>ID</th>
    <th>Issues</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for provider in data_to_template['imdata'] %}
  <tr>
    <td>{{ provider.compProv.attributes.name }}</td>
    <td>{{ provider.compProv.attributes.nameAlias }}</td>
    <td>{{ provider.compProv.attributes.childAction }}</td>
    <td>{{ provider.compProv.attributes.descr }}</td>
    <td>{{ provider.compProv.attributes.dn }}</td>
    <td>{{ provider.compProv.attributes.id }}</td>
    <td>{{ provider.compProv.attributes.issues }}</td>
    <td>{{ provider.compProv.attributes.lcOwn }}</td>
    <td>{{ provider.compProv.attributes.modTs }}</td>
    <td>{{ provider.compProv.attributes.monPolDn }}</td>
    <td>{{ provider.compProv.attributes.status }}</td>
    <td>{{ provider.compProv.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "arpAdjEp" in api %}
<h1>ARP Adjacency Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Interface ID</th>
    <th>IP</th>
    <th>MAC</th>
    <th>Last Modified</th>
    <th>Operational State</th>
    <th>Physical Interface ID</th>
    <th>Status</th>
    <th>Last Updated</th>
  </tr>
</thead>
<tbody>
{%-     for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.arpAdjEp.attributes.name }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.childAction }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.dn }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.ifId }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.ip }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.mac }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.modTs }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.operSt }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.physIfId }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.status }}</td>
    <td>{{ endpoint.arpAdjEp.attributes.upTS }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "arpDb" in api %}
<h1>ARP Database</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Last Modified</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for entry in data_to_template['imdata'] %}
  <tr>
    <td>{{ entry.arpDb.attributes.name }}</td>
    <td>{{ entry.arpDb.attributes.childAction }}</td>
    <td>{{ entry.arpDb.attributes.dn }}</td>
    <td>{{ entry.arpDb.attributes.modTs }}</td>
    <td>{{ entry.arpDb.attributes.status }}</td>
    <td>{{ entry.arpDb.attributes.type }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "arpDom" in api %}
<h1>ARP Domain</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.arpDom.attributes.name }}</td>
    <td>{{ domain.arpDom.attributes.childAction }}</td>
    <td>{{ domain.arpDom.attributes.dn }}</td>
    <td>{{ domain.arpDom.attributes.encap }}</td>
    <td>{{ domain.arpDom.attributes.lcOwn }}</td>
    <td>{{ domain.arpDom.attributes.modTs }}</td>
    <td>{{ domain.arpDom.attributes.monPolDn }}</td>
    <td>{{ domain.arpDom.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "arpEntity" in api %}
<h1>ARP Entity</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Operational Error</th>
    <th>Operational State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for entity in data_to_template['imdata'] %}
  <tr>
    <td>{{ entity.arpEntity.attributes.name }}</td>
    <td>{{ entity.arpEntity.attributes.adminSt }}</td>
    <td>{{ entity.arpEntity.attributes.childAction }}</td>
    <td>{{ entity.arpEntity.attributes.dn }}</td>
    <td>{{ entity.arpEntity.attributes.lcOwn }}</td>
    <td>{{ entity.arpEntity.attributes.modTs }}</td>
    <td>{{ entity.arpEntity.attributes.monPolDn }}</td>
    <td>{{ entity.arpEntity.attributes.operErr }}</td>
    <td>{{ entity.arpEntity.attributes.operSt }}</td>
    <td>{{ entity.arpEntity.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "arpIf" in api %}
<h1>ARP Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>Description</th>
    <th>DN</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.arpIf.attributes.name }}</td>
    <td>{{ interface.arpIf.attributes.adminSt }}</td>
    <td>{{ interface.arpIf.attributes.childAction }}</td>
    <td>{{ interface.arpIf.attributes.ctrl }}</td>
    <td>{{ interface.arpIf.attributes.descr }}</td>
    <td>{{ interface.arpIf.attributes.dn }}</td>
    <td>{{ interface.arpIf.attributes.id }}</td>
    <td>{{ interface.arpIf.attributes.lcOwn }}</td>
    <td>{{ interface.arpIf.attributes.modTs }}</td>
    <td>{{ interface.arpIf.attributes.monPolDn }}</td>
    <td>{{ interface.arpIf.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "arpInst" in api %}
<h1>ARP Instances</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Err</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for instance in data_to_template['imdata'] %}
  <tr>
    <td>{{ instance.arpInst.attributes.name }}</td>
    <td>{{ instance.arpInst.attributes.adminSt }}</td>
    <td>{{ instance.arpInst.attributes.childAction }}</td>
    <td>{{ instance.arpInst.attributes.ctrl }}</td>
    <td>{{ instance.arpInst.attributes.dn }}</td>
    <td>{{ instance.arpInst.attributes.lcOwn }}</td>
    <td>{{ instance.arpInst.attributes.modTs }}</td>
    <td>{{ instance.arpInst.attributes.monPolDn }}</td>
    <td>{{ instance.arpInst.attributes.operErr }}</td>
    <td>{{ instance.arpInst.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "bgpDom" in api %}
{%-     if "Af" in api%}
<h1>BGP Domain Address Families</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Best Path Complete Timestamp</th>
    <th>Best Path Signature Timestamp</th>
    <th>Child Action</th>
    <th>Crit Nh Timeout</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Max ECMP</th>
    <th>Max ECMP IBGP</th>
    <th>Last Modified</th>
    <th>Non Crit Nh Timeout</th>
    <th>Status</th>
    <th>Table Version</th>
    <th>Type</th>
  </tr>
{%-          for family in data_to_template['imdata'] %}
  <tr>
    <td>{{ family.bgpDomAf.attributes.name }}</td>
    <td>{{ family.bgpDomAf.attributes.bestPathCmpltTs }}</td>
    <td>{{ family.bgpDomAf.attributes.bestPathSigTs }}</td>
    <td>{{ family.bgpDomAf.attributes.childAction }}</td>
    <td>{{ family.bgpDomAf.attributes.critNhTimeout }}</td>
    <td>{{ family.bgpDomAf.attributes.dn }}</td>
    <td>{{ family.bgpDomAf.attributes.lcOwn }}</td>
    <td>{{ family.bgpDomAf.attributes.maxEcmp }}</td>
    <td>{{ family.bgpDomAf.attributes.maxEcmpIbgp }}</td>
    <td>{{ family.bgpDomAf.attributes.modTs }}</td>
    <td>{{ family.bgpDomAf.attributes.nonCritNhTimeout }}</td>
    <td>{{ family.bgpDomAf.attributes.status }}</td>
    <td>{{ family.bgpDomAf.attributes.tblVer }}</td>
    <td>{{ family.bgpDomAf.attributes.type }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%-     else %}
<h1>BGP Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>BGP Configuration Failed Bmp</th>
    <th>BGP Configuration Failed Timestamp</th>
    <th>BGP Configuration State</th>
    <th>Child Action</th>
    <th>Cluster ID</th>
    <th>Control</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>First Best Path Delay</th>
    <th>First Peer Uptime Timestamp</th>
    <th>Flags</th>
    <th>Hold Interval</th>
    <th>ka Interval</th>
    <th>Local Owner</th>
    <th>Max AS Limit</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>MSite Cluster ID</th>
    <th>Number of Established Peers</th>
    <th>Number of Peers</th>
    <th>Oper Router ID</th>
    <th>Oper State</th>
    <th>RD</th>
    <th>Router ID</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-         for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.bgpDom.attributes.name }}</td>
    <td>{{ domain.bgpDom.attributes.bgpCfgFailedBmp }}</td>
    <td>{{ domain.bgpDom.attributes.bgpCfgFailedTs }}</td>
    <td>{{ domain.bgpDom.attributes.bgpCfgState }}</td>
    <td>{{ domain.bgpDom.attributes.childAction }}</td>
    <td>{{ domain.bgpDom.attributes.clusterId }}</td>
    <td>{{ domain.bgpDom.attributes.ctrl }}</td>
    <td>{{ domain.bgpDom.attributes.dn }}</td>
    <td>{{ domain.bgpDom.attributes.encap }}</td>
    <td>{{ domain.bgpDom.attributes.firstBestPathDelay }}</td>
    <td>{{ domain.bgpDom.attributes.firstPeerUpTs }}</td>
    <td>{{ domain.bgpDom.attributes.flags }}</td>
    <td>{{ domain.bgpDom.attributes.holdIntvl }}</td>
    <td>{{ domain.bgpDom.attributes.kaIntvl }}</td>
    <td>{{ domain.bgpDom.attributes.lcOwn }}</td>
    <td>{{ domain.bgpDom.attributes.maxAsLimit }}</td>
    <td>{{ domain.bgpDom.attributes.modTs }}</td>
    <td>{{ domain.bgpDom.attributes.mode }}</td>
    <td>{{ domain.bgpDom.attributes.monPolDn }}</td>
    <td>{{ domain.bgpDom.attributes.msiteClusterId }}</td>
    <td>{{ domain.bgpDom.attributes.numEstPeers }}</td>
    <td>{{ domain.bgpDom.attributes.numPeers }}</td>
    <td>{{ domain.bgpDom.attributes.operRtrId }}</td>
    <td>{{ domain.bgpDom.attributes.operSt }}</td>
    <td>{{ domain.bgpDom.attributes.rd }}</td>
    <td>{{ domain.bgpDom.attributes.rtrId }}</td>
    <td>{{ domain.bgpDom.attributes.status }}</td>
    <td>{{ domain.bgpDom.attributes.type }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "bgpEntity" in api %}
<h1>BGP Entities</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Oper State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for entity in data_to_template['imdata'] %}
  <tr>
    <td>{{ entity.bgpEntity.attributes.name }}</td>
    <td>{{ entity.bgpEntity.attributes.adminSt }}</td>
    <td>{{ entity.bgpEntity.attributes.childAction }}</td>
    <td>{{ entity.bgpEntity.attributes.dn }}</td>
    <td>{{ entity.bgpEntity.attributes.lcOwn }}</td>
    <td>{{ entity.bgpEntity.attributes.modTs }}</td>
    <td>{{ entity.bgpEntity.attributes.monPolDn }}</td>
    <td>{{ entity.bgpEntity.attributes.operErr }}</td>
    <td>{{ entity.bgpEntity.attributes.operSt }}</td>
    <td>{{ entity.bgpEntity.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "bgpInst" in api %}
{%-     if "InstPol" in api %}
<h1>BGP Instances Policy</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-         for policy in data_to_template['imdata'] %}
  <tr>
    <td>{{ policy.bgpInstPol.attributes.name }}</td>
    <td>{{ policy.bgpInstPol.attributes.nameAlias }}</td>
    <td>{{ policy.bgpInstPol.attributes.annotation }}</td>
    <td>{{ policy.bgpInstPol.attributes.childAction }}</td>
    <td>{{ policy.bgpInstPol.attributes.descr }}</td>
    <td>{{ policy.bgpInstPol.attributes.dn }}</td>
    <td>{{ policy.bgpInstPol.attributes.extMngdBy }}</td>
    <td>{{ policy.bgpInstPol.attributes.lcOwn }}</td>
    <td>{{ policy.bgpInstPol.attributes.modTs }}</td>
    <td>{{ policy.bgpInstPol.attributes.monPolDn }}</td>
    <td>{{ policy.bgpInstPol.attributes.ownerKey }}</td>
    <td>{{ policy.bgpInstPol.attributes.ownerTag }}</td>
    <td>{{ policy.bgpInstPol.attributes.status }}</td>
    <td>{{ policy.bgpInstPol.attributes.uid }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>BGP Instances</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Activated Timestamp</th>
    <th>Admin State</th>
    <th>AS Path DB Size</th>
    <th>ASN</th>
    <th>Attribute DB Size</th>
    <th>Child Action</th>
    <th>Created Timestamp</th>
    <th>Control</th>
    <th>DN</th>
    <th>Fabric SoO</th>
    <th>Local Owner</th>
    <th>mSite SoO</th>
    <th>Memory Alert</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Number AS Path</th>
    <th>Number RT Attributes</th>
    <th>Oper Error</th>
    <th>Pod SoO</th>
    <th>SNMP Trap State</th>
    <th>Spine Role</th>
    <th>Status</th>
    <th>Suppr RT</th>
    <th>Syslog Level</th>
    <th>Version</th>
    <th>Wait Done Timestamp</th>
  </tr>
</thead>
<tbody>
{%-         for instance in data_to_template['imdata'] %}
  <tr>
    <td>{{ instance.bgpInst.attributes.name }}</td>
    <td>{{ instance.bgpInst.attributes.activateTs }}</td>
    <td>{{ instance.bgpInst.attributes.adminSt }}</td>
    <td>{{ instance.bgpInst.attributes.asPathDbSz }}</td>
    <td>{{ instance.bgpInst.attributes.asn }}</td>
    <td>{{ instance.bgpInst.attributes.attribDbSz }}</td>
    <td>{{ instance.bgpInst.attributes.childAction }}</td>
    <td>{{ instance.bgpInst.attributes.createTs }}</td>
    <td>{{ instance.bgpInst.attributes.ctrl }}</td>
    <td>{{ instance.bgpInst.attributes.dn }}</td>
    <td>{{ instance.bgpInst.attributes.fabricSoO }}</td>
    <td>{{ instance.bgpInst.attributes.lcOwn }}</td>
    <td>{{ instance.bgpInst.attributes.mSiteSoO }}</td>
    <td>{{ instance.bgpInst.attributes.memAlert }}</td>
    <td>{{ instance.bgpInst.attributes.modTs }}</td>
    <td>{{ instance.bgpInst.attributes.monPolDn }}</td>
    <td>{{ instance.bgpInst.attributes.numAsPath }}</td>
    <td>{{ instance.bgpInst.attributes.numRtAttrib }}</td>
    <td>{{ instance.bgpInst.attributes.operErr }}</td>
    <td>{{ instance.bgpInst.attributes.podSoO }}</td>
    <td>{{ instance.bgpInst.attributes.snmpTrapSt }}</td>
    <td>{{ instance.bgpInst.attributes.spineRole }}</td>
    <td>{{ instance.bgpInst.attributes.status }}</td>
    <td>{{ instance.bgpInst.attributes.supprRt }}</td>
    <td>{{ instance.bgpInst.attributes.syslogLvl }}</td>
    <td>{{ instance.bgpInst.attributes.ver }}</td>
    <td>{{ instance.bgpInst.attributes.waitDoneTs }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "bgpPeer" in api %}
{%-     if "bgpPeerAf" in api %}
<h1>BGP Peer AF Entries</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Accepted Paths</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>First Eor Received Timestamp</th>
    <th>Flags</th>
    <th>Last Eor Received Timestamp</th>
    <th>Memory Acc Paths</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Peer Table Version</th>
    <th>Prefix Flushed</th>
    <th>Prefix Saved</th>
    <th>Prefix Sent</th>
    <th>Status</th>
    <th>Table State</th>
    <th>Table Version</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-         for af in data_to_template['imdata'] %}
  <tr>
    <td>{{ af.bgpPeerAfEntry.attributes.name }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.acceptedPaths }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.childAction }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.dn }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.firstEorRcvdTs }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.flags }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.lastEorRcvdTs }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.memAccPaths }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.modTs }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.monPolDn }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.peerTblVer }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.pfxFlushed }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.pfxSaved }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.pfxSent }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.status }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.tblSt }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.tblVer }}</td>
    <td>{{ af.bgpPeerAfEntry.attributes.type }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
{%-         if "bgpPeerEntry" in api %}
<h1>BGP Peer Entries</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Address</th>
    <th>Advertised Capabilites</th>
    <th>Child Action</th>
    <th>Connection Attempts</th>
    <th>Connection Drop</th>
    <th>Connection Established</th>
    <th>Connection Interface</th>
    <th>DN</th>
    <th>FD</th>
    <th>Flags</th>
    <th>Hold Interval</th>
    <th>ka Interval</th>
    <th>Last Flap Timestamp</th>
    <th>Local IP</th>
    <th>Local Port</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Password Set</th>
    <th>Peer Index</th>
    <th>Previous Oper State</th>
    <th>Received Capabilites</th>
    <th>Remote Port</th>
    <th>Router ID</th>
    <th>Shut State Quality</th>
    <th>State Reason</th>
    <th>Status</th>
    <th>Type</th>
    <th>Update Elapsed Timestamp</th>
  </tr>
</thead>
<tbody>
{%-             for entry in data_to_template['imdata'] %}
  <tr>
    <td>{{ entry.bgpPeerEntry.attributes.name }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.addr }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.advCap }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.childAction }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.connAttempts }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.connDrop }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.connEst }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.connIf }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.dn }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.fd }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.flags }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.holdIntvl }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.kaIntvl }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.lastFlapTs }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.localIp }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.localPort }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.modTs }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.monPolDn }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.operSt }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.passwdSet }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.peerIdx }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.prevOperSt }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.rcvCap }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.remotePort }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.rtrId }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.shutStQual }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.stReason }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.status }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.type }}</td>
    <td>{{ entry.bgpPeerEntry.attributes.updateElapsedTs }}</td>
  </tr>
{%-             endfor %}
</tbody>
</table>
{%-         else %}
<h1>BGP Peers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Active Prefix Peers</th>
    <th>Address</th>
    <th>Admin State</th>
    <th>ASN</th>
    <th>BGP Config Failed Bmp</th>
    <th>BGP Config Failed Timestamp</th>
    <th>BGP Config State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>Current Prefix Peers</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Maximum Current Peers</th>
    <th>Maximum Prefix Peers</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Password Set</th>
    <th>Peer Role</th>
    <th>Private AS Control</th>
    <th>Source Interface</th>
    <th>Status</th>
    <th>Total Prefix Peers</th>
    <th>TTL</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-             for peer in data_to_template['imdata'] %}
  <tr>
    <td>{{ peer.bgpPeer.attributes.name }}</td>
    <td>{{ peer.bgpPeer.attributes.activePfxPeers }}</td>
    <td>{{ peer.bgpPeer.attributes.addr }}</td>
    <td>{{ peer.bgpPeer.attributes.adminSt }}</td>
    <td>{{ peer.bgpPeer.attributes.asn }}</td>
    <td>{{ peer.bgpPeer.attributes.bgpCfgFailedBmp }}</td>
    <td>{{ peer.bgpPeer.attributes.bgpCfgFailedTs }}</td>
    <td>{{ peer.bgpPeer.attributes.bgpCfgState }}</td>
    <td>{{ peer.bgpPeer.attributes.childAction }}</td>
    <td>{{ peer.bgpPeer.attributes.ctrl }}</td>
    <td>{{ peer.bgpPeer.attributes.curPfxPeers }}</td>
    <td>{{ peer.bgpPeer.attributes.dn }}</td>
    <td>{{ peer.bgpPeer.attributes.lcOwn }}</td>
    <td>{{ peer.bgpPeer.attributes.maxCurPeers }}</td>
    <td>{{ peer.bgpPeer.attributes.maxPfxPeers }}</td>
    <td>{{ peer.bgpPeer.attributes.modTs }}</td>
    <td>{{ peer.bgpPeer.attributes.monPolDn }}</td>
    <td>{{ peer.bgpPeer.attributes.passwdSet }}</td>
    <td>{{ peer.bgpPeer.attributes.peerRole }}</td>
    <td>{{ peer.bgpPeer.attributes.privateASctrl }}</td>
    <td>{{ peer.bgpPeer.attributes.srcIf }}</td>
    <td>{{ peer.bgpPeer.attributes.status }}</td>
    <td>{{ peer.bgpPeer.attributes.totalPfxPeers }}</td>
    <td>{{ peer.bgpPeer.attributes.ttl }}</td>
    <td>{{ peer.bgpPeer.attributes.type }}</td>
  </tr>
{%-             endfor %}
</tbody>
</table>
{%-         endif %}
{%-     endif %}
{%- elif "bgpRRP" in api %}
<h1>BGP Route Reflector Policies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for policy in data_to_template['imdata'] %}
  <tr>
    <td>{{ policy.bgpRRP.attributes.name }}</td>
    <td>{{ policy.bgpRRP.attributes.nameAlias }}</td>
    <td>{{ policy.bgpRRP.attributes.annotation }}</td>
    <td>{{ policy.bgpRRP.attributes.childAction }}</td>
    <td>{{ policy.bgpRRP.attributes.descr }}</td>
    <td>{{ policy.bgpRRP.attributes.dn }}</td>
    <td>{{ policy.bgpRRP.attributes.extMngdBy }}</td>
    <td>{{ policy.bgpRRP.attributes.lcOwn }}</td>
    <td>{{ policy.bgpRRP.attributes.modTs }}</td>
    <td>{{ policy.bgpRRP.attributes.monPolDn }}</td>
    <td>{{ policy.bgpRRP.attributes.status }}</td>
    <td>{{ policy.bgpRRP.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "cdpAdjEp" in api %}
<h1>CDP Adjacency Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Capabilites</th>
    <th>Child Action</th>
    <th>Device ID</th>
    <th>DN</th>
    <th>Duplex</th>
    <th>Index</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>MTU</th>
    <th>Native VLAN</th>
    <th>Platform ID</th>
    <th>Port ID</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>System Location</th>
    <th>System Name</th>
    <th>System Object ID L</th>
    <th>System Object ID V</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>
{%-     for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.cdpAdjEp.attributes.name }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.cap }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.childAction }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.devId }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.dn }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.duplex }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.index }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.modTs }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.monPolDn }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.mtu }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.nativeVlan }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.platId }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.portId }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.stQual }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.status }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.sysLoc }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.sysName }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.sysObjIdL }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.sysObjIdV }}</td>
    <td>{{ endpoint.cdpAdjEp.attributes.ver | replace("\n"," ") }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "cdpEntity" in api %}
<h1>CDP Adjacency Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Oper Error</th>
    <th>Oper State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for entity in data_to_template['imdata'] %}
  <tr>
    <td>{{ entity.cdpEntity.attributes.name }}</td>
    <td>{{ entity.cdpEntity.attributes.adminSt }}</td>
    <td>{{ entity.cdpEntity.attributes.childAction }}</td>
    <td>{{ entity.cdpEntity.attributes.dn }}</td>
    <td>{{ entity.cdpEntity.attributes.lcOwn }}</td>
    <td>{{ entity.cdpEntity.attributes.modTs }}</td>
    <td>{{ entity.cdpEntity.attributes.operErr }}</td>
    <td>{{ entity.cdpEntity.attributes.operSt }}</td>
    <td>{{ entity.cdpEntity.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "cdpIf" in api %}
<h1>CDP Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Local Description</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Native VLAN</th>
    <th>Oper State</th>
    <th>Oper State Quality</th>
    <th>Port Description</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.cdpIf.attributes.name }}</td>
    <td>{{ interface.cdpIf.attributes.adminSt }}</td>
    <td>{{ interface.cdpIf.attributes.childAction }}</td>
    <td>{{ interface.cdpIf.attributes.descr }}</td>
    <td>{{ interface.cdpIf.attributes.dn }}</td>
    <td>{{ interface.cdpIf.attributes.id }}</td>
    <td>{{ interface.cdpIf.attributes.lcOwn }}</td>
    <td>{{ interface.cdpIf.attributes.locDesc }}</td>
    <td>{{ interface.cdpIf.attributes.modTs }}</td>
    <td>{{ interface.cdpIf.attributes.monPolDn }}</td>
    <td>{{ interface.cdpIf.attributes.nativeVlan }}</td>
    <td>{{ interface.cdpIf.attributes.operSt }}</td>
    <td>{{ interface.cdpIf.attributes.operStQual }}</td>
    <td>{{ interface.cdpIf.attributes.portDesc }}</td>
    <td>{{ interface.cdpIf.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "cdpInst" in api %}
<h1>CDP Instances</h1>
<table id = "datatable">
<thead>
  <tr>
    <td>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>Device ID Type</th>
    <th>DN</th>
    <th>Hold Interval</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Number CDP Hifs</th>
    <th>Oper Error</th>
    <th>Status</th>
    <th>System Name</th>
    <th>TX Frequency</th>
    <th>Version</td>
  </tr>
</thead>
<tbody>
{%-     for instance in data_to_template['imdata'] %}
  <tr>
    <td>{{ instance.cdpInst.attributes.name }}</td>
    <td>{{ instance.cdpInst.attributes.adminSt }}</td>
    <td>{{ instance.cdpInst.attributes.childAction }}</td>
    <td>{{ instance.cdpInst.attributes.ctrl }}</td>
    <td>{{ instance.cdpInst.attributes.devIdType }}</td>
    <td>{{ instance.cdpInst.attributes.dn }}</td>
    <td>{{ instance.cdpInst.attributes.holdIntvl }}</td>
    <td>{{ instance.cdpInst.attributes.lcOwn }}</td>
    <td>{{ instance.cdpInst.attributes.modTs }}</td>
    <td>{{ instance.cdpInst.attributes.monPolDn }}</td>
    <td>{{ instance.cdpInst.attributes.numCdpHifs }}</td>
    <td>{{ instance.cdpInst.attributes.operErr }}</td>
    <td>{{ instance.cdpInst.attributes.status }}</td>
    <td>{{ instance.cdpInst.attributes.sysName }}</td>
    <td>{{ instance.cdpInst.attributes.txFreq }}</td>
    <td>{{ instance.cdpInst.attributes.ver }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "cdpIntfAddr" in api %}
<h1>CDP Interface Addresses</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Address</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Last Modified</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for address in data_to_template['imdata'] %}
  <tr>
    <td>{{ address.cdpIntfAddr.attributes.addr }}</td>
    <td>{{ address.cdpIntfAddr.attributes.childAction }}</td>
    <td>{{ address.cdpIntfAddr.attributes.dn }}</td>
    <td>{{ address.cdpIntfAddr.attributes.modTs }}</td>
    <td>{{ address.cdpIntfAddr.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "cdpMgmtAddr" in api %}
<h1>CDP Management Addresses</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Address</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Last Modified</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for address in data_to_template['imdata'] %}
  <tr>
    <td>{{ address.cdpMgmtAddr.attributes.addr }}</td>
    <td>{{ address.cdpMgmtAddr.attributes.childAction }}</td>
    <td>{{ address.cdpMgmtAddr.attributes.dn }}</td>
    <td>{{ address.cdpMgmtAddr.attributes.modTs }}</td>
    <td>{{ address.cdpMgmtAddr.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "cnwRsMbrIfs" in api %}
<h1>Node RS Member Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>tDN</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Parent SKey</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tSKey</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.cnwRsMbrIfs.attributes.tDn }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.childAction }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.dn }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.forceResolve }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.lcOwn }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.modTs }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.parentSKey }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.rType }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.state }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.stateQual }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.status }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.tCl }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.tSKey }}</td>
    <td>{{ interface.cnwRsMbrIfs.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "compRsDomP" in api %}
<h1>Compute RS Domain Policies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDn</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for policy in data_to_template['imdata'] %}
  <tr>
    <td>{{ policy.compRsDomP.attributes.dn }}</td>
    <td>{{ policy.compRsDomP.attributes.childAction }}</td>
    <td>{{ policy.compRsDomP.attributes.forceResolve }}</td>
    <td>{{ policy.compRsDomP.attributes.lcOwn }}</td>
    <td>{{ policy.compRsDomP.attributes.modTs }}</td>
    <td>{{ policy.compRsDomP.attributes.rType }}</td>
    <td>{{ policy.compRsDomP.attributes.state }}</td>
    <td>{{ policy.compRsDomP.attributes.stateQual }}</td>
    <td>{{ policy.compRsDomP.attributes.status }}</td>
    <td>{{ policy.compRsDomP.attributes.tCl }}</td>
    <td>{{ policy.compRsDomP.attributes.tDn }}</td>
    <td>{{ policy.compRsDomP.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptBSlot" in api %}
<h1>Equipment Board Slots</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Card Oper State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Location</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Physical ID</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for slot in data_to_template['imdata'] %}
  <tr>
    <td>{{ slot.eqptBSlot.attributes.id }}</td>
    <td>{{ slot.eqptBSlot.attributes.cardOperSt }}</td>
    <td>{{ slot.eqptBSlot.attributes.childAction }}</td>
    <td>{{ slot.eqptBSlot.attributes.descr }}</td>
    <td>{{ slot.eqptBSlot.attributes.dn }}</td>
    <td>{{ slot.eqptBSlot.attributes.lcOwn }}</td>
    <td>{{ slot.eqptBSlot.attributes.loc }}</td>
    <td>{{ slot.eqptBSlot.attributes.modTs }}</td>
    <td>{{ slot.eqptBSlot.attributes.monPolDn }}</td>
    <td>{{ slot.eqptBSlot.attributes.operSt }}</td>
    <td>{{ slot.eqptBSlot.attributes.physId }}</td>
    <td>{{ slot.eqptBSlot.attributes.status }}</td>
    <td>{{ slot.eqptBSlot.attributes.type }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptBoard" in api %}
<h1>Equipment Boards</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>Hardware Version</th>
    <th>Local Owner</th>
    <th>MAC B</th>
    <th>MAC L</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Number P</th>
    <th>Oper State</th>
    <th>Power State</th>
    <th>rd State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>SW CID</th>
    <th>Type</th>
    <th>Uptime</th>
    <th>vID</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for board in data_to_template['imdata'] %}
  <tr>
    <td>{{ board.eqptBoard.attributes.id }}</td>
    <td>{{ board.eqptBoard.attributes.childAction }}</td>
    <td>{{ board.eqptBoard.attributes.cimcVersion }}</td>
    <td>{{ board.eqptBoard.attributes.descr }}</td>
    <td>{{ board.eqptBoard.attributes.dn }}</td>
    <td>{{ board.eqptBoard.attributes.hwVer }}</td>
    <td>{{ board.eqptBoard.attributes.lcOwn }}</td>
    <td>{{ board.eqptBoard.attributes.macB }}</td>
    <td>{{ board.eqptBoard.attributes.macL }}</td>
    <td>{{ board.eqptBoard.attributes.mfgTm }}</td>
    <td>{{ board.eqptBoard.attributes.modTs }}</td>
    <td>{{ board.eqptBoard.attributes.model }}</td>
    <td>{{ board.eqptBoard.attributes.monPolDn }}</td>
    <td>{{ board.eqptBoard.attributes.numP }}</td>
    <td>{{ board.eqptBoard.attributes.operSt }}</td>
    <td>{{ board.eqptBoard.attributes.pwrSt }}</td>
    <td>{{ board.eqptBoard.attributes.rdSt }}</td>
    <td>{{ board.eqptBoard.attributes.rev }}</td>
    <td>{{ board.eqptBoard.attributes.ser }}</td>
    <td>{{ board.eqptBoard.attributes.status }}</td>
    <td>{{ board.eqptBoard.attributes.swCId }}</td>
    <td>{{ board.eqptBoard.attributes.type }}</td>
    <td>{{ board.eqptBoard.attributes.upTs }}</td>
    <td>{{ board.eqptBoard.attributes.vId }}</td>
    <td>{{ board.eqptBoard.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptCPU" in api %}
<h1>Equipment CPUs</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Architecture</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Cores</th>
    <th>Cores Enabled</th>
    <th>Description</th>
    <th>DN</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Socket</th>
    <th>Speed</th>
    <th>Status</th>
    <th>Threads</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for cpu in data_to_template['imdata'] %}
  <tr>
    <td>{{ cpu.eqptCPU.attributes.id }}</td>
    <td>{{ cpu.eqptCPU.attributes.arch }}</td>
    <td>{{ cpu.eqptCPU.attributes.childAction }}</td>
    <td>{{ cpu.eqptCPU.attributes.cimcVersion }}</td>
    <td>{{ cpu.eqptCPU.attributes.cores }}</td>
    <td>{{ cpu.eqptCPU.attributes.coresEn }}</td>
    <td>{{ cpu.eqptCPU.attributes.descr }}</td>
    <td>{{ cpu.eqptCPU.attributes.dn }}</td>
    <td>{{ cpu.eqptCPU.attributes.mfgTm }}</td>
    <td>{{ cpu.eqptCPU.attributes.modTs }}</td>
    <td>{{ cpu.eqptCPU.attributes.model }}</td>
    <td>{{ cpu.eqptCPU.attributes.rev }}</td>
    <td>{{ cpu.eqptCPU.attributes.ser }}</td>
    <td>{{ cpu.eqptCPU.attributes.sock }}</td>
    <td>{{ cpu.eqptCPU.attributes.speed }}</td>
    <td>{{ cpu.eqptCPU.attributes.status }}</td>
    <td>{{ cpu.eqptCPU.attributes.thrds }}</td>
    <td>{{ cpu.eqptCPU.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptCh" in api %}
<h1>Equipment Chassis</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Configured Role</th>
    <th>Description</th>
    <th>DN</th>
    <th>Hybrid Mode</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Oper State Quality</th>
    <th>Revision</th>
    <th>Role</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>vID</th>
    <th>Vendor</th>
    <th>Virtual Mode</th>
  </tr>
</thead>
<tbody>
{%-     for chassis in data_to_template['imdata'] %}
  <tr>
    <td>{{ chassis.eqptCh.attributes.id }}</td>
    <td>{{ chassis.eqptCh.attributes.childAction }}</td>
    <td>{{ chassis.eqptCh.attributes.cimcVersion }}</td>
    <td>{{ chassis.eqptCh.attributes.configRole }}</td>
    <td>{{ chassis.eqptCh.attributes.descr }}</td>
    <td>{{ chassis.eqptCh.attributes.dn }}</td>
    <td>{{ chassis.eqptCh.attributes.hybridMode }}</td>
    <td>{{ chassis.eqptCh.attributes.mfgTm }}</td>
    <td>{{ chassis.eqptCh.attributes.modTs }}</td>
    <td>{{ chassis.eqptCh.attributes.model }}</td>
    <td>{{ chassis.eqptCh.attributes.monPolDn }}</td>
    <td>{{ chassis.eqptCh.attributes.operSt }}</td>
    <td>{{ chassis.eqptCh.attributes.operStQual }}</td>
    <td>{{ chassis.eqptCh.attributes.rev }}</td>
    <td>{{ chassis.eqptCh.attributes.role }}</td>
    <td>{{ chassis.eqptCh.attributes.ser }}</td>
    <td>{{ chassis.eqptCh.attributes.status }}</td>
    <td>{{ chassis.eqptCh.attributes.vId }}</td>
    <td>{{ chassis.eqptCh.attributes.vendor }}</td>
    <td>{{ chassis.eqptCh.attributes.virtualMode }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptDimm" in api %}
<h1>Equipment DIMMs</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Acc</th>
    <th>Capacity</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>MGF Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Type</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for dimm in data_to_template['imdata'] %}
  <tr>
    <td>{{ dimm.eqptDimm.attributes.id }}</td>
    <td>{{ dimm.eqptDimm.attributes.acc }}</td>
    <td>{{ dimm.eqptDimm.attributes.cap }}</td>
    <td>{{ dimm.eqptDimm.attributes.childAction }}</td>
    <td>{{ dimm.eqptDimm.attributes.cimcVersion }}</td>
    <td>{{ dimm.eqptDimm.attributes.descr }}</td>
    <td>{{ dimm.eqptDimm.attributes.dn }}</td>
    <td>{{ dimm.eqptDimm.attributes.mfgTm }}</td>
    <td>{{ dimm.eqptDimm.attributes.modTs }}</td>
    <td>{{ dimm.eqptDimm.attributes.model }}</td>
    <td>{{ dimm.eqptDimm.attributes.operSt }}</td>
    <td>{{ dimm.eqptDimm.attributes.rev }}</td>
    <td>{{ dimm.eqptDimm.attributes.ser }}</td>
    <td>{{ dimm.eqptDimm.attributes.status }}</td>
    <td>{{ dimm.eqptDimm.attributes.type }}</td>
    <td>{{ dimm.eqptDimm.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptExtCh" in api %}
<h1>Equipment Fabric Extenders</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Control FPort SDP Timeout</th>
    <th>Description</th>
    <th>DN</th>
    <th>External Chassis State</th>
    <th>MAC Address</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Number of MACs</th>
    <th>Number of Uplink Ports</th>
    <th>Part Number</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for fabricextender in data_to_template['imdata'] %}
  <tr>
    <td>{{ fabricextender.eqptExtCh.attributes.id }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.childAction }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.cimcVersion }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.controlFPortSDPTimeout }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.descr }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.dn }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.extChSt }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.macAddr }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.mfgTm }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.modTs }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.model }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.monPolDn }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.numMacs }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.numUplinkP }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.partNum }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.rev }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.ser }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.status }}</td>
    <td>{{ fabricextender.eqptExtCh.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptFabP" in api %}
<h1>Equipment Fabric Ports</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Flags</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Speed</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for port in data_to_template['imdata'] %}
  <tr>
    <td>{{ port.eqptFabP.attributes.id }}</td>
    <td>{{ port.eqptFabP.attributes.childAction }}</td>
    <td>{{ port.eqptFabP.attributes.descr }}</td>
    <td>{{ port.eqptFabP.attributes.dn }}</td>
    <td>{{ port.eqptFabP.attributes.flags }}</td>
    <td>{{ port.eqptFabP.attributes.modTs }}</td>
    <td>{{ port.eqptFabP.attributes.monPolDn }}</td>
    <td>{{ port.eqptFabP.attributes.speed }}</td>
    <td>{{ port.eqptFabP.attributes.status }}</td>
    <td>{{ port.eqptFabP.attributes.type }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptFan" in api %}
<h1>Equipment Fans</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>Direction</th>
    <th>DN</th>
    <th>Max Speed</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Speed</th>
    <th>Status</th>
    <th>vID</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for fan in data_to_template['imdata'] %}
  <tr>
    <td>{{ fan.eqptFan.attributes.id }}</td>
    <td>{{ fan.eqptFan.attributes.childAction }}</td>
    <td>{{ fan.eqptFan.attributes.cimcVersion }}</td>
    <td>{{ fan.eqptFan.attributes.descr }}</td>
    <td>{{ fan.eqptFan.attributes.dir }}</td>
    <td>{{ fan.eqptFan.attributes.dn }}</td>
    <td>{{ fan.eqptFan.attributes.maxSpeed }}</td>
    <td>{{ fan.eqptFan.attributes.mfgTm }}</td>
    <td>{{ fan.eqptFan.attributes.modTs }}</td>
    <td>{{ fan.eqptFan.attributes.model }}</td>
    <td>{{ fan.eqptFan.attributes.monPolDn }}</td>
    <td>{{ fan.eqptFan.attributes.operSt }}</td>
    <td>{{ fan.eqptFan.attributes.rev }}</td>
    <td>{{ fan.eqptFan.attributes.ser }}</td>
    <td>{{ fan.eqptFan.attributes.speed }}</td>
    <td>{{ fan.eqptFan.attributes.status }}</td>
    <td>{{ fan.eqptFan.attributes.vId }}</td>
    <td>{{ fan.eqptFan.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptFpga" in api %}
<h1>Equipment Field Programmable Gate Arrays</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Type</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for array in data_to_template['imdata'] %}
  <tr>
    <td>{{ array.eqptFpga.attributes.id }}</td>
    <td>{{ array.eqptFpga.attributes.childAction }}</td>
    <td>{{ array.eqptFpga.attributes.cimcVersion }}</td>
    <td>{{ array.eqptFpga.attributes.descr }}</td>
    <td>{{ array.eqptFpga.attributes.dn }}</td>
    <td>{{ array.eqptFpga.attributes.mfgTm }}</td>
    <td>{{ array.eqptFpga.attributes.modTs }}</td>
    <td>{{ array.eqptFpga.attributes.model }}</td>
    <td>{{ array.eqptFpga.attributes.monPolDn }}</td>
    <td>{{ array.eqptFpga.attributes.operSt }}</td>
    <td>{{ array.eqptFpga.attributes.rev }}</td>
    <td>{{ array.eqptFpga.attributes.ser }}</td>
    <td>{{ array.eqptFpga.attributes.status }}</td>
    <td>{{ array.eqptFpga.attributes.type }}</td>
    <td>{{ array.eqptFpga.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptFt" in api %}
{%-     if "Slot" in api %}
<h1>Equipment Fan Tray Slots</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Card Oper State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Location</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Physical ID</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-         for slot in data_to_template['imdata'] %}
  <tr>
    <td>{{ slot.eqptFtSlot.attributes.id }}</td>
    <td>{{ slot.eqptFtSlot.attributes.cardOperSt }}</td>
    <td>{{ slot.eqptFtSlot.attributes.childAction }}</td>
    <td>{{ slot.eqptFtSlot.attributes.descr }}</td>
    <td>{{ slot.eqptFtSlot.attributes.dn }}</td>
    <td>{{ slot.eqptFtSlot.attributes.loc }}</td>
    <td>{{ slot.eqptFtSlot.attributes.modTs }}</td>
    <td>{{ slot.eqptFtSlot.attributes.monPolDn }}</td>
    <td>{{ slot.eqptFtSlot.attributes.operSt }}</td>
    <td>{{ slot.eqptFtSlot.attributes.physId }}</td>
    <td>{{ slot.eqptFtSlot.attributes.status }}</td>
    <td>{{ slot.eqptFtSlot.attributes.type }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>Equipment Fan Trays</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>Fan Name</th>
    <th>Fanlet Fail String</th>
    <th>Hardware Version</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-         for trays in data_to_template['imdata'] %}
  <tr>
    <td>{{ trays.eqptFt.attributes.id }}</td>
    <td>{{ trays.eqptFt.attributes.childAction }}</td>
    <td>{{ trays.eqptFt.attributes.cimcVersion }}</td>
    <td>{{ trays.eqptFt.attributes.descr }}</td>
    <td>{{ trays.eqptFt.attributes.dn }}</td>
    <td>{{ trays.eqptFt.attributes.fanName }}</td>
    <td>{{ trays.eqptFt.attributes.fanletFailString }}</td>
    <td>{{ trays.eqptFt.attributes.hwVer }}</td>
    <td>{{ trays.eqptFt.attributes.mfgTm }}</td>
    <td>{{ trays.eqptFt.attributes.modTs }}</td>
    <td>{{ trays.eqptFt.attributes.model }}</td>
    <td>{{ trays.eqptFt.attributes.monPolDn }}</td>
    <td>{{ trays.eqptFt.attributes.operSt }}</td>
    <td>{{ trays.eqptFt.attributes.rev }}</td>
    <td>{{ trays.eqptFt.attributes.ser }}</td>
    <td>{{ trays.eqptFt.attributes.status }}</td>
    <td>{{ trays.eqptFt.attributes.vendor }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "eqptIndLed" in api %}
<h1>Equipment Indicator LEDs</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Color</th>
    <th>Description</th>
    <th>DN</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Type</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for led in data_to_template['imdata'] %}
  <tr>
    <td>{{ led.eqptIndLed.attributes.id }}</td>
    <td>{{ led.eqptIndLed.attributes.childAction }}</td>
    <td>{{ led.eqptIndLed.attributes.cimcVersion }}</td>
    <td>{{ led.eqptIndLed.attributes.color }}</td>
    <td>{{ led.eqptIndLed.attributes.descr }}</td>
    <td>{{ led.eqptIndLed.attributes.dn }}</td>
    <td>{{ led.eqptIndLed.attributes.mfgTm }}</td>
    <td>{{ led.eqptIndLed.attributes.modTs }}</td>
    <td>{{ led.eqptIndLed.attributes.model }}</td>
    <td>{{ led.eqptIndLed.attributes.operSt }}</td>
    <td>{{ led.eqptIndLed.attributes.rev }}</td>
    <td>{{ led.eqptIndLed.attributes.ser }}</td>
    <td>{{ led.eqptIndLed.attributes.status }}</td>
    <td>{{ led.eqptIndLed.attributes.type }}</td>
    <td>{{ led.eqptIndLed.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptLC" in api %}
{%-     if "Slot" in api %}
<h1>Equipment Line Card Slots</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Card Oper State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Location</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Physical ID</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-         for slot in data_to_template['imdata'] %}
  <tr>
    <td>{{ slot.eqptLCSlot.attributes.id }}</td>
    <td>{{ slot.eqptLCSlot.attributes.cardOperSt }}</td>
    <td>{{ slot.eqptLCSlot.attributes.childAction }}</td>
    <td>{{ slot.eqptLCSlot.attributes.descr }}</td>
    <td>{{ slot.eqptLCSlot.attributes.dn }}</td>
    <td>{{ slot.eqptLCSlot.attributes.loc }}</td>
    <td>{{ slot.eqptLCSlot.attributes.modTs }}</td>
    <td>{{ slot.eqptLCSlot.attributes.monPolDn }}</td>
    <td>{{ slot.eqptLCSlot.attributes.operSt }}</td>
    <td>{{ slot.eqptLCSlot.attributes.physId }}</td>
    <td>{{ slot.eqptLCSlot.attributes.status }}</td>
    <td>{{ slot.eqptLCSlot.attributes.type }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>Equipment Line Cards</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>Hardware Version</th>
    <th>MAC B</th>
    <th>MAC L</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Number Ports</th>
    <th>Oper State</th>
    <th>Power State</th>
    <th>rd State</th>
    <th>Revision</th>
    <th>Serial</th>
    <th>Status</th>
    <th>Software CID</th>
    <th>Type</th>
    <th>Uptime</th>
    <th>vID</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-         for card in data_to_template['imdata'] %}
  <tr>
    <td>{{ card.eqptLC.attributes.id }}</td>
    <td>{{ card.eqptLC.attributes.childAction }}</td>
    <td>{{ card.eqptLC.attributes.cimcVersion }}</td>
    <td>{{ card.eqptLC.attributes.descr }}</td>
    <td>{{ card.eqptLC.attributes.dn }}</td>
    <td>{{ card.eqptLC.attributes.hwVer }}</td>
    <td>{{ card.eqptLC.attributes.macB }}</td>
    <td>{{ card.eqptLC.attributes.macL }}</td>
    <td>{{ card.eqptLC.attributes.mfgTm }}</td>
    <td>{{ card.eqptLC.attributes.modTs }}</td>
    <td>{{ card.eqptLC.attributes.model }}</td>
    <td>{{ card.eqptLC.attributes.monPolDn }}</td>
    <td>{{ card.eqptLC.attributes.numP }}</td>
    <td>{{ card.eqptLC.attributes.operSt }}</td>
    <td>{{ card.eqptLC.attributes.pwrSt }}</td>
    <td>{{ card.eqptLC.attributes.rdSt }}</td>
    <td>{{ card.eqptLC.attributes.rev }}</td>
    <td>{{ card.eqptLC.attributes.ser }}</td>
    <td>{{ card.eqptLC.attributes.status }}</td>
    <td>{{ card.eqptLC.attributes.swCId }}</td>
    <td>{{ card.eqptLC.attributes.type }}</td>
    <td>{{ card.eqptLC.attributes.upTs }}</td>
    <td>{{ card.eqptLC.attributes.vId }}</td>
    <td>{{ card.eqptLC.attributes.vendor }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "eqptLeafP" in api %}
<h1>Equipment Leaf Ports</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Flags</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Speed</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for port in data_to_template['imdata'] %}
  <tr>
    <td>{{ port.eqptLeafP.attributes.id }}</td>
    <td>{{ port.eqptLeafP.attributes.childAction }}</td>
    <td>{{ port.eqptLeafP.attributes.descr }}</td>
    <td>{{ port.eqptLeafP.attributes.dn }}</td>
    <td>{{ port.eqptLeafP.attributes.flags }}</td>
    <td>{{ port.eqptLeafP.attributes.modTs }}</td>
    <td>{{ port.eqptLeafP.attributes.monPolDn }}</td>
    <td>{{ port.eqptLeafP.attributes.speed }}</td>
    <td>{{ port.eqptLeafP.attributes.status }}</td>
    <td>{{ port.eqptLeafP.attributes.type }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptLocLed" in api %}
<h1>Equipment Port Locator LEDs</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Color</th>
    <th>Description</th>
    <th>DN</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Type</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for led in data_to_template['imdata'] %}
  <tr>
    <td>{{ led.eqptLocLed.attributes.id }}</td>
    <td>{{ led.eqptLocLed.attributes.adminSt }}</td>
    <td>{{ led.eqptLocLed.attributes.childAction }}</td>
    <td>{{ led.eqptLocLed.attributes.cimcVersion }}</td>
    <td>{{ led.eqptLocLed.attributes.color }}</td>
    <td>{{ led.eqptLocLed.attributes.descr }}</td>
    <td>{{ led.eqptLocLed.attributes.dn }}</td>
    <td>{{ led.eqptLocLed.attributes.mfgTm }}</td>
    <td>{{ led.eqptLocLed.attributes.modTs }}</td>
    <td>{{ led.eqptLocLed.attributes.model }}</td>
    <td>{{ led.eqptLocLed.attributes.operSt }}</td>
    <td>{{ led.eqptLocLed.attributes.rev }}</td>
    <td>{{ led.eqptLocLed.attributes.ser }}</td>
    <td>{{ led.eqptLocLed.attributes.status }}</td>
    <td>{{ led.eqptLocLed.attributes.type }}</td>
    <td>{{ led.eqptLocLed.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptPsu" in api %}
{%-     if "Slot" in api %}
<h1>Equipment Power Supply Slots</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Card Oper State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Location</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Physical ID</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-         for slot in data_to_template['imdata'] %}
  <tr>
    <td>{{ slot.eqptPsuSlot.attributes.id }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.cardOperSt }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.childAction }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.descr }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.dn }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.loc }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.modTs }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.monPolDn }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.operSt }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.physId }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.status }}</td>
    <td>{{ slot.eqptPsuSlot.attributes.type }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>Equipment Power Supplies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Alarm Reg</th>
    <th>Capacity</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>Drawn Current</th>
    <th>Fan Oper State</th>
    <th>Hardware Version</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>TC</th>
    <th>vID</th>
    <th>vSrc</th>
    <th>Vendor</th>
    <th>Voltage</th>
  </tr>
</thead>
<tbody>
{%-         for psu in data_to_template['imdata'] %}
  <tr>
    <td>{{ psu.eqptPsu.attributes.id }}</td>
    <td>{{ psu.eqptPsu.attributes.almReg }}</td>
    <td>{{ psu.eqptPsu.attributes.cap }}</td>
    <td>{{ psu.eqptPsu.attributes.childAction }}</td>
    <td>{{ psu.eqptPsu.attributes.cimcVersion }}</td>
    <td>{{ psu.eqptPsu.attributes.descr }}</td>
    <td>{{ psu.eqptPsu.attributes.dn }}</td>
    <td>{{ psu.eqptPsu.attributes.drawnCurr }}</td>
    <td>{{ psu.eqptPsu.attributes.fanOpSt }}</td>
    <td>{{ psu.eqptPsu.attributes.hwVer }}</td>
    <td>{{ psu.eqptPsu.attributes.mfgTm }}</td>
    <td>{{ psu.eqptPsu.attributes.modTs }}</td>
    <td>{{ psu.eqptPsu.attributes.model }}</td>
    <td>{{ psu.eqptPsu.attributes.monPolDn }}</td>
    <td>{{ psu.eqptPsu.attributes.operSt }}</td>
    <td>{{ psu.eqptPsu.attributes.rev }}</td>
    <td>{{ psu.eqptPsu.attributes.ser }}</td>
    <td>{{ psu.eqptPsu.attributes.status }}</td>
    <td>{{ psu.eqptPsu.attributes.tc }}</td>
    <td>{{ psu.eqptPsu.attributes.vId }}</td>
    <td>{{ psu.eqptPsu.attributes.vSrc }}</td>
    <td>{{ psu.eqptPsu.attributes.vendor }}</td>
    <td>{{ psu.eqptPsu.attributes.volt }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "eqptRsIoPPhysConf" in api %}
<h1>Equipment RS IO Port Physical Configurations</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>tSKey</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCL</th>
    <th>tDN</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for port in data_to_template['imdata'] %}
  <tr>
    <td>{{ port.eqptRsIoPPhysConf.attributes.tSKey }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.childAction }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.dn }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.forceResolve }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.lcOwn }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.modTs }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.rType }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.state }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.stateQual }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.status }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.tCl }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.tDn }}</td>
    <td>{{ port.eqptRsIoPPhysConf.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptSensor" in api %}
<h1>Equipment Sensors</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>Major Threshold</th>
    <th>MFG Timestamp</th>
    <th>Minor Threshold</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Type</th>
    <th>Value</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for sensor in data_to_template['imdata'] %}
  <tr>
    <td>{{ sensor.eqptSensor.attributes.id }}</td>
    <td>{{ sensor.eqptSensor.attributes.childAction }}</td>
    <td>{{ sensor.eqptSensor.attributes.cimcVersion }}</td>
    <td>{{ sensor.eqptSensor.attributes.descr }}</td>
    <td>{{ sensor.eqptSensor.attributes.dn }}</td>
    <td>{{ sensor.eqptSensor.attributes.majorThresh }}</td>
    <td>{{ sensor.eqptSensor.attributes.mfgTm }}</td>
    <td>{{ sensor.eqptSensor.attributes.minorThresh }}</td>
    <td>{{ sensor.eqptSensor.attributes.modTs }}</td>
    <td>{{ sensor.eqptSensor.attributes.model }}</td>
    <td>{{ sensor.eqptSensor.attributes.monPolDn }}</td>
    <td>{{ sensor.eqptSensor.attributes.operSt }}</td>
    <td>{{ sensor.eqptSensor.attributes.rev }}</td>
    <td>{{ sensor.eqptSensor.attributes.ser }}</td>
    <td>{{ sensor.eqptSensor.attributes.status }}</td>
    <td>{{ sensor.eqptSensor.attributes.type }}</td>
    <td>{{ sensor.eqptSensor.attributes.value }}</td>
    <td>{{ sensor.eqptSensor.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptSpCmnBlk" in api %}
<h1>Equipment SP Common Blocks</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>PD Number</th>
    <th>Port Number</th>
    <th>Child Action</th>
    <th>Checksum</th>
    <th>CLEI</th>
    <th>Count</th>
    <th>DN</th>
    <th>Eng Bits</th>
    <th>Hardware Revision Major</th>
    <th>Hardware Revision Minor</th>
    <th>Length</th>
    <th>Major</th>
    <th>MFG Bits</th>
    <th>MFG Dev</th>
    <th>Minor</th>
    <th>Last Modified</th>
    <th>OEM</th>
    <th>pRevision</th>
    <th>Power Consumption</th>
    <th>RAM FL</th>
    <th>Serial Number</th>
    <th>Signature</th>
    <th>Size</th>
    <th>Status</th>
    <th>Vendor ID</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>
{%-     for common_block in data_to_template['imdata'] %}
  <tr>
    <td>{{ common_block.eqptSpCmnBlk.attributes.pdNum }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.prtNum }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.childAction }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.cksum }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.clei }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.count }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.dn }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.engBits }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.hwRevMaj }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.hwRevMin }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.len }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.major }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.mfgBits }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.mfgDev }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.minor }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.modTs }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.oem }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.pRev }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.pwrCon }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.ramFl }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.serNum }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.sig }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.size }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.status }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.vdrId }}</td>
    <td>{{ common_block.eqptSpCmnBlk.attributes.ver }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptSpromLc" in api %}
<h1>Equipment SPROM LCs</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Access</th>
    <th>Capacity</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>Error Reason</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Number Blocks</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Type</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for lc in data_to_template['imdata'] %}
  <tr>
    <td>{{ lc.eqptSpromLc.attributes.id }}</td>
    <td>{{ lc.eqptSpromLc.attributes.acc }}</td>
    <td>{{ lc.eqptSpromLc.attributes.cap }}</td>
    <td>{{ lc.eqptSpromLc.attributes.childAction }}</td>
    <td>{{ lc.eqptSpromLc.attributes.cimcVersion }}</td>
    <td>{{ lc.eqptSpromLc.attributes.descr }}</td>
    <td>{{ lc.eqptSpromLc.attributes.dn }}</td>
    <td>{{ lc.eqptSpromLc.attributes.errRsn }}</td>
    <td>{{ lc.eqptSpromLc.attributes.mfgTm }}</td>
    <td>{{ lc.eqptSpromLc.attributes.modTs }}</td>
    <td>{{ lc.eqptSpromLc.attributes.model }}</td>
    <td>{{ lc.eqptSpromLc.attributes.monPolDn }}</td>
    <td>{{ lc.eqptSpromLc.attributes.numBlk }}</td>
    <td>{{ lc.eqptSpromLc.attributes.operSt }}</td>
    <td>{{ lc.eqptSpromLc.attributes.rev }}</td>
    <td>{{ lc.eqptSpromLc.attributes.ser }}</td>
    <td>{{ lc.eqptSpromLc.attributes.status }}</td>
    <td>{{ lc.eqptSpromLc.attributes.type }}</td>
    <td>{{ lc.eqptSpromLc.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptSpromPsu" in api %}
{%-     if "Blk" in api %}
<h1>Equipment SPROM Power Supply Blocks</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>c110v</th>
    <th>c220v</th>
    <th>Child Action</th>
    <th>Checksum</th>
    <th>F Bits</th>
    <th>Length</th>
    <th>Last Modified</th>
    <th>Power Supply CMd1</th>
    <th>Power Supply CMd2</th>
    <th>Power Supply CMd3</th>
    <th>Power Supply CMd4</th>
    <th>Power Supply CMxMd1</th>
    <th>Power Supply CMxMd2</th>
    <th>Power Supply CMxMd3</th>
    <th>Power Supply CMxMd4</th>
    <th>Signature</th>
    <th>smOID</th>
    <th>Status</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>
{%-         for psu_block in data_to_template['imdata'] %}
  <tr>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.dn }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.c110v }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.c220v }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.childAction }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.cksum }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.fbits }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.len }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.modTs }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.psCMd1 }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.psCMd2 }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.psCMd3 }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.psCMd4 }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd1 }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd2 }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd3 }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd4 }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.sig }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.smOID }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.status }}</td>
    <td>{{ psu_block.eqptSpromPsuBlk.attributes.ver }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>Equipment SPROM Power Supplies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Access</th>
    <th>Capacity</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>Error Reason</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Number Blocks</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Type</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-         for psu in data_to_template['imdata'] %}
  <tr>
    <td>{{ psu.eqptSpromPsu.attributes.id }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.acc }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.cap }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.childAction }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.cimcVersion }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.descr }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.dn }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.errRsn }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.mfgTm }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.modTs }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.model }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.monPolDn }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.numBlk }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.operSt }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.rev }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.ser }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.status }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.type }}</td>
    <td>{{ psu.eqptSpromPsu.attributes.vendor }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "eqptSpromSup" in api %}
<h1>Equipment SPROM Supervisors</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Access</th>
    <th>Capacity</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>Error Reason</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Number Blocks</th>
    <th>Oper State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Type</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-     for sup in data_to_template['imdata'] %}
  <tr>
    <td>{{ sup.eqptSpromSup.attributes.id }}</td>
    <td>{{ sup.eqptSpromSup.attributes.acc }}</td>
    <td>{{ sup.eqptSpromSup.attributes.cap }}</td>
    <td>{{ sup.eqptSpromSup.attributes.childAction }}</td>
    <td>{{ sup.eqptSpromSup.attributes.cimcVersion }}</td>
    <td>{{ sup.eqptSpromSup.attributes.descr }}</td>
    <td>{{ sup.eqptSpromSup.attributes.dn }}</td>
    <td>{{ sup.eqptSpromSup.attributes.errRsn }}</td>
    <td>{{ sup.eqptSpromSup.attributes.mfgTm }}</td>
    <td>{{ sup.eqptSpromSup.attributes.modTs }}</td>
    <td>{{ sup.eqptSpromSup.attributes.model }}</td>
    <td>{{ sup.eqptSpromSup.attributes.monPolDn }}</td>
    <td>{{ sup.eqptSpromSup.attributes.numBlk }}</td>
    <td>{{ sup.eqptSpromSup.attributes.operSt }}</td>
    <td>{{ sup.eqptSpromSup.attributes.rev }}</td>
    <td>{{ sup.eqptSpromSup.attributes.ser }}</td>
    <td>{{ sup.eqptSpromSup.attributes.status }}</td>
    <td>{{ sup.eqptSpromSup.attributes.type }}</td>
    <td>{{ sup.eqptSpromSup.attributes.vendor }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptStorage" in api %}
<h1>Equipment Storage</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Available</th>
    <th>Blocks</th>
    <th>Capacity Utilized</th>
    <th>Child Action</th>
    <th>Device</th>
    <th>DN</th>
    <th>Fail Reason</th>
    <th>File System</th>
    <th>Firmware Version</th>
    <th>Local Owner</th>
    <th>Media Wearout</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Mount</th>
    <th>Oper State</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Used</th>
  </tr>
</thead>
<tbody>
{%-     for storage in data_to_template['imdata'] %}
  <tr>
    <td>{{ storage.eqptStorage.attributes.name }}</td>
    <td>{{ storage.eqptStorage.attributes.nameAlias }}</td>
    <td>{{ storage.eqptStorage.attributes.available }}</td>
    <td>{{ storage.eqptStorage.attributes.blocks }}</td>
    <td>{{ storage.eqptStorage.attributes.capUtilized }}</td>
    <td>{{ storage.eqptStorage.attributes.childAction }}</td>
    <td>{{ storage.eqptStorage.attributes.device }}</td>
    <td>{{ storage.eqptStorage.attributes.dn }}</td>
    <td>{{ storage.eqptStorage.attributes.failReason }}</td>
    <td>{{ storage.eqptStorage.attributes.fileSystem }}</td>
    <td>{{ storage.eqptStorage.attributes.firmwareVersion }}</td>
    <td>{{ storage.eqptStorage.attributes.lcOwn }}</td>
    <td>{{ storage.eqptStorage.attributes.mediaWearout }}</td>
    <td>{{ storage.eqptStorage.attributes.modTs }}</td>
    <td>{{ storage.eqptStorage.attributes.model }}</td>
    <td>{{ storage.eqptStorage.attributes.monPolDn }}</td>
    <td>{{ storage.eqptStorage.attributes.mount }}</td>
    <td>{{ storage.eqptStorage.attributes.operSt }}</td>
    <td>{{ storage.eqptStorage.attributes.serial }}</td>
    <td>{{ storage.eqptStorage.attributes.status }}</td>
    <td>{{ storage.eqptStorage.attributes.used }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "eqptSupC" in api %}
{%-     if "Slot" in api %}
<h1>Equipment Supervisor Slots</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Card Oper State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Location</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Physical ID</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-         for slot in data_to_template['imdata'] %}
  <tr>
    <td>{{ slot.eqptSupCSlot.attributes.id }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.cardOperSt }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.childAction }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.descr }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.dn }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.loc }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.modTs }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.monPolDn }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.operSt }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.physId }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.status }}</td>
    <td>{{ slot.eqptSupCSlot.attributes.type }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>Equipment Supervisors</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Child Action</th>
    <th>CIMC Version</th>
    <th>Description</th>
    <th>DN</th>
    <th>Hardware Version</th>
    <th>MAC B</th>
    <th>MAC L</th>
    <th>MFG Timestamp</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Number of Ports</th>
    <th>Oper State</th>
    <th>Power State</th>
    <th>rd State</th>
    <th>Revision</th>
    <th>Serial Number</th>
    <th>Status</th>
    <th>Software CID</th>
    <th>Type</th>
    <th>Uptime</th>
    <th>vID</th>
    <th>Vendor</th>
  </tr>
</thead>
<tbody>
{%-         for supervisor in data_to_template['imdata'] %}
  <tr>
    <td>{{ supervisor.eqptSupC.attributes.id }}</td>
    <td>{{ supervisor.eqptSupC.attributes.childAction }}</td>
    <td>{{ supervisor.eqptSupC.attributes.cimcVersion }}</td>
    <td>{{ supervisor.eqptSupC.attributes.descr }}</td>
    <td>{{ supervisor.eqptSupC.attributes.dn }}</td>
    <td>{{ supervisor.eqptSupC.attributes.hwVer }}</td>
    <td>{{ supervisor.eqptSupC.attributes.macB }}</td>
    <td>{{ supervisor.eqptSupC.attributes.macL }}</td>
    <td>{{ supervisor.eqptSupC.attributes.mfgTm }}</td>
    <td>{{ supervisor.eqptSupC.attributes.modTs }}</td>
    <td>{{ supervisor.eqptSupC.attributes.model }}</td>
    <td>{{ supervisor.eqptSupC.attributes.monPolDn }}</td>
    <td>{{ supervisor.eqptSupC.attributes.numP }}</td>
    <td>{{ supervisor.eqptSupC.attributes.operSt }}</td>
    <td>{{ supervisor.eqptSupC.attributes.pwrSt }}</td>
    <td>{{ supervisor.eqptSupC.attributes.rdSt }}</td>
    <td>{{ supervisor.eqptSupC.attributes.rev }}</td>
    <td>{{ supervisor.eqptSupC.attributes.ser }}</td>
    <td>{{ supervisor.eqptSupC.attributes.status }}</td>
    <td>{{ supervisor.eqptSupC.attributes.swCId }}</td>
    <td>{{ supervisor.eqptSupC.attributes.type }}</td>
    <td>{{ supervisor.eqptSupC.attributes.upTs }}</td>
    <td>{{ supervisor.eqptSupC.attributes.vId }}</td>
    <td>{{ supervisor.eqptSupC.attributes.vendor }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "ethpmPhysIf" in api %}
<h1>Ethernet Port Manager Physical Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Interface Number</th>
    <th>Access VLAN</th>
    <th>Allowed VLANs</th>
    <th>Backplane MAC</th>
    <th>Bundle Bup ID</th>
    <th>Bundle Index</th>
    <th>Configured Access VLAN</th>
    <th>Confgured Native VLAN</th>
    <th>Child Action</th>
    <th>Current Error Index</th>
    <th>Diagnostics</th>
    <th>Encapsulation</th>
    <th>Error Display Timer Running</th>
    <th>Error VLAN Status Ht</th>
    <th>Error VLANs</th>
    <th>Hardware Bd ID</th>
    <th>Hardware Resource ID</th>
    <th>Interface Type</th>
    <th>IOD</th>
    <th>Last Errors</th>
    <th>Last Link State Change</th>
    <th>Media</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Native VLAN</th>
    <th>Number of SI</th>
    <th>Oper Bitset</th>
    <th>Oper Dce Mode</th>
    <th>Oper Duplex</th>
    <th>Oper EEE Rx Wk Time</th>
    <th>Oper EEE State</th>
    <th>Oper EEE Tx Wk Time</th>
    <th>Oper Error Display Quality</th>
    <th>Oper FEC Mode</th>
    <th>Oper Flow Control</th>
    <th>Oper MDIX</th>
    <th>Oper Mode</th>
    <th>Oper Mode Detail</th>
    <th>Oper Physical En State</th>
    <th>Oper Router MAC</th>
    <th>Oper Speed</th>
    <th>Oper State</th>
    <th>Oper State Quality</th>
    <th>Oper State Quality Code</th>
    <th>Oper VLANs</th>
    <th>OS Sum</th>
    <th>Port Config Wait Flags</th>
    <th>Primary VLAN</th>
    <th>Reset Counter</th>
    <th>SI List</th>
    <th>Status</th>
    <th>TX Type</th>
    <th>Usage</th>
    <th>User Configured Flags</th>
    <th>VDC ID</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.ethpmPhysIf.attributes.dn }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.accessVlan }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.allowedVlans }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.backplaneMac }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.bundleBupId }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.bundleIndex }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.cfgAccessVlan }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.cfgNativeVlan }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.childAction }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.currErrIndex }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.diags }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.encap }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.errDisTimerRunning }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.errVlanStatusHt }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.errVlans }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.hwBdId }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.hwResourceId }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.intfT }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.iod }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.lastErrors }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.lastLinkStChg }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.media }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.modTs }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.monPolDn }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.nativeVlan }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.numOfSI }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operBitset }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operDceMode }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operDuplex }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operEEERxWkTime }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operEEEState }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operEEETxWkTime }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operErrDisQual }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operFecMode }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operFlowCtrl }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operMdix }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operMode }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operModeDetail }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operPhyEnSt }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operRouterMac }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operSpeed }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operSt }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operStQual }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operStQualCode }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.operVlans }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.osSum }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.portCfgWaitFlags }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.primaryVlan }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.resetCtr }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.siList }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.status }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.txT }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.usage }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.userCfgdFlags }}</td>
    <td>{{ interface.ethpmPhysIf.attributes.vdcId }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fabricExtPathEpCont" in api %}
<h1>Fabric Extended Path Endpoint Containers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Extended Ch ID</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for container in data_to_template['imdata'] %}
  <tr>
    <td>{{ container.fabricExtPathEpCont.attributes.dn }}</td>
    <td>{{ container.fabricExtPathEpCont.attributes.childAction }}</td>
    <td>{{ container.fabricExtPathEpCont.attributes.extChId }}</td>
    <td>{{ container.fabricExtPathEpCont.attributes.lcOwn }}</td>
    <td>{{ container.fabricExtPathEpCont.attributes.modTs }}</td>
    <td>{{ container.fabricExtPathEpCont.attributes.monPolDn }}</td>
    <td>{{ container.fabricExtPathEpCont.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fabricInst" in api %}
<h1>Fabric Instances</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for instance in data_to_template['imdata'] %}
  <tr>
    <td>{{ instance.fabricInst.attributes.name }}</td>
    <td>{{ instance.fabricInst.attributes.nameAlias }}</td>
    <td>{{ instance.fabricInst.attributes.annotation }}</td>
    <td>{{ instance.fabricInst.attributes.childAction }}</td>
    <td>{{ instance.fabricInst.attributes.dn }}</td>
    <td>{{ instance.fabricInst.attributes.extMngdBy }}</td>
    <td>{{ instance.fabricInst.attributes.lcOwn }}</td>
    <td>{{ instance.fabricInst.attributes.modTs }}</td>
    <td>{{ instance.fabricInst.attributes.monPolDn }}</td>
    <td>{{ instance.fabricInst.attributes.ownerKey }}</td>
    <td>{{ instance.fabricInst.attributes.ownerTag }}</td>
    <td>{{ instance.fabricInst.attributes.status }}</td>
    <td>{{ instance.fabricInst.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fabricLink" in api %}
{%-     if "Cont" in api %}
<h1>Fabric Link Containers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Node</th>
    <th>DN</th>
    <th>Child Action</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-         for container in data_to_template['imdata'] %}
  <tr>
    <td>{{ container.fabricLinkCont.attributes.n }}</td>
    <td>{{ container.fabricLinkCont.attributes.dn }}</td>
    <td>{{ container.fabricLinkCont.attributes.childAction }}</td>
    <td>{{ container.fabricLinkCont.attributes.lcOwn }}</td>
    <td>{{ container.fabricLinkCont.attributes.modTs }}</td>
    <td>{{ container.fabricLinkCont.attributes.monPolDn }}</td>
    <td>{{ container.fabricLinkCont.attributes.status }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>Fabric Links</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Local Owner</th>
    <th>Link State</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Node 1</th>
    <th>Node 2</th>
    <th>Port 1</th>
    <th>Port 2</th>
    <th>Router 1</th>
    <th>Router 2</th>
    <th>Switch 1</th>
    <th>Switch 2</th>
    <th>Status</th>
    <th>Wiring Issues</th>
  </tr>
</thead>
<tbody>
{%-         for link in data_to_template['imdata'] %}
  <tr>
    <td>{{ link.fabricLink.attributes.dn }}</td>
    <td>{{ link.fabricLink.attributes.childAction }}</td>
    <td>{{ link.fabricLink.attributes.lcOwn }}</td>
    <td>{{ link.fabricLink.attributes.linkState }}</td>
    <td>{{ link.fabricLink.attributes.modTs }}</td>
    <td>{{ link.fabricLink.attributes.monPolDn }}</td>
    <td>{{ link.fabricLink.attributes.n1 }}</td>
    <td>{{ link.fabricLink.attributes.n2 }}</td>
    <td>{{ link.fabricLink.attributes.p1 }}</td>
    <td>{{ link.fabricLink.attributes.p2 }}</td>
    <td>{{ link.fabricLink.attributes.r1 }}</td>
    <td>{{ link.fabricLink.attributes.r2 }}</td>
    <td>{{ link.fabricLink.attributes.s1 }}</td>
    <td>{{ link.fabricLink.attributes.s2 }}</td>
    <td>{{ link.fabricLink.attributes.status }}</td>
    <td>{{ link.fabricLink.attributes.wiringIssues }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "fabricLooseLink" in api %}
<h1>Fabric Loose Links</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>is Edm Managed</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Node DN</th>
    <th>Port DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for link in data_to_template['imdata'] %}
  <tr>
    <td>{{ link.fabricLooseLink.attributes.name }}</td>
    <td>{{ link.fabricLooseLink.attributes.nameAlias }}</td>
    <td>{{ link.fabricLooseLink.attributes.childAction }}</td>
    <td>{{ link.fabricLooseLink.attributes.dn }}</td>
    <td>{{ link.fabricLooseLink.attributes.isEdmManaged }}</td>
    <td>{{ link.fabricLooseLink.attributes.lcOwn }}</td>
    <td>{{ link.fabricLooseLink.attributes.modTs }}</td>
    <td>{{ link.fabricLooseLink.attributes.nodeDn }}</td>
    <td>{{ link.fabricLooseLink.attributes.portDn }}</td>
    <td>{{ link.fabricLooseLink.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fabricLooseNode" in api %}
<h1>Fabric Loose Nodes</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>ID</th>
    <th>Is Managed</th>
    <th>Local Owner</th>
    <th>Manager Key</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Issues</th>
    <th>Pod ID</th>
    <th>Status</th>
    <th>System Description</th>
    <th>System Name</th>
  </tr>
</thead>
<tbody>
{%-     for node in data_to_template['imdata'] %}
  <tr>
    <td>{{ node.fabricLooseNode.attributes.name }}</th>
    <th>{{ node.fabricLooseNode.attributes.nameAlias }}</th>
    <th>{{ node.fabricLooseNode.attributes.childAction }}</th>
    <th>{{ node.fabricLooseNode.attributes.dn }}</th>
    <th>{{ node.fabricLooseNode.attributes.id }}</th>
    <th>{{ node.fabricLooseNode.attributes.isManaged }}</th>
    <th>{{ node.fabricLooseNode.attributes.lcOwn }}</th>
    <th>{{ node.fabricLooseNode.attributes.mgrKey }}</th>
    <th>{{ node.fabricLooseNode.attributes.modTs }}</th>
    <th>{{ node.fabricLooseNode.attributes.monPolDn }}</th>
    <th>{{ node.fabricLooseNode.attributes.operIssues }}</th>
    <th>{{ node.fabricLooseNode.attributes.podId }}</th>
    <th>{{ node.fabricLooseNode.attributes.status }}</th>
    <th>{{ node.fabricLooseNode.attributes.sysDesc | replace("\n"," ") }}</th>
    <th>{{ node.fabricLooseNode.attributes.sysName }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fabricProtPathEpCont" in api %}
<h1>Fabric Protected Path Endpoint Containers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Node AId</th>
    <th>Node BId</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for container in data_to_template['imdata'] %}
  <tr>
    <td>{{ container.fabricProtPathEpCont.attributes.dn }}</td>
    <td>{{ container.fabricProtPathEpCont.attributes.childAction }}</td>
    <td>{{ container.fabricProtPathEpCont.attributes.lcOwn }}</td>
    <td>{{ container.fabricProtPathEpCont.attributes.modTs }}</td>
    <td>{{ container.fabricProtPathEpCont.attributes.monPolDn }}</td>
    <td>{{ container.fabricProtPathEpCont.attributes.nodeAId }}</td>
    <td>{{ container.fabricProtPathEpCont.attributes.nodeBId }}</td>
    <td>{{ container.fabricProtPathEpCont.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fcEntity" in api %}
<h1>Fibre Channel Entities</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Oper State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for entity in data_to_template['imdata'] %}
  <tr>
    <td>{{ entity.fcEntity.attributes.name }}</td>
    <td>{{ entity.fcEntity.attributes.adminSt }}</td>
    <td>{{ entity.fcEntity.attributes.childAction }}</td>
    <td>{{ entity.fcEntity.attributes.dn }}</td>
    <td>{{ entity.fcEntity.attributes.modTs }}</td>
    <td>{{ entity.fcEntity.attributes.monPolDn }}</td>
    <td>{{ entity.fcEntity.attributes.operErr }}</td>
    <td>{{ entity.fcEntity.attributes.operSt }}</td>
    <td>{{ entity.fcEntity.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "firmwareCardRunning" in api %}
<h1>Firmware Card Running</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>BIOS Version</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>Expected Version</th>
    <th>Interim Version</th>
    <th>Internal Label</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>sr Firmware Flash Rec Version</th>
    <th>sr Firmware Flash Version</th>
    <th>sr Firmware Image Version</th>
    <th>sr Firmware Running Source</th>
    <th>sr Firmware Running Version</th>
    <th>Status</th>
    <th>Timestamp</th>
    <th>Type</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>
{%-     for card in data_to_template['imdata'] %}
  <tr>
    <td>{{ card.firmwareCardRunning.attributes.dn }}</td>
    <td>{{ card.firmwareCardRunning.attributes.biosVer }}</td>
    <td>{{ card.firmwareCardRunning.attributes.childAction }}</td>
    <td>{{ card.firmwareCardRunning.attributes.descr }}</td>
    <td>{{ card.firmwareCardRunning.attributes.expectedVer }}</td>
    <td>{{ card.firmwareCardRunning.attributes.interimVer }}</td>
    <td>{{ card.firmwareCardRunning.attributes.internalLabel }}</td>
    <td>{{ card.firmwareCardRunning.attributes.modTs }}</td>
    <td>{{ card.firmwareCardRunning.attributes.mode }}</td>
    <td>{{ card.firmwareCardRunning.attributes.monPolDn }}</td>
    <td>{{ card.firmwareCardRunning.attributes.operSt }}</td>
    <td>{{ card.firmwareCardRunning.attributes.srFwFlashRecVer }}</td>
    <td>{{ card.firmwareCardRunning.attributes.srFwFlashVer }}</td>
    <td>{{ card.firmwareCardRunning.attributes.srFwImageVer }}</td>
    <td>{{ card.firmwareCardRunning.attributes.srFwRunningSrc }}</td>
    <td>{{ card.firmwareCardRunning.attributes.srFwRunningVer }}</td>
    <td>{{ card.firmwareCardRunning.attributes.status }}</td>
    <td>{{ card.firmwareCardRunning.attributes.ts }}</td>
    <td>{{ card.firmwareCardRunning.attributes.type }}</td>
    <td>{{ card.firmwareCardRunning.attributes.version }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "firmwareCompRunning" in api %}
<h1>Firmware Compute Running</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>Expected Version</th>
    <th>Internal Label</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Status</th>
    <th>Timestamp</th>
    <th>Type</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>
{%-     for compute in data_to_template['imdata'] %}
  <tr>
    <td>{{ compute.firmwareCompRunning.attributes.dn }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.childAction }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.descr }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.expectedVer }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.internalLabel }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.modTs }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.mode }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.monPolDn }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.operSt }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.status }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.ts }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.type }}</td>
    <td>{{ compute.firmwareCompRunning.attributes.version }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "firmwareRunning" in api %}
<h1>Firmware Running</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>BIOS Timestamp</th>
    <th>BIOS Version</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>Internal Label</th>
    <th>Kickstart File</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>PE Version</th>
    <th>sr Firmware Flash Rec Timestamp</th>
    <th>sr Firmware Flash Rec Version</th>
    <th>sr Firmware Flash Timestamp</th>
    <th>sr Firmware Flash Version</th>
    <th>sr Firmware Image Timestamp</th>
    <th>sr Firmware Image Version</th>
    <th>sr Firmware Running Source</th>
    <th>sr Firmware Running Version</th>
    <th>Status</th>
    <th>System File</th>
    <th>Timestamp</th>
    <th>Type</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>
{%-     for firmware in data_to_template['imdata'] %}
  <tr>
    <td>{{ firmware.firmwareRunning.attributes.dn }}</td>
    <td>{{ firmware.firmwareRunning.attributes.biosTs }}</td>
    <td>{{ firmware.firmwareRunning.attributes.biosVer }}</td>
    <td>{{ firmware.firmwareRunning.attributes.childAction }}</td>
    <td>{{ firmware.firmwareRunning.attributes.descr }}</td>
    <td>{{ firmware.firmwareRunning.attributes.internalLabel }}</td>
    <td>{{ firmware.firmwareRunning.attributes.ksFile }}</td>
    <td>{{ firmware.firmwareRunning.attributes.modTs }}</td>
    <td>{{ firmware.firmwareRunning.attributes.mode }}</td>
    <td>{{ firmware.firmwareRunning.attributes.peVer }}</td>
    <td>{{ firmware.firmwareRunning.attributes.srFwFlashRecTs }}</td>
    <td>{{ firmware.firmwareRunning.attributes.srFwFlashRecVer }}</td>
    <td>{{ firmware.firmwareRunning.attributes.srFwFlashTs }}</td>
    <td>{{ firmware.firmwareRunning.attributes.srFwFlashVer }}</td>
    <td>{{ firmware.firmwareRunning.attributes.srFwImageTs }}</td>
    <td>{{ firmware.firmwareRunning.attributes.srFwImageVer }}</td>
    <td>{{ firmware.firmwareRunning.attributes.srFwRunningSrc }}</td>
    <td>{{ firmware.firmwareRunning.attributes.srFwRunningVer }}</td>
    <td>{{ firmware.firmwareRunning.attributes.status }}</td>
    <td>{{ firmware.firmwareRunning.attributes.sysFile }}</td>
    <td>{{ firmware.firmwareRunning.attributes.ts }}</td>
    <td>{{ firmware.firmwareRunning.attributes.type }}</td>
    <td>{{ firmware.firmwareRunning.attributes.version }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvEpPCont" in api %}
<h1>Endpoint Profile Containers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Aggregation Enabled</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for container in data_to_template['imdata'] %}
  <tr>
    <td>{{ container.fvEpPCont.attributes.name }}</td>
    <td>{{ container.fvEpPCont.attributes.nameAlias }}</td>
    <td>{{ container.fvEpPCont.attributes.aggrEnabled }}</td>
    <td>{{ container.fvEpPCont.attributes.childAction }}</td>
    <td>{{ container.fvEpPCont.attributes.dn }}</td>
    <td>{{ container.fvEpPCont.attributes.lcOwn }}</td>
    <td>{{ container.fvEpPCont.attributes.modTs }}</td>
    <td>{{ container.fvEpPCont.attributes.monPolDn }}</td>
    <td>{{ container.fvEpPCont.attributes.ownerKey }}</td>
    <td>{{ container.fvEpPCont.attributes.ownerTag }}</td>
    <td>{{ container.fvEpPCont.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvLocale" in api %}
<h1>Locales</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>ID</th>
    <th>Boostrap Triggered</th>
    <th>Child Action</th>
    <th>Deploy All Ports</th>
    <th>DN</th>
    <th>Fabric Ext Control Peering</th>
    <th>Fabric Ext Intersite Control Peering</th>
    <th>Fabric Ext Intersite Peering</th>
    <th>First Update Deployed</th>
    <th>Instruction Immediacy</th>
    <th>IPv4 Load Balancer Address</th>
    <th>IPv6 Load Balancer Address</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Mode Misconfiguration</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Router ID</th>
    <th>Router ID Loopback</th>
    <th>Status</th>
    <th>Summary Needed</th>
  </tr>
</thead>
<tbody>
{%-     for locale in data_to_template['imdata'] %}
  <tr>
    <td>{{ locale.fvLocale.attributes.id }}</td>
    <td>{{ locale.fvLocale.attributes.boostrapTriggered }}</td>
    <td>{{ locale.fvLocale.attributes.childAction }}</td>
    <td>{{ locale.fvLocale.attributes.deployAllPorts }}</td>
    <td>{{ locale.fvLocale.attributes.dn }}</td>
    <td>{{ locale.fvLocale.attributes.fabricExtCtrlPeering }}</td>
    <td>{{ locale.fvLocale.attributes.fabricExtIntersiteCtrlPeering }}</td>
    <td>{{ locale.fvLocale.attributes.fabricExtIntersitePeering }}</td>
    <td>{{ locale.fvLocale.attributes.firstUpdateDeployed }}</td>
    <td>{{ locale.fvLocale.attributes.instrImedcy }}</td>
    <td>{{ locale.fvLocale.attributes.ipv4LbAddr }}</td>
    <td>{{ locale.fvLocale.attributes.ipv6LbAddr }}</td>
    <td>{{ locale.fvLocale.attributes.lcOwn }}</td>
    <td>{{ locale.fvLocale.attributes.modTs }}</td>
    <td>{{ locale.fvLocale.attributes.modeMisconfiguration }}</td>
    <td>{{ locale.fvLocale.attributes.monPolDn }}</td>
    <td>{{ locale.fvLocale.attributes.operSt }}</td>
    <td>{{ locale.fvLocale.attributes.rtrId }}</td>
    <td>{{ locale.fvLocale.attributes.rtrIdLoopBack }}</td>
    <td>{{ locale.fvLocale.attributes.status }}</td>
    <td>{{ locale.fvLocale.attributes.summaryNeeded }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvRsBDToOut" in api %}
<h1>Bridge Domains To Outside</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tContext DN</th>
    <th>tDN</th>
    <th>tRN</th>
    <th>tType</th>
    <th>tn L3 Ext Out Name</th>
  </tr>
</thead>
<tbody>
{%-     for bd in data_to_template['imdata'] %}
  <tr>
    <td>{{ bd.fvRsBDToOut.attributes.uid }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.annotation }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.childAction }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.dn }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.extMngdBy }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.forceResolve }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.lcOwn }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.modTs }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.monPolDn }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.rType }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.state }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.stateQual }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.status }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.tCl }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.tContextDn }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.tDn }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.tRn }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.tType }}</td>
    <td>{{ bd.fvRsBDToOut.attributes.tnL3extOutName }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvRsBd" in api %}
<h1>EPG Bridge Domain Links</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tContext DN</th>
    <th>tDN</th>
    <th>tRN</th>
    <th>tType</th>
    <th>tnFvBDName</th>
  </tr>
</thead>
<tbody>
{%-     for bd in data_to_template['imdata'] %}
  <tr>
    <td>{{ bd.fvRsBd.attributes.uid }}</td>
    <td>{{ bd.fvRsBd.attributes.annotation }}</td>
    <td>{{ bd.fvRsBd.attributes.childAction }}</td>
    <td>{{ bd.fvRsBd.attributes.dn }}</td>
    <td>{{ bd.fvRsBd.attributes.extMngdBy }}</td>
    <td>{{ bd.fvRsBd.attributes.forceResolve }}</td>
    <td>{{ bd.fvRsBd.attributes.lcOwn }}</td>
    <td>{{ bd.fvRsBd.attributes.modTs }}</td>
    <td>{{ bd.fvRsBd.attributes.monPolDn }}</td>
    <td>{{ bd.fvRsBd.attributes.rType }}</td>
    <td>{{ bd.fvRsBd.attributes.state }}</td>
    <td>{{ bd.fvRsBd.attributes.stateQual }}</td>
    <td>{{ bd.fvRsBd.attributes.status }}</td>
    <td>{{ bd.fvRsBd.attributes.tCl }}</td>
    <td>{{ bd.fvRsBd.attributes.tContextDn }}</td>
    <td>{{ bd.fvRsBd.attributes.tDn }}</td>
    <td>{{ bd.fvRsBd.attributes.tRn }}</td>
    <td>{{ bd.fvRsBd.attributes.tType }}</td>
    <td>{{ bd.fvRsBd.attributes.tnFvBDName }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvRsCEpToPathEp" in api %}
<h1>Endpoints To Paths</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Force Resolve</th>
    <th>lcC</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.dn }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.childAction }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.forceResolve }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.lcC }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.lcOwn }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.modTs }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.rType }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.state }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.stateQual }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.status }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.tCl }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.tDn }}</td>
    <td>{{ endpoint.fvRsCEpToPathEp.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvRsCons" in api %}
{%-     if "If" in api %}
<h1>Contract Consumer Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Deployment Info</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Priority</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tContext DN</th>
    <th>tDN</th>
    <th>tRN</th>
    <th>tType</th>
    <th>tnVz CP Interface Name</th>
    <th>Update Collection</th>
  </tr>
</thead>
<tbody>
{%-         for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.fvRsConsIf.attributes.uid }}</td>
    <td>{{ interface.fvRsConsIf.attributes.annotation }}</td>
    <td>{{ interface.fvRsConsIf.attributes.childAction }}</td>
    <td>{{ interface.fvRsConsIf.attributes.deplInfo }}</td>
    <td>{{ interface.fvRsConsIf.attributes.dn }}</td>
    <td>{{ interface.fvRsConsIf.attributes.extMngdBy }}</td>
    <td>{{ interface.fvRsConsIf.attributes.forceResolve }}</td>
    <td>{{ interface.fvRsConsIf.attributes.lcOwn }}</td>
    <td>{{ interface.fvRsConsIf.attributes.modTs }}</td>
    <td>{{ interface.fvRsConsIf.attributes.monPolDn }}</td>
    <td>{{ interface.fvRsConsIf.attributes.prio }}</td>
    <td>{{ interface.fvRsConsIf.attributes.rType }}</td>
    <td>{{ interface.fvRsConsIf.attributes.state }}</td>
    <td>{{ interface.fvRsConsIf.attributes.stateQual }}</td>
    <td>{{ interface.fvRsConsIf.attributes.status }}</td>
    <td>{{ interface.fvRsConsIf.attributes.tCl }}</td>
    <td>{{ interface.fvRsConsIf.attributes.tContextDn }}</td>
    <td>{{ interface.fvRsConsIf.attributes.tDn }}</td>
    <td>{{ interface.fvRsConsIf.attributes.tRn }}</td>
    <td>{{ interface.fvRsConsIf.attributes.tType }}</td>
    <td>{{ interface.fvRsConsIf.attributes.tnVzCPIfName }}</td>
    <td>{{ interface.fvRsConsIf.attributes.updateCollection }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>Contract Consumers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Contract Update</th>
    <th>Deployment Info</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Intent</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Priority</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tContext DN</th>
    <th>tDN</th>
    <th>tRN</th>
    <th>tType</th>
    <th>tnVz Br CP Name</th>
    <th>Trigger State</th>
    <th>Update Collection</th>
  </tr>
</thead>
<tbody>
{%-         for consumer in data_to_template['imdata'] %}
  <tr>
    <td>{{ consumer.fvRsCons.attributes.uid }}</td>
    <td>{{ consumer.fvRsCons.attributes.annotation }}</td>
    <td>{{ consumer.fvRsCons.attributes.childAction }}</td>
    <td>{{ consumer.fvRsCons.attributes.ctrctUpd }}</td>
    <td>{{ consumer.fvRsCons.attributes.deplInfo }}</td>
    <td>{{ consumer.fvRsCons.attributes.dn }}</td>
    <td>{{ consumer.fvRsCons.attributes.extMngdBy }}</td>
    <td>{{ consumer.fvRsCons.attributes.forceResolve }}</td>
    <td>{{ consumer.fvRsCons.attributes.intent }}</td>
    <td>{{ consumer.fvRsCons.attributes.lcOwn }}</td>
    <td>{{ consumer.fvRsCons.attributes.modTs }}</td>
    <td>{{ consumer.fvRsCons.attributes.monPolDn }}</td>
    <td>{{ consumer.fvRsCons.attributes.prio }}</td>
    <td>{{ consumer.fvRsCons.attributes.rType }}</td>
    <td>{{ consumer.fvRsCons.attributes.state }}</td>
    <td>{{ consumer.fvRsCons.attributes.stateQual }}</td>
    <td>{{ consumer.fvRsCons.attributes.status }}</td>
    <td>{{ consumer.fvRsCons.attributes.tCl }}</td>
    <td>{{ consumer.fvRsCons.attributes.tContextDn }}</td>
    <td>{{ consumer.fvRsCons.attributes.tDn }}</td>
    <td>{{ consumer.fvRsCons.attributes.tRn }}</td>
    <td>{{ consumer.fvRsCons.attributes.tType }}</td>
    <td>{{ consumer.fvRsCons.attributes.tnVzBrCPName }}</td>
    <td>{{ consumer.fvRsCons.attributes.triggerSt }}</td>
    <td>{{ consumer.fvRsCons.attributes.updateCollection }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "fvRsCtx" in api %}
<h1>Context Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tContext DN</th>
    <th>tDN</th>
    <th>tRN</th>
    <th>tType</th>
    <th>tnFv Context Name</th>
  </tr>
</thead>
<tbody>
{%-     for context in data_to_template['imdata'] %}
  <tr>
    <td>{{ context.fvRsCtx.attributes.uid }}</td>
    <td>{{ context.fvRsCtx.attributes.annotation }}</td>
    <td>{{ context.fvRsCtx.attributes.childAction }}</td>
    <td>{{ context.fvRsCtx.attributes.dn }}</td>
    <td>{{ context.fvRsCtx.attributes.extMngdBy }}</td>
    <td>{{ context.fvRsCtx.attributes.forceResolve }}</td>
    <td>{{ context.fvRsCtx.attributes.lcOwn }}</td>
    <td>{{ context.fvRsCtx.attributes.modTs }}</td>
    <td>{{ context.fvRsCtx.attributes.monPolDn }}</td>
    <td>{{ context.fvRsCtx.attributes.rType }}</td>
    <td>{{ context.fvRsCtx.attributes.state }}</td>
    <td>{{ context.fvRsCtx.attributes.stateQual }}</td>
    <td>{{ context.fvRsCtx.attributes.status }}</td>
    <td>{{ context.fvRsCtx.attributes.tCl }}</td>
    <td>{{ context.fvRsCtx.attributes.tContextDn }}</td>
    <td>{{ context.fvRsCtx.attributes.tDn }}</td>
    <td>{{ context.fvRsCtx.attributes.tRn }}</td>
    <td>{{ context.fvRsCtx.attributes.tType }}</td>
    <td>{{ context.fvRsCtx.attributes.tnFvCtxName }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvRsDomAtt" in api %}
<h1>Domain Attachments</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Binding Type</th>
    <th>Child Action</th>
    <th>Class Preference</th>
    <th>Config Issues</th>
    <th>Custom EPG Name</th>
    <th>Delimiter</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>Encapsulation Mode</th>
    <th>EPG COS</th>
    <th>EPG COS Preference</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Instruction Immediacy</th>
    <th>LAG Policy Name</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>Netflow Direction</th>
    <th>Netflow Preference</th>
    <th>Number of Ports</th>
    <th>Port Allocation</th>
    <th>Primary Encapsulation</th>
    <th>Primary Encapsulation Inner</th>
    <th>rType</th>
    <th>Res Immediacy</th>
    <th>Secondary Encapsulation Inner</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>Switching Mode</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tType</th>
    <th>Trigger State</th>
    <th>TX ID</th>
    <th>Untagged</th>
    <th>VNET Only</th>
  </tr>
</thead>
<tbody>
{%-     for attachment in data_to_template['imdata'] %}
  <tr>
    <td>{{ attachment.fvRsDomAtt.attributes.uid }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.annotation }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.bindingType }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.childAction }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.classPref }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.configIssues }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.customEpgName }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.delimiter }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.dn }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.encap }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.encapMode }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.epgCos }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.epgCosPref }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.extMngdBy }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.forceResolve }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.instrImedcy }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.lagPolicyName }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.lcOwn }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.modTs }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.mode }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.monPolDn }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.netflowDir }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.netflowPref }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.numPorts }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.portAllocation }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.primaryEncap }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.primaryEncapInner }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.rType }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.resImedcy }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.secondaryEncapInner }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.state }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.stateQual }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.status }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.switchingMode }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.tCl }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.tDn }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.tType }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.triggerSt }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.txId }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.untagged }}</td>
    <td>{{ attachment.fvRsDomAtt.attributes.vnetOnly }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvRsPathAtt" in api %}
<h1>Path Attachments</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Instruction Immediacy</th>
    <th>lcC</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>Primary Encapsulation</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for attachment in data_to_template['imdata'] %}
  <tr>
    <td>{{ attachment.fvRsPathAtt.attributes.uid }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.annotation }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.childAction }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.descr }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.dn }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.encap }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.extMngdBy }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.forceResolve }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.instrImedcy }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.lcC }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.lcOwn }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.modTs }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.mode }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.monPolDn }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.primaryEncap }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.rType }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.state }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.stateQual }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.status }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.tCl }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.tDn }}</td>
    <td>{{ attachment.fvRsPathAtt.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvRsProv" in api %}
<h1>Contract Providers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Contract Update</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Intent</th>
    <th>Local Owner</th>
    <th>Match Type</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Priority</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tContext DN</th>
    <th>tDN</th>
    <th>tRN</th>
    <th>tType</th>
    <th>tnVz Br CP Name</th>
    <th>Trigger State</th>
    <th>Update Collection</th>
  </tr>
</thead>
<tbody>
{%-     for provider in data_to_template['imdata'] %}
  <tr>
    <td>{{ provider.fvRsProv.attributes.uid }}</td>
    <td>{{ provider.fvRsProv.attributes.annotation }}</td>
    <td>{{ provider.fvRsProv.attributes.childAction }}</td>
    <td>{{ provider.fvRsProv.attributes.ctrctUpd }}</td>
    <td>{{ provider.fvRsProv.attributes.dn }}</td>
    <td>{{ provider.fvRsProv.attributes.extMngdBy }}</td>
    <td>{{ provider.fvRsProv.attributes.forceResolve }}</td>
    <td>{{ provider.fvRsProv.attributes.intent }}</td>
    <td>{{ provider.fvRsProv.attributes.lcOwn }}</td>
    <td>{{ provider.fvRsProv.attributes.matchT }}</td>
    <td>{{ provider.fvRsProv.attributes.modTs }}</td>
    <td>{{ provider.fvRsProv.attributes.monPolDn }}</td>
    <td>{{ provider.fvRsProv.attributes.prio }}</td>
    <td>{{ provider.fvRsProv.attributes.rType }}</td>
    <td>{{ provider.fvRsProv.attributes.state }}</td>
    <td>{{ provider.fvRsProv.attributes.stateQual }}</td>
    <td>{{ provider.fvRsProv.attributes.status }}</td>
    <td>{{ provider.fvRsProv.attributes.tCl }}</td>
    <td>{{ provider.fvRsProv.attributes.tContextDn }}</td>
    <td>{{ provider.fvRsProv.attributes.tDn }}</td>
    <td>{{ provider.fvRsProv.attributes.tRn }}</td>
    <td>{{ provider.fvRsProv.attributes.tType }}</td>
    <td>{{ provider.fvRsProv.attributes.tnVzBrCPName }}</td>
    <td>{{ provider.fvRsProv.attributes.triggerSt }}</td>
    <td>{{ provider.fvRsProv.attributes.updateCollection }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvRtBd" in api %}
<h1>Bridge Domain Target Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
  </tr>
</thead>
<tbody>
{%-     for bd in data_to_template['imdata'] %}
  <tr>
    <td>{{ bd.fvRtBd.attributes.dn }}</td>
    <td>{{ bd.fvRtBd.attributes.childAction }}</td>
    <td>{{ bd.fvRtBd.attributes.lcOwn }}</td>
    <td>{{ bd.fvRtBd.attributes.modTs }}</td>
    <td>{{ bd.fvRtBd.attributes.status }}</td>
    <td>{{ bd.fvRtBd.attributes.tCl }}</td>
    <td>{{ bd.fvRtBd.attributes.tDn }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvRtCtx" in api %}
<h1>Contexts Target Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
  </tr>
</thead>
<tbody>
{%-     for context in data_to_template['imdata'] %}
  <tr>
    <td>{{ context.fvRtCtx.attributes.dn }}</td>
    <td>{{ context.fvRtCtx.attributes.childAction }}</td>
    <td>{{ context.fvRtCtx.attributes.lcOwn }}</td>
    <td>{{ context.fvRtCtx.attributes.modTs }}</td>
    <td>{{ context.fvRtCtx.attributes.status }}</td>
    <td>{{ context.fvRtCtx.attributes.tCl }}</td>
    <td>{{ context.fvRtCtx.attributes.tDn }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvnsEncapBlk" in api %}
<h1>VLAN Encapsulation Blocks</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Allocation Mode</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>From</th>
    <th>To</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitroing Policy DN</th>
    <th>Role</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for vlan in data_to_template['imdata'] %}
  <tr>
    <td>{{ vlan.fvnsEncapBlk.attributes.name }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.nameAlias }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.allocMode }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.annotation }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.childAction }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.descr }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.dn }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.extMngdBy }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.from }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.to }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.lcOwn }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.modTs }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.monPolDn }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.role }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.status }}</td>
    <td>{{ vlan.fvnsEncapBlk.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "fvnsVlanInstP" in api %}
<h1>VLAN Namespace Policies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Allocation Mode</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Config Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for policy in data_to_template['imdata'] %}
  <tr>
    <td>{{ policy.fvnsVlanInstP.attributes.name }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.nameAlias }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.allocMode }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.annotation }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.childAction }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.configIssues }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.descr }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.dn }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.extMngdBy }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.lcOwn }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.modTs }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.monPolDn }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.ownerKey }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.ownerTag }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.status }}</td>
    <td>{{ policy.fvnsVlanInstP.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraAccBndlGrp" in api %}
<h1>Access Bundle Groups</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>LAG Type</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for group in data_to_template['imdata'] %}
  <tr>
    <td>{{ group.infraAccBndlGrp.attributes.name }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.nameAlias }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.annotation }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.childAction }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.descr }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.dn }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.extMngdBy }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.lagT }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.lcOwn }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.modTs }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.monPolDn }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.ownerKey }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.ownerTag }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.status }}</td>
    <td>{{ group.infraAccBndlGrp.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraAccPortGrp" in api %}
<h1>Access Port Groups</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for group in data_to_template['imdata'] %}
  <tr>
    <td>{{ group.infraAccPortGrp.attributes.name }}</td>
    <td>{{ group.infraAccPortGrp.attributes.nameAlias }}</td>
    <td>{{ group.infraAccPortGrp.attributes.annotation }}</td>
    <td>{{ group.infraAccPortGrp.attributes.childAction }}</td>
    <td>{{ group.infraAccPortGrp.attributes.descr }}</td>
    <td>{{ group.infraAccPortGrp.attributes.dn }}</td>
    <td>{{ group.infraAccPortGrp.attributes.extMngdBy }}</td>
    <td>{{ group.infraAccPortGrp.attributes.lcOwn }}</td>
    <td>{{ group.infraAccPortGrp.attributes.modTs }}</td>
    <td>{{ group.infraAccPortGrp.attributes.monPolDn }}</td>
    <td>{{ group.infraAccPortGrp.attributes.ownerKey }}</td>
    <td>{{ group.infraAccPortGrp.attributes.ownerTag }}</td>
    <td>{{ group.infraAccPortGrp.attributes.status }}</td>
    <td>{{ group.infraAccPortGrp.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraAccPortP" in api %}
<h1>Access Port Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraAccPortP.attributes.name }}</td>
    <td>{{ profile.infraAccPortP.attributes.nameAlias }}</td>
    <td>{{ profile.infraAccPortP.attributes.annotation }}</td>
    <td>{{ profile.infraAccPortP.attributes.childAction }}</td>
    <td>{{ profile.infraAccPortP.attributes.descr }}</td>
    <td>{{ profile.infraAccPortP.attributes.dn }}</td>
    <td>{{ profile.infraAccPortP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraAccPortP.attributes.lcOwn }}</td>
    <td>{{ profile.infraAccPortP.attributes.modTs }}</td>
    <td>{{ profile.infraAccPortP.attributes.monPolDn }}</td>
    <td>{{ profile.infraAccPortP.attributes.ownerKey }}</td>
    <td>{{ profile.infraAccPortP.attributes.ownerTag }}</td>
    <td>{{ profile.infraAccPortP.attributes.status }}</td>
    <td>{{ profile.infraAccPortP.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraCont" in api %}
<h1>Controllers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>DRR Mode</th>
    <th>DSCV Mode</th>
    <th>Fabric Domain Name</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Size</th>
    <th>Status</th>
    <th>Start Timestamp</th>
    <th>UCT Difference</th>
  </tr>
</thead>
<tbody>
{%-     for controller in data_to_template['imdata'] %}
  <tr>
    <td>{{ controller.infraCont.attributes.name }}</td>
    <td>{{ controller.infraCont.attributes.nameAlias }}</td>
    <td>{{ controller.infraCont.attributes.childAction }}</td>
    <td>{{ controller.infraCont.attributes.dn }}</td>
    <td>{{ controller.infraCont.attributes.drrMd }}</td>
    <td>{{ controller.infraCont.attributes.dscvMd }}</td>
    <td>{{ controller.infraCont.attributes.fbDmNm }}</td>
    <td>{{ controller.infraCont.attributes.lcOwn }}</td>
    <td>{{ controller.infraCont.attributes.modTs }}</td>
    <td>{{ controller.infraCont.attributes.monPolDn }}</td>
    <td>{{ controller.infraCont.attributes.size }}</td>
    <td>{{ controller.infraCont.attributes.status }}</td>
    <td>{{ controller.infraCont.attributes.strtTs }}</td>
    <td>{{ controller.infraCont.attributes.uctDiff }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraFexP" in api %}
<h1>FEX Policies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for policy in data_to_template['imdata'] %}
  <tr>
    <td>{{ policy.infraFexP.attributes.name }}</td>
    <td>{{ policy.infraFexP.attributes.nameAlias }}</td>
    <td>{{ policy.infraFexP.attributes.annotation }}</td>
    <td>{{ policy.infraFexP.attributes.childAction }}</td>
    <td>{{ policy.infraFexP.attributes.descr }}</td>
    <td>{{ policy.infraFexP.attributes.dn }}</td>
    <td>{{ policy.infraFexP.attributes.extMngdBy }}</td>
    <td>{{ policy.infraFexP.attributes.lcOwn }}</td>
    <td>{{ policy.infraFexP.attributes.modTs }}</td>
    <td>{{ policy.infraFexP.attributes.monPolDn }}</td>
    <td>{{ policy.infraFexP.attributes.ownerKey }}</td>
    <td>{{ policy.infraFexP.attributes.ownerTag }}</td>
    <td>{{ policy.infraFexP.attributes.status }}</td>
    <td>{{ policy.infraFexP.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraFuncP" in api %}
<h1>Function Policies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for function in data_to_template['imdata'] %}
  <tr>
    <td>{{ function.infraFuncP.attributes.name }}</td>
    <td>{{ function.infraFuncP.attributes.nameAlias }}</td>
    <td>{{ function.infraFuncP.attributes.annotation }}</td>
    <td>{{ function.infraFuncP.attributes.childAction }}</td>
    <td>{{ function.infraFuncP.attributes.descr }}</td>
    <td>{{ function.infraFuncP.attributes.dn }}</td>
    <td>{{ function.infraFuncP.attributes.extMngdBy }}</td>
    <td>{{ function.infraFuncP.attributes.lcOwn }}</td>
    <td>{{ function.infraFuncP.attributes.modTs }}</td>
    <td>{{ function.infraFuncP.attributes.monPolDn }}</td>
    <td>{{ function.infraFuncP.attributes.ownerKey }}</td>
    <td>{{ function.infraFuncP.attributes.ownerTag }}</td>
    <td>{{ function.infraFuncP.attributes.status }}</td>
    <td>{{ function.infraFuncP.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraHPortS" in api %}
<h1>Host Port Selectors</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>Type</th>    
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for port in data_to_template['imdata'] %}
  <tr>
    <td>{{ port.infraHPortS.attributes.name }}</td>
    <td>{{ port.infraHPortS.attributes.nameAlias }}</td>
    <td>{{ port.infraHPortS.attributes.annotation }}</td>
    <td>{{ port.infraHPortS.attributes.childAction }}</td>
    <td>{{ port.infraHPortS.attributes.descr }}</td>
    <td>{{ port.infraHPortS.attributes.dn }}</td>
    <td>{{ port.infraHPortS.attributes.extMngdBy }}</td>
    <td>{{ port.infraHPortS.attributes.lcOwn }}</td>
    <td>{{ port.infraHPortS.attributes.modTs }}</td>
    <td>{{ port.infraHPortS.attributes.monPolDn }}</td>
    <td>{{ port.infraHPortS.attributes.ownerKey }}</td>
    <td>{{ port.infraHPortS.attributes.ownerTag }}</td>
    <td>{{ port.infraHPortS.attributes.status }}</td>
    <td>{{ port.infraHPortS.attributes.type }}</td>    
    <td>{{ port.infraHPortS.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraPortBlk" in api %}
<h1>Port Blocks</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>From Card</th>
    <th>To Card</th>
    <th>From Port</th>
    <th>To Port</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for port_block in data_to_template['imdata'] %}
  <tr>
    <td>{{ port_block.infraPortBlk.attributes.name }}</td>
    <td>{{ port_block.infraPortBlk.attributes.nameAlias }}</td>
    <td>{{ port_block.infraPortBlk.attributes.annotation }}</td>
    <td>{{ port_block.infraPortBlk.attributes.childAction }}</td>
    <td>{{ port_block.infraPortBlk.attributes.descr }}</td>
    <td>{{ port_block.infraPortBlk.attributes.dn }}</td>
    <td>{{ port_block.infraPortBlk.attributes.extMngdBy }}</td>
    <td>{{ port_block.infraPortBlk.attributes.fromCard }}</td>
    <td>{{ port_block.infraPortBlk.attributes.toCard }}</td>
    <td>{{ port_block.infraPortBlk.attributes.fromPort }}</td>
    <td>{{ port_block.infraPortBlk.attributes.toPort }}</td>
    <td>{{ port_block.infraPortBlk.attributes.lcOwn }}</td>
    <td>{{ port_block.infraPortBlk.attributes.modTs }}</td>
    <td>{{ port_block.infraPortBlk.attributes.monPolDn }}</td>
    <td>{{ port_block.infraPortBlk.attributes.status }}</td>
    <td>{{ port_block.infraPortBlk.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraRsAccBaseGrp" in api %}
<h1>Access Policy Group Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>FEX ID</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for policy in data_to_template['imdata'] %}
  <tr>
    <td>{{ policy.infraRsAccBaseGrp.attributes.uid }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.annotation }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.childAction }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.dn }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.extMngdBy }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.fexId }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.forceResolve }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.lcOwn }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.modTs }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.monPolDn }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.rType }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.state }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.stateQual }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.status }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.tCl }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.tDn }}</td>
    <td>{{ policy.infraRsAccBaseGrp.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraRsAttEntP" in api %}
<h1>Attachable Entity Profiles Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Is Using Connection Selector</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraRsAttEntP.attributes.uid }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.annotation }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.childAction }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.dn }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.forceResolve }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.isUsingConnSel }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.lcOwn }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.modTs }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.monPolDn }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.rType }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.state }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.stateQual }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.status }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.tCl }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.tDn }}</td>
    <td>{{ profile.infraRsAttEntP.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraRsDomP" in api %}
<h1>Domain Profiles Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraRsDomP.attributes.uid }}</td>
    <td>{{ profile.infraRsDomP.attributes.annotation }}</td>
    <td>{{ profile.infraRsDomP.attributes.childAction }}</td>
    <td>{{ profile.infraRsDomP.attributes.dn }}</td>
    <td>{{ profile.infraRsDomP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraRsDomP.attributes.forceResolve }}</td>
    <td>{{ profile.infraRsDomP.attributes.lcOwn }}</td>
    <td>{{ profile.infraRsDomP.attributes.modTs }}</td>
    <td>{{ profile.infraRsDomP.attributes.monPolDn }}</td>
    <td>{{ profile.infraRsDomP.attributes.rType }}</td>
    <td>{{ profile.infraRsDomP.attributes.state }}</td>
    <td>{{ profile.infraRsDomP.attributes.stateQual }}</td>
    <td>{{ profile.infraRsDomP.attributes.status }}</td>
    <td>{{ profile.infraRsDomP.attributes.tCl }}</td>
    <td>{{ profile.infraRsDomP.attributes.tDn }}</td>
    <td>{{ profile.infraRsDomP.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraRsSpAccGrp" in api %}
<h1>Spine Access Policy Groups</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for group in data_to_template['imdata'] %}
  <tr>
    <td>{{ group.infraRsSpAccGrp.attributes.uid }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.annotation }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.childAction }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.dn }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.extMngdBy }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.forceResolve }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.lcOwn }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.modTs }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.monPolDn }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.rType }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.state }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.stateQual }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.status }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.tCl }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.tDn }}</td>
    <td>{{ group.infraRsSpAccGrp.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraRsVlanNs" in api %}
<h1>VLAN Namespace Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for namespace in data_to_template['imdata'] %}
  <tr>
    <td>{{ namespace.infraRsVlanNs.attributes.uid }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.annotation }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.childAction }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.dn }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.extMngdBy }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.forceResolve }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.lcOwn }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.modTs }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.monPolDn }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.rType }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.state }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.stateQual }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.status }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.tCl }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.tDn }}</td>
    <td>{{ namespace.infraRsVlanNs.attributes.tType }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraSHPortS" in api %}
<h1>Spine Host Port Selector</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for selector in data_to_template['imdata'] %}
  <tr>
    <td>{{ selector.infraSHPortS.attributes.name }}</td>
    <td>{{ selector.infraSHPortS.attributes.nameAlias }}</td>
    <td>{{ selector.infraSHPortS.attributes.annotation }}</td>
    <td>{{ selector.infraSHPortS.attributes.childAction }}</td>
    <td>{{ selector.infraSHPortS.attributes.descr }}</td>
    <td>{{ selector.infraSHPortS.attributes.dn }}</td>
    <td>{{ selector.infraSHPortS.attributes.extMngdBy }}</td>
    <td>{{ selector.infraSHPortS.attributes.lcOwn }}</td>
    <td>{{ selector.infraSHPortS.attributes.modTs }}</td>
    <td>{{ selector.infraSHPortS.attributes.monPolDn }}</td>
    <td>{{ selector.infraSHPortS.attributes.ownerKey }}</td>
    <td>{{ selector.infraSHPortS.attributes.ownerTag }}</td>
    <td>{{ selector.infraSHPortS.attributes.status }}</td>
    <td>{{ selector.infraSHPortS.attributes.type }}</td>
    <td>{{ selector.infraSHPortS.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraSpAccPortP" in api %}
<h1>Spine Access Port Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraSpAccPortP.attributes.name }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.nameAlias }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.annotation }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.childAction }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.descr }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.dn }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.lcOwn }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.modTs }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.monPolDn }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.ownerKey }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.ownerTag }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.status }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "infraWiNode" in api %}
<h1>Wired Nodes</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Address</th>
    <th>Admin State</th>
    <th>Annotation</th>
    <th>APIC Mode</th>
    <th>Chassis</th>
    <th>Child Action</th>
    <th>Controller Sbst State</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Failover Status</th>
    <th>Health</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Motherboard Serial Number</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Mutn Timestamp</th>
    <th>Node Name</th>
    <th>Oper State</th>
    <th>Pod ID</th>
    <th>Routable IP Address</th>
    <th>Status</th>
    <th>Target Motherboard Serial Number</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for node in data_to_template['imdata'] %}
  <tr>
    <td>{{ node.infraWiNode.attributes.name }}</td>
    <td>{{ node.infraWiNode.attributes.nameAlias }}</td>
    <td>{{ node.infraWiNode.attributes.addr }}</td>
    <td>{{ node.infraWiNode.attributes.adminSt }}</td>
    <td>{{ node.infraWiNode.attributes.annotation }}</td>
    <td>{{ node.infraWiNode.attributes.apicMode }}</td>
    <td>{{ node.infraWiNode.attributes.chassis }}</td>
    <td>{{ node.infraWiNode.attributes.childAction }}</td>
    <td>{{ node.infraWiNode.attributes.cntrlSbstState }}</td>
    <td>{{ node.infraWiNode.attributes.dn }}</td>
    <td>{{ node.infraWiNode.attributes.extMngdBy }}</td>
    <td>{{ node.infraWiNode.attributes.failoverStatus }}</td>
    <td>{{ node.infraWiNode.attributes.health }}</td>
    <td>{{ node.infraWiNode.attributes.id }}</td>
    <td>{{ node.infraWiNode.attributes.lcOwn }}</td>
    <td>{{ node.infraWiNode.attributes.mbSn }}</td>
    <td>{{ node.infraWiNode.attributes.modTs }}</td>
    <td>{{ node.infraWiNode.attributes.monPolDn }}</td>
    <td>{{ node.infraWiNode.attributes.mutnTs }}</td>
    <td>{{ node.infraWiNode.attributes.nodeName }}</td>
    <td>{{ node.infraWiNode.attributes.operSt }}</td>
    <td>{{ node.infraWiNode.attributes.podId }}</td>
    <td>{{ node.infraWiNode.attributes.routableIpAddr }}</td>
    <td>{{ node.infraWiNode.attributes.status }}</td>
    <td>{{ node.infraWiNode.attributes.targetMbSn }}</td>
    <td>{{ node.infraWiNode.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "ipNexthopP" in api %}
<h1>Static Route Next Hop Policies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Next Hop Address</th>
    <th>Prefix</th>
    <th>Status</th>
    <th>Type</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for policy in data_to_template['imdata'] %}
  <tr>
    <td>{{ policy.ipNexthopP.attributes.name }}</td>
    <td>{{ policy.ipNexthopP.attributes.nameAlias }}</td>
    <td>{{ policy.ipNexthopP.attributes.annotation }}</td>
    <td>{{ policy.ipNexthopP.attributes.childAction }}</td>
    <td>{{ policy.ipNexthopP.attributes.descr }}</td>
    <td>{{ policy.ipNexthopP.attributes.dn }}</td>
    <td>{{ policy.ipNexthopP.attributes.extMngdBy }}</td>
    <td>{{ policy.ipNexthopP.attributes.lcOwn }}</td>
    <td>{{ policy.ipNexthopP.attributes.modTs }}</td>
    <td>{{ policy.ipNexthopP.attributes.monPolDn }}</td>
    <td>{{ policy.ipNexthopP.attributes.nhAddr }}</td>
    <td>{{ policy.ipNexthopP.attributes.pref }}</td>
    <td>{{ policy.ipNexthopP.attributes.status }}</td>
    <td>{{ policy.ipNexthopP.attributes.type }}</td>
    <td>{{ policy.ipNexthopP.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "ipRouteP" in api %}
<h1>Route Policies</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Aggregate</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>From Prefix Length</th>
    <th>To Prefix Length</th>
    <th>IP</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Prefix</th>
    <th>Route Control</th>
    <th>Status</th>
    <th>Type</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for policy in data_to_template['imdata'] %}
  <tr>
    <td>{{ policy.ipRouteP.attributes.name }}</td>
    <td>{{ policy.ipRouteP.attributes.nameAlias }}</td>
    <td>{{ policy.ipRouteP.attributes.aggregate }}</td>
    <td>{{ policy.ipRouteP.attributes.annotation }}</td>
    <td>{{ policy.ipRouteP.attributes.childAction }}</td>
    <td>{{ policy.ipRouteP.attributes.descr }}</td>
    <td>{{ policy.ipRouteP.attributes.dn }}</td>
    <td>{{ policy.ipRouteP.attributes.extMngdBy }}</td>
    <td>{{ policy.ipRouteP.attributes.fromPfxLen }}</td>
    <td>{{ policy.ipRouteP.attributes.toPfxLen }}</td>
    <td>{{ policy.ipRouteP.attributes.ip }}</td>
    <td>{{ policy.ipRouteP.attributes.lcOwn }}</td>
    <td>{{ policy.ipRouteP.attributes.modTs }}</td>
    <td>{{ policy.ipRouteP.attributes.monPolDn }}</td>
    <td>{{ policy.ipRouteP.attributes.pref }}</td>
    <td>{{ policy.ipRouteP.attributes.rtCtrl }}</td>
    <td>{{ policy.ipRouteP.attributes.status }}</td>
    <td>{{ policy.ipRouteP.attributes.type }}</td>
    <td>{{ policy.ipRouteP.attributes.uid }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "ipv4Addr" in api %}
<h1>IPv4 Addresses</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Address</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>DN</th>
    <th>IPv4 Config Failed Bmp</th>
    <th>IPv4 Config Failed Timestamp</th>
    <th>IPv4 Config State</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Oper State Quality</th>
    <th>Prefix</th>
    <th>Status</th>
    <th>Tag</th>
    <th>Type</th>
    <th>vPC Peer</th>
  </tr>
</thead>
<tbody>
{%-     for address in data_to_template['imdata'] %}
  <tr>
    <td>{{ address.ipv4Addr.attributes.addr }}</td>
    <td>{{ address.ipv4Addr.attributes.childAction }}</td>
    <td>{{ address.ipv4Addr.attributes.ctrl }}</td>
    <td>{{ address.ipv4Addr.attributes.dn }}</td>
    <td>{{ address.ipv4Addr.attributes.ipv4CfgFailedBmp }}</td>
    <td>{{ address.ipv4Addr.attributes.ipv4CfgFailedTs }}</td>
    <td>{{ address.ipv4Addr.attributes.ipv4CfgState }}</td>
    <td>{{ address.ipv4Addr.attributes.lcOwn }}</td>
    <td>{{ address.ipv4Addr.attributes.modTs }}</td>
    <td>{{ address.ipv4Addr.attributes.monPolDn }}</td>
    <td>{{ address.ipv4Addr.attributes.operSt }}</td>
    <td>{{ address.ipv4Addr.attributes.operStQual }}</td>
    <td>{{ address.ipv4Addr.attributes.pref }}</td>
    <td>{{ address.ipv4Addr.attributes.status }}</td>
    <td>{{ address.ipv4Addr.attributes.tag }}</td>
    <td>{{ address.ipv4Addr.attributes.type }}</td>
    <td>{{ address.ipv4Addr.attributes.vpcPeer }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "ipv4Dom" in api %}
<h1>IPv4 Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Router ID</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.ipv4Dom.attributes.name }}</td>
    <td>{{ domain.ipv4Dom.attributes.childAction }}</td>
    <td>{{ domain.ipv4Dom.attributes.dn }}</td>
    <td>{{ domain.ipv4Dom.attributes.encap }}</td>
    <td>{{ domain.ipv4Dom.attributes.lcOwn }}</td>
    <td>{{ domain.ipv4Dom.attributes.modTs }}</td>
    <td>{{ domain.ipv4Dom.attributes.monPolDn }}</td>
    <td>{{ domain.ipv4Dom.attributes.rtrId }}</td>
    <td>{{ domain.ipv4Dom.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "ipv4Entity" in api %}
<h1>IPv4 Entities</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Oper State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for entity in data_to_template['imdata'] %}
  <tr>
    <td>{{ entity.ipv4Entity.attributes.name }}</td>
    <td>{{ entity.ipv4Entity.attributes.adminSt }}</td>
    <td>{{ entity.ipv4Entity.attributes.childAction }}</td>
    <td>{{ entity.ipv4Entity.attributes.dn }}</td>
    <td>{{ entity.ipv4Entity.attributes.lcOwn }}</td>
    <td>{{ entity.ipv4Entity.attributes.modTs }}</td>
    <td>{{ entity.ipv4Entity.attributes.monPolDn }}</td>
    <td>{{ entity.ipv4Entity.attributes.operErr }}</td>
    <td>{{ entity.ipv4Entity.attributes.operSt }}</td>
    <td>{{ entity.ipv4Entity.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "ipv4If" in api %}
<h1>IPv4 Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>Description</th>
    <th>DN</th>
    <th>Donor Interface</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Mode External</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.ipv4If.attributes.name }}</td>
    <td>{{ interface.ipv4If.attributes.adminSt }}</td>
    <td>{{ interface.ipv4If.attributes.childAction }}</td>
    <td>{{ interface.ipv4If.attributes.ctrl }}</td>
    <td>{{ interface.ipv4If.attributes.descr }}</td>
    <td>{{ interface.ipv4If.attributes.dn }}</td>
    <td>{{ interface.ipv4If.attributes.donorIf }}</td>
    <td>{{ interface.ipv4If.attributes.id }}</td>
    <td>{{ interface.ipv4If.attributes.lcOwn }}</td>
    <td>{{ interface.ipv4If.attributes.modTs }}</td>
    <td>{{ interface.ipv4If.attributes.mode }}</td>
    <td>{{ interface.ipv4If.attributes.modeExtn }}</td>
    <td>{{ interface.ipv4If.attributes.monPolDn }}</td>
    <td>{{ interface.ipv4If.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "ipv4Inst" in api %}
<h1>IPv4 Instances</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for instance in data_to_template['imdata'] %}
  <tr>
    <td>{{ instance.ipv4Inst.attributes.name }}</td>
    <td>{{ instance.ipv4Inst.attributes.adminSt }}</td>
    <td>{{ instance.ipv4Inst.attributes.childAction }}</td>
    <td>{{ instance.ipv4Inst.attributes.ctrl }}</td>
    <td>{{ instance.ipv4Inst.attributes.dn }}</td>
    <td>{{ instance.ipv4Inst.attributes.lcOwn }}</td>
    <td>{{ instance.ipv4Inst.attributes.modTs }}</td>
    <td>{{ instance.ipv4Inst.attributes.monPolDn }}</td>
    <td>{{ instance.ipv4Inst.attributes.operErr }}</td>
    <td>{{ instance.ipv4Inst.attributes.status }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "ipv4Nexthop" in api %}
<h1>IPv4 Next Hop</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Logical DN</th>
    <th>Cached Route Control</th>
    <th>Child Action</th>
    <th>Context ID</th>
    <th>Control</th>
    <th>Description</th>
    <th>DN</th>
    <th>Flags</th>
    <th>IPv4 Config Failed Bmp</th>
    <th>IPv4 Config Failed Timestamps</th>
    <th>IPv4 Config State</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Next Hop Address</th>
    <th>Next Hop Interface</th>
    <th>Next Hop VRF</th>
    <th>Oper State</th>
    <th>Oper State Quality</th>
    <th>Prefix</th>
    <th>RW Encapsulation</th>
    <th>Status</th>
    <th>Track ID</th>
  </tr>
</thead>
<tbody>
{%-     for nexthop in data_to_template['imdata'] %}
  <tr>
    <td>{{ nexthop.ipv4Nexthop.attributes.name }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.nameAlias }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.LogicalDn }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.cachedRtCtrl }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.childAction }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.contextId }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.ctrl }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.descr }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.dn }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.flags }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.ipv4CfgFailedBmp }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.ipv4CfgFailedTs }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.ipv4CfgState }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.lcOwn }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.modTs }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.monPolDn }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.nhAddr }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.nhIf }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.nhVrf }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.operSt }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.operStQual }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.pref }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.rwEncap }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.status }}</td>
    <td>{{ nexthop.ipv4Nexthop.attributes.trackId }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "ipv4Route" in api %}
<h1>IPv4 Routes</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>Description</th>
    <th>DN</th>
    <th>Flush Count</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>PC Tag</th>
    <th>Preference</th>
    <th>Prefix</th>
    <th>Shared Cons Count</th>
    <th>Status</th>
    <th>Tag</th>
    <th>Track ID</th>
  </tr>
</thead>
<tbody>
{%-     for route in data_to_template['imdata'] %}
  <tr>
    <td>{{ route.ipv4Route.attributes.name }}</td>
    <td>{{ route.ipv4Route.attributes.nameAlias }}</td>
    <td>{{ route.ipv4Route.attributes.childAction }}</td>
    <td>{{ route.ipv4Route.attributes.ctrl }}</td>
    <td>{{ route.ipv4Route.attributes.descr }}</td>
    <td>{{ route.ipv4Route.attributes.dn }}</td>
    <td>{{ route.ipv4Route.attributes.flushCount }}</td>
    <td>{{ route.ipv4Route.attributes.lcOwn }}</td>
    <td>{{ route.ipv4Route.attributes.modTs }}</td>
    <td>{{ route.ipv4Route.attributes.monPolDn }}</td>
    <td>{{ route.ipv4Route.attributes.pcTag }}</td>
    <td>{{ route.ipv4Route.attributes.pref }}</td>
    <td>{{ route.ipv4Route.attributes.prefix }}</td>
    <td>{{ route.ipv4Route.attributes.sharedConsCount }}</td>
    <td>{{ route.ipv4Route.attributes.status }}</td>
    <td>{{ route.ipv4Route.attributes.tag }}</td>
    <td>{{ route.ipv4Route.attributes.trackId }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "isisAdjEp" in api %}
<h1>ISIS Adjacency Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>BFD Oper State</th>
    <th>Child Action</th>
    <th>Ckt Type</th>
    <th>DN</th>
    <th>Hold Expired Timestamp</th>
    <th>LAN ID</th>
    <th>Last Trans</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Number Adjacency Transactions</th>
    <th>Oper State</th>
    <th>Peer Ckt ID</th>
    <th>Peer Ckt Priority</th>
    <th>Peer Gr Flags</th>
    <th>Status</th>
    <th>Sys ID</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.isisAdjEp.attributes.name }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.bfdOperSt }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.childAction }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.cktType }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.dn }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.holdExpTs }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.lanId }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.lastTrans }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.modTs }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.monPolDn }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.numAdjTrans }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.operSt }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.peerCktId }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.peerCktPrio }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.peerGrFlags }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.status }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.sysId }}</td>
    <td>{{ endpoint.isisAdjEp.attributes.type }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "isisDTEp" in api %}
<h1>ISIS Discovered Tunnel Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Encapsulation Type</th>
    <th>ID</th>
    <th>Last Modified</th>
    <th>Role</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.isisDTEp.attributes.name }}</td>
    <td>{{ endpoint.isisDTEp.attributes.childAction }}</td>
    <td>{{ endpoint.isisDTEp.attributes.dn }}</td>
    <td>{{ endpoint.isisDTEp.attributes.encapt }}</td>
    <td>{{ endpoint.isisDTEp.attributes.id }}</td>
    <td>{{ endpoint.isisDTEp.attributes.modTs }}</td>
    <td>{{ endpoint.isisDTEp.attributes.role }}</td>
    <td>{{ endpoint.isisDTEp.attributes.status }}</td>
    <td>{{ endpoint.isisDTEp.attributes.type }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- elif "isisDom" in api %}
{%-     if "Lvl" in api %}
<h1>ISIS Domain Levels</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>Distance</th>
    <th>DN</th>
    <th>Fast Csnp</th>
    <th>Fast LISP</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Number Routes Summarized</th>
    <th>SPF Resynced</th>
    <th>SPF Scheduled</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-         for level in data_to_template['imdata'] %}
  <tr>
    <td>{{ level.isisDomLvl.attributes.name }}</td>
    <td>{{ level.isisDomLvl.attributes.childAction }}</td>
    <td>{{ level.isisDomLvl.attributes.ctrl }}</td>
    <td>{{ level.isisDomLvl.attributes.dist }}</td>
    <td>{{ level.isisDomLvl.attributes.dn }}</td>
    <td>{{ level.isisDomLvl.attributes.fastCsnp }}</td>
    <td>{{ level.isisDomLvl.attributes.fastLsp }}</td>
    <td>{{ level.isisDomLvl.attributes.lcOwn }}</td>
    <td>{{ level.isisDomLvl.attributes.modTs }}</td>
    <td>{{ level.isisDomLvl.attributes.monPolDn }}</td>
    <td>{{ level.isisDomLvl.attributes.numRtSummarized }}</td>
    <td>{{ level.isisDomLvl.attributes.spfResynced }}</td>
    <td>{{ level.isisDomLvl.attributes.spfScheduled }}</td>
    <td>{{ level.isisDomLvl.attributes.status }}</td>
    <td>{{ level.isisDomLvl.attributes.type }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>ISIS Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Aggregation Fabric Adjacency Oper State</th>
    <th>Area ID</th>
    <th>Bandwidth Reference</th>
    <th>Child Action</th>
    <th>Context ID</th>
    <th>Control</th>
    <th>DN</th>
    <th>Fast Csnps</th>
    <th>Fast Lsps</th>
    <th>Local Owner</th>
    <th>LISP Purged</th>
    <th>LISP Refreshed</th>
    <th>LISP Sourced</th>
    <th>Max ECMP</th>
    <th>Metric Style</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>MTS Error</th>
    <th>MTU</th>
    <th>nSel</th>
    <th>Oper State</th>
    <th>Redistribution Metric</th>
    <th>Sequence Wrap Error</th>
    <th>SPF Calculated</th>
    <th>Status</th>
    <th>System ID</th>
    <th>System GIPO</th>
    <th>System GIPO Oper State</th>
    <th>Urib Error</th>
  </tr>
</thead>
<tbody>
{%-         for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.isisDom.attributes.name }}</td>
    <td>{{ domain.isisDom.attributes.aggFabAdjOperSt }}</td>
    <td>{{ domain.isisDom.attributes.areaId }}</td>
    <td>{{ domain.isisDom.attributes.bwRef }}</td>
    <td>{{ domain.isisDom.attributes.childAction }}</td>
    <td>{{ domain.isisDom.attributes.contextId }}</td>
    <td>{{ domain.isisDom.attributes.ctrl }}</td>
    <td>{{ domain.isisDom.attributes.dn }}</td>
    <td>{{ domain.isisDom.attributes.fastCsnps }}</td>
    <td>{{ domain.isisDom.attributes.fastLsps }}</td>
    <td>{{ domain.isisDom.attributes.lcOwn }}</td>
    <td>{{ domain.isisDom.attributes.lspPurged }}</td>
    <td>{{ domain.isisDom.attributes.lspRefreshed }}</td>
    <td>{{ domain.isisDom.attributes.lspSourced }}</td>
    <td>{{ domain.isisDom.attributes.maxEcmp }}</td>
    <td>{{ domain.isisDom.attributes.metricStyle }}</td>
    <td>{{ domain.isisDom.attributes.modTs }}</td>
    <td>{{ domain.isisDom.attributes.mode }}</td>
    <td>{{ domain.isisDom.attributes.monPolDn }}</td>
    <td>{{ domain.isisDom.attributes.mtsError }}</td>
    <td>{{ domain.isisDom.attributes.mtu }}</td>
    <td>{{ domain.isisDom.attributes.nSel }}</td>
    <td>{{ domain.isisDom.attributes.operSt }}</td>
    <td>{{ domain.isisDom.attributes.redistribMetric }}</td>
    <td>{{ domain.isisDom.attributes.seqWrapError }}</td>
    <td>{{ domain.isisDom.attributes.spfCalculated }}</td>
    <td>{{ domain.isisDom.attributes.status }}</td>
    <td>{{ domain.isisDom.attributes.sysId }}</td>
    <td>{{ domain.isisDom.attributes.systemGipo }}</td>
    <td>{{ domain.isisDom.attributes.systemGipoOperSt }}</td>
    <td>{{ domain.isisDom.attributes.uribError }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     endif %}
{%- elif "isisEntity" in api %}
<h1>ISIS Entities</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Oper State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for entity in data_to_template['imdata'] %}
  <tr>
    <td>{{ entity.isisEntity.attributes.name }}</td>
    <td>{{ entity.isisEntity.attributes.adminSt }}</td>
    <td>{{ entity.isisEntity.attributes.childAction }}</td>
    <td>{{ entity.isisEntity.attributes.dn }}</td>
    <td>{{ entity.isisEntity.attributes.lcOwn }}</td>
    <td>{{ entity.isisEntity.attributes.modTs }}</td>
    <td>{{ entity.isisEntity.attributes.monPolDn }}</td>
    <td>{{ entity.isisEntity.attributes.operErr }}</td>
    <td>{{ entity.isisEntity.attributes.operSt }}</td>
    <td>{{ entity.isisEntity.attributes.status }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%- elif "isisIf" in api %}
{%-     if "Lvl" in api %}
<h1>ISIS Interfaces Level</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>Csnp Interval</th>
    <th>DN</th>
    <th>Hello Interval</th>
    <th>Hello Mult</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Next Csnp Timestamp</th>
    <th>Priority</th>
    <th>Protocol Error</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-         for level in data_to_template['imdata'] %}
  <tr>
    <td>{{ level.isisIfLvl.attributes.name }}</td>
    <td>{{ level.isisIfLvl.attributes.childAction }}</td>
    <td>{{ level.isisIfLvl.attributes.csnpIntvl }}</td>
    <td>{{ level.isisIfLvl.attributes.dn }}</td>
    <td>{{ level.isisIfLvl.attributes.helloIntvl }}</td>
    <td>{{ level.isisIfLvl.attributes.helloMult }}</td>
    <td>{{ level.isisIfLvl.attributes.lcOwn }}</td>
    <td>{{ level.isisIfLvl.attributes.modTs }}</td>
    <td>{{ level.isisIfLvl.attributes.monPolDn }}</td>
    <td>{{ level.isisIfLvl.attributes.nextCsnpTs }}</td>
    <td>{{ level.isisIfLvl.attributes.priority }}</td>
    <td>{{ level.isisIfLvl.attributes.protoError }}</td>
    <td>{{ level.isisIfLvl.attributes.status }}</td>
    <td>{{ level.isisIfLvl.attributes.type }}</td>
  </tr>
{%-         endfor %}
</tbody>
</table>
{%-     else %}
<h1>ISIS Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Ckt Type</th>
    <th>Control</th>
    <th>Description</th>
    <th>DN</th>
    <th>Extended Local Ckt ID</th>
    <th>ID</th>
    <th>IIB Index</th>
    <th>IIB State</th>
    <th>IIB Up Control</th>
    <th>Init Error</th>
    <th>Local Owner</th>
    <th>Local Ckt ID</th>
    <th>LISP Refresh Interval</th>
    <th>Metric</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Next IIH Timestamp</th>
    <th>P2P Ckt ID</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-         for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.isisIf.attributes.name }}</td>
    <td>{{ interface.isisIf.attributes.adminSt }}</td>
    <td>{{ interface.isisIf.attributes.childAction }}</td>
    <td>{{ interface.isisIf.attributes.cktT }}</td>
    <td>{{ interface.isisIf.attributes.ctrl }}</td>
    <td>{{ interface.isisIf.attributes.descr }}</td>
    <td>{{ interface.isisIf.attributes.dn }}</td>
    <td>{{ interface.isisIf.attributes.extdLocalCktId }}</td>
    <td>{{ interface.isisIf.attributes.id }}</td>
    <td>{{ interface.isisIf.attributes.iibIdx }}</td>
    <td>{{ interface.isisIf.attributes.iibState }}</td>
    <td>{{ interface.isisIf.attributes.iibUpCtrl }}</td>
    <td>{{ interface.isisIf.attributes.initError }}</td>
    <td>{{ interface.isisIf.attributes.lcOwn }}</td>
    <td>{{ interface.isisIf.attributes.localCktId }}</td>
    <td>{{ interface.isisIf.attributes.lspRefreshIntvl }}</td>
    <td>{{ interface.isisIf.attributes.metric }}</td>
    <td>{{ interface.isisIf.attributes.modTs }}</td>
    <td>{{ interface.isisIf.attributes.monPolDn }}</td>
    <td>{{ interface.isisIf.attributes.nextIIHTs }}</td>
    <td>{{ interface.isisIf.attributes.p2pCktId }}</td>
    <td>{{ interface.isisIf.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%-      endif %}
{%- elif "isisInst" in api %}
<h1>ISIS Instances</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>DN</th>
    <th>Duplicate System ID Error</th>
    <th>Local Owner</th>
    <th>Memory Alert</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>MTS Error</th>
    <th>Oper Error</th>
    <th>Oper State</th>
    <th>Process Queue</th>
    <th>Process Sap</th>
    <th>Process Tag</th>
    <th>Protocol Error</th>
    <th>PSS Error</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for instance in data_to_template['imdata'] %}
  <tr>
    <td>{{ instance.isisInst.attributes.name }}</td>
    <td>{{ instance.isisInst.attributes.adminSt }}</td>
    <td>{{ instance.isisInst.attributes.childAction }}</td>
    <td>{{ instance.isisInst.attributes.ctrl }}</td>
    <td>{{ instance.isisInst.attributes.dn }}</td>
    <td>{{ instance.isisInst.attributes.dupSysIdErr }}</td>
    <td>{{ instance.isisInst.attributes.lcOwn }}</td>
    <td>{{ instance.isisInst.attributes.memAlert }}</td>
    <td>{{ instance.isisInst.attributes.modTs }}</td>
    <td>{{ instance.isisInst.attributes.monPolDn }}</td>
    <td>{{ instance.isisInst.attributes.mtsErr }}</td>
    <td>{{ instance.isisInst.attributes.operErr }}</td>
    <td>{{ instance.isisInst.attributes.operSt }}</td>
    <td>{{ instance.isisInst.attributes.processQueue }}</td>
    <td>{{ instance.isisInst.attributes.processSap }}</td>
    <td>{{ instance.isisInst.attributes.processTag }}</td>
    <td>{{ instance.isisInst.attributes.protoErr }}</td>
    <td>{{ instance.isisInst.attributes.pssErr }}</td>
    <td>{{ instance.isisInst.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "isisNexthop" in api %}
<h1>ISIS Next Hop</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Address</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Interface</th>
    <th>Last Modified</th>
    <th>Next Hop Interface</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for nexthop in data_to_template['imdata'] %}
  <tr>
    <td>{{ nexthop.isisNexthop.attributes.name }}</td>
    <td>{{ nexthop.isisNexthop.attributes.addr }}</td>
    <td>{{ nexthop.isisNexthop.attributes.childAction }}</td>
    <td>{{ nexthop.isisNexthop.attributes.dn }}</td>
    <td>{{ nexthop.isisNexthop.attributes.if }}</td>
    <td>{{ nexthop.isisNexthop.attributes.modTs }}</td>
    <td>{{ nexthop.isisNexthop.attributes.nhIf }}</td>
    <td>{{ nexthop.isisNexthop.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "isisRoute" in api %}
<h1>ISIS Routes</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Metric</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Prefix</th>
    <th>Preference</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for route in data_to_template['imdata'] %}
  <tr>
    <td>{{ route.isisRoute.attributes.name }}</td>
    <td>{{ route.isisRoute.attributes.childAction }}</td>
    <td>{{ route.isisRoute.attributes.dn }}</td>
    <td>{{ route.isisRoute.attributes.metric }}</td>
    <td>{{ route.isisRoute.attributes.modTs }}</td>
    <td>{{ route.isisRoute.attributes.monPolDn }}</td>
    <td>{{ route.isisRoute.attributes.pfx }}</td>
    <td>{{ route.isisRoute.attributes.pref }}</td>
    <td>{{ route.isisRoute.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l2BD" in api %}
<h1>L2 Bridge Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Access Encapsulation</th>
    <th>Address</th>
    <th>Admin State</th>
    <th>BD Def DN</th>
    <th>Bridge Mode</th>
    <th>Child Action</th>
    <th>Created</th>
    <th>Control</th>
    <th>DN</th>
    <th>Endpoint Move Detect Mode</th>
    <th>Endpoint Oper State</th>
    <th>Endpoint Oper State Quality</th>
    <th>Endpoint Up Sequence Number</th>
    <th>Fabric Encapsulation</th>
    <th>Forward Control</th>
    <th>Forward Mode</th>
    <th>Hardware ID</th>
    <th>Hardware Resource ID</th>
    <th>Hardware Shadow ID</th>
    <th>ID</th>
    <th>IPv6 Multicast Allow</th>
    <th>Local Owner</th>
    <th>Multicast Allow</th>
    <th>Multicast Oper State</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>Multi Destination Packet Action</th>
    <th>Oper State</th>
    <th>PC Tag</th>
    <th>Q in Q L2 Protocol Tunnel Mask</th>
    <th>QOS Priority</th>
    <th>Status</th>
    <th>Type</th>
    <th>Unknown MAC Unicast Action</th>
    <th>Unknown Multicast Action</th>
    <th>v6 Unknown Multicast Action</th>
    <th>VLAN Manager Config Failed Bmp</th>
    <th>VLAN Manager Config Failed Timestamp</th>
    <th>VLAN Manager Config State</th>
    <th>VLAN Manager Custom Fault Bmp</th>
  </tr>
</thead>
<tbody>
{%-     for bd in data_to_template['imdata'] %}
  <tr>
    <td>{{ bd.l2BD.attributes.name }}</td>
    <td>{{ bd.l2BD.attributes.accEncap }}</td>
    <td>{{ bd.l2BD.attributes.addr }}</td>
    <td>{{ bd.l2BD.attributes.adminSt }}</td>
    <td>{{ bd.l2BD.attributes.bdDefDn }}</td>
    <td>{{ bd.l2BD.attributes.bridgeMode }}</td>
    <td>{{ bd.l2BD.attributes.childAction }}</td>
    <td>{{ bd.l2BD.attributes.createTs }}</td>
    <td>{{ bd.l2BD.attributes.ctrl }}</td>
    <td>{{ bd.l2BD.attributes.dn }}</td>
    <td>{{ bd.l2BD.attributes.epMoveDetectMode }}</td>
    <td>{{ bd.l2BD.attributes.epOperSt }}</td>
    <td>{{ bd.l2BD.attributes.epOperStQual }}</td>
    <td>{{ bd.l2BD.attributes.epUpSeqNum }}</td>
    <td>{{ bd.l2BD.attributes.fabEncap }}</td>
    <td>{{ bd.l2BD.attributes.fwdCtrl }}</td>
    <td>{{ bd.l2BD.attributes.fwdMode }}</td>
    <td>{{ bd.l2BD.attributes.hwId }}</td>
    <td>{{ bd.l2BD.attributes.hwResourceId }}</td>
    <td>{{ bd.l2BD.attributes.hwShadowId }}</td>
    <td>{{ bd.l2BD.attributes.id }}</td>
    <td>{{ bd.l2BD.attributes.ipv6McastAllow }}</td>
    <td>{{ bd.l2BD.attributes.lcOwn }}</td>
    <td>{{ bd.l2BD.attributes.mcastAllow }}</td>
    <td>{{ bd.l2BD.attributes.mcastOperSt }}</td>
    <td>{{ bd.l2BD.attributes.modTs }}</td>
    <td>{{ bd.l2BD.attributes.mode }}</td>
    <td>{{ bd.l2BD.attributes.monPolDn }}</td>
    <td>{{ bd.l2BD.attributes.multiDstPktAct }}</td>
    <td>{{ bd.l2BD.attributes.operSt }}</td>
    <td>{{ bd.l2BD.attributes.pcTag }}</td>
    <td>{{ bd.l2BD.attributes.qiqL2ProtTunMask }}</td>
    <td>{{ bd.l2BD.attributes.qosPrio }}</td>
    <td>{{ bd.l2BD.attributes.status }}</td>
    <td>{{ bd.l2BD.attributes.type }}</td>
    <td>{{ bd.l2BD.attributes.unkMacUcastAct }}</td>
    <td>{{ bd.l2BD.attributes.unkMcastAct }}</td>
    <td>{{ bd.l2BD.attributes.v6unkMcastAct }}</td>
    <td>{{ bd.l2BD.attributes.vlanmgrCfgFailedBmp }}</td>
    <td>{{ bd.l2BD.attributes.vlanmgrCfgFailedTs }}</td>
    <td>{{ bd.l2BD.attributes.vlanmgrCfgState }}</td>
    <td>{{ bd.l2BD.attributes.vlanmgrCustFaultBmp }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l2ExtIf" in api %}
<h1>L2 External Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>External Chassis ID</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>SAT Manager Config Failed Bmp</th>
    <th>SAT Manager Config Failed Timestamp</th>
    <th>SAT Manager Config State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.l2ExtIf.attributes.name }}</td>
    <td>{{ interface.l2ExtIf.attributes.childAction }}</td>
    <td>{{ interface.l2ExtIf.attributes.descr }}</td>
    <td>{{ interface.l2ExtIf.attributes.dn }}</td>
    <td>{{ interface.l2ExtIf.attributes.extChasId }}</td>
    <td>{{ interface.l2ExtIf.attributes.id }}</td>
    <td>{{ interface.l2ExtIf.attributes.lcOwn }}</td>
    <td>{{ interface.l2ExtIf.attributes.modTs }}</td>
    <td>{{ interface.l2ExtIf.attributes.monPolDn }}</td>
    <td>{{ interface.l2ExtIf.attributes.satmgrCfgFailedBmp }}</td>
    <td>{{ interface.l2ExtIf.attributes.satmgrCfgFailedTs }}</td>
    <td>{{ interface.l2ExtIf.attributes.satmgrCfgState }}</td>
    <td>{{ interface.l2ExtIf.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l2RsEthIf" in api %}
<h1>L2 Interface Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Parent Source Key</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tSKey</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.l2RsEthIf.attributes.dn }}</td>
    <td>{{ interface.l2RsEthIf.attributes.childAction }}</td>
    <td>{{ interface.l2RsEthIf.attributes.forceResolve }}</td>
    <td>{{ interface.l2RsEthIf.attributes.lcOwn }}</td>
    <td>{{ interface.l2RsEthIf.attributes.modTs }}</td>
    <td>{{ interface.l2RsEthIf.attributes.parentSKey }}</td>
    <td>{{ interface.l2RsEthIf.attributes.rType }}</td>
    <td>{{ interface.l2RsEthIf.attributes.state }}</td>
    <td>{{ interface.l2RsEthIf.attributes.stateQual }}</td>
    <td>{{ interface.l2RsEthIf.attributes.status }}</td>
    <td>{{ interface.l2RsEthIf.attributes.tCl }}</td>
    <td>{{ interface.l2RsEthIf.attributes.tDn }}</td>
    <td>{{ interface.l2RsEthIf.attributes.tSKey }}</td>
    <td>{{ interface.l2RsEthIf.attributes.tType }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l2extInstP" in api %}
<h1>L2 External Instance Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Config Issues</th>
    <th>Config State</th>
    <th>Description</th>
    <th>DN</th>
    <th>Exception Tag</th>
    <th>Externally Managed By</th>
    <th>Flood On Encapsulation</th>
    <th>Is Shared Service Multisite EPG</th>
    <th>Local Owner</th>
    <th>Match Type</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>PC Enforced Preference</th>
    <th>PC Tag</th>
    <th>Preferred Group Member</th>
    <th>Priority</th>
    <th>Scope</th>
    <th>Status</th>
    <th>Target DSCP</th>
    <th>Trigger State</th>
    <th>TX ID</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.l2extInstP.attributes.name }}</td>
    <td>{{ profile.l2extInstP.attributes.nameAlias }}</td>
    <td>{{ profile.l2extInstP.attributes.annotation }}</td>
    <td>{{ profile.l2extInstP.attributes.childAction }}</td>
    <td>{{ profile.l2extInstP.attributes.configIssues }}</td>
    <td>{{ profile.l2extInstP.attributes.configSt }}</td>
    <td>{{ profile.l2extInstP.attributes.descr }}</td>
    <td>{{ profile.l2extInstP.attributes.dn }}</td>
    <td>{{ profile.l2extInstP.attributes.exceptionTag }}</td>
    <td>{{ profile.l2extInstP.attributes.extMngdBy }}</td>
    <td>{{ profile.l2extInstP.attributes.floodOnEncap }}</td>
    <td>{{ profile.l2extInstP.attributes.isSharedSrvMsiteEPg }}</td>
    <td>{{ profile.l2extInstP.attributes.lcOwn }}</td>
    <td>{{ profile.l2extInstP.attributes.matchT }}</td>
    <td>{{ profile.l2extInstP.attributes.modTs }}</td>
    <td>{{ profile.l2extInstP.attributes.monPolDn }}</td>
    <td>{{ profile.l2extInstP.attributes.pcEnfPref }}</td>
    <td>{{ profile.l2extInstP.attributes.pcTag }}</td>
    <td>{{ profile.l2extInstP.attributes.prefGrMemb }}</td>
    <td>{{ profile.l2extInstP.attributes.prio }}</td>
    <td>{{ profile.l2extInstP.attributes.scope }}</td>
    <td>{{ profile.l2extInstP.attributes.status }}</td>
    <td>{{ profile.l2extInstP.attributes.targetDscp }}</td>
    <td>{{ profile.l2extInstP.attributes.triggerSt }}</td>
    <td>{{ profile.l2extInstP.attributes.txId }}</td>
    <td>{{ profile.l2extInstP.attributes.uid }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l2extLIfP" in api %}
<h1>L2 External Logical Interface Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>Tag</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.l2extLIfP.attributes.name }}</td>
    <td>{{ profile.l2extLIfP.attributes.nameAlias }}</td>
    <td>{{ profile.l2extLIfP.attributes.annotation }}</td>
    <td>{{ profile.l2extLIfP.attributes.childAction }}</td>
    <td>{{ profile.l2extLIfP.attributes.descr }}</td>
    <td>{{ profile.l2extLIfP.attributes.dn }}</td>
    <td>{{ profile.l2extLIfP.attributes.extMngdBy }}</td>
    <td>{{ profile.l2extLIfP.attributes.lcOwn }}</td>
    <td>{{ profile.l2extLIfP.attributes.modTs }}</td>
    <td>{{ profile.l2extLIfP.attributes.monPolDn }}</td>
    <td>{{ profile.l2extLIfP.attributes.ownerKey }}</td>
    <td>{{ profile.l2extLIfP.attributes.ownerTag }}</td>
    <td>{{ profile.l2extLIfP.attributes.status }}</td>
    <td>{{ profile.l2extLIfP.attributes.tag }}</td>
    <td>{{ profile.l2extLIfP.attributes.uid }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l2extLNodeP" in api %}
<h1>L2 External Logical Interface Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>Tag</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for node in data_to_template['imdata'] %}
  <tr>
    <td>{{ node.l2extLNodeP.attributes.name }}</td>
    <td>{{ node.l2extLNodeP.attributes.nameAlias }}</td>
    <td>{{ node.l2extLNodeP.attributes.annotation }}</td>
    <td>{{ node.l2extLNodeP.attributes.childAction }}</td>
    <td>{{ node.l2extLNodeP.attributes.descr }}</td>
    <td>{{ node.l2extLNodeP.attributes.dn }}</td>
    <td>{{ node.l2extLNodeP.attributes.extMngdBy }}</td>
    <td>{{ node.l2extLNodeP.attributes.lcOwn }}</td>
    <td>{{ node.l2extLNodeP.attributes.modTs }}</td>
    <td>{{ node.l2extLNodeP.attributes.monPolDn }}</td>
    <td>{{ node.l2extLNodeP.attributes.ownerKey }}</td>
    <td>{{ node.l2extLNodeP.attributes.ownerTag }}</td>
    <td>{{ node.l2extLNodeP.attributes.status }}</td>
    <td>{{ node.l2extLNodeP.attributes.tag }}</td>
    <td>{{ node.l2extLNodeP.attributes.uid }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l2extRsEBd" in api %}
<h1>L2 EPG Bridge Domain Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tContext DN</th>
    <th>tDN</th>
    <th>tRN</th>
    <th>tType</th>
    <th>tnFv Bridge Domain Name</th>
  </tr>
</thead>
<tbody>
{%-     for epg in data_to_template['imdata'] %}
  <tr>
    <td>{{ epg.l2extRsEBd.attributes.uid }}</td>
    <td>{{ epg.l2extRsEBd.attributes.annotation }}</td>
    <td>{{ epg.l2extRsEBd.attributes.childAction }}</td>
    <td>{{ epg.l2extRsEBd.attributes.dn }}</td>
    <td>{{ epg.l2extRsEBd.attributes.encap }}</td>
    <td>{{ epg.l2extRsEBd.attributes.extMngdBy }}</td>
    <td>{{ epg.l2extRsEBd.attributes.forceResolve }}</td>
    <td>{{ epg.l2extRsEBd.attributes.lcOwn }}</td>
    <td>{{ epg.l2extRsEBd.attributes.modTs }}</td>
    <td>{{ epg.l2extRsEBd.attributes.monPolDn }}</td>
    <td>{{ epg.l2extRsEBd.attributes.rType }}</td>
    <td>{{ epg.l2extRsEBd.attributes.state }}</td>
    <td>{{ epg.l2extRsEBd.attributes.stateQual }}</td>
    <td>{{ epg.l2extRsEBd.attributes.status }}</td>
    <td>{{ epg.l2extRsEBd.attributes.tCl }}</td>
    <td>{{ epg.l2extRsEBd.attributes.tContextDn }}</td>
    <td>{{ epg.l2extRsEBd.attributes.tDn }}</td>
    <td>{{ epg.l2extRsEBd.attributes.tRn }}</td>
    <td>{{ epg.l2extRsEBd.attributes.tType }}</td>
    <td>{{ epg.l2extRsEBd.attributes.tnFvBDName }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l2extRsPathL2OutAtt" in api %}
<h1>L2Out Paths</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDn</th>
    <th>tType</th>
    <th>Target DSCP</th>
  </tr>
</thead>
<tbody>
{%-     for path in data_to_template['imdata'] %}
  <tr>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.uid }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.annotation }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.childAction }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.descr }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.dn }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.extMngdBy }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.forceResolve }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.lcOwn }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.modTs }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.rType }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.state }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.stateQual }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.status }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.tCl }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.tDn }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.tType }}</td>
    <td>{{ path.l2extRsPathL2OutAtt.attributes.targetDscp }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3Ctx" in api %}
<h1>L3 Contexts</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Bridge Domain Enforced Enable</th>
    <th>BGP RD</th>
    <th>BGP RD Display</th>
    <th>Child Action</th>
    <th>Created</th>
    <th>Context P Key</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>GSDB Context</th>
    <th>Hardware Resource ID</th>
    <th>ID</th>
    <th>IP Learning Disable</th>
    <th>L3 VM Config Failed Bmp</th>
    <th>L3 VM Config Failed Timestamp</th>
    <th>L3 VM Config State</th>
    <th>Last Changed Timestamp</th>
    <th>Local Owner</th>
    <th>Management PC Tag</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>NG AVS</th>
    <th>Old Oper State Quality</th>
    <th>Oper State Quality</th>
    <th>Oper State</th>
    <th>OUI</th>
    <th>PC Enforced Direction</th>
    <th>PC Enforced Preference</th>
    <th>PC Tag</th>
    <th>Pending</th>
    <th>Port CL Bmp</th>
    <th>Resource ID</th>
    <th>Scope</th>
    <th>Status</th>
    <th>Type</th>
    <th>v4 TIB ID</th>
    <th>v4 TIB Name</th>
    <th>v4 TIB Old Oper State Quality</th>
    <th>v4 TIB Oper State Quality</th>
    <th>v4 TIB Oper State</th>
    <th>v4 TIB Pending</th>
    <th>v4 TIB Valid</th>
    <th>v6 TIB ID</th>
    <th>v6 TIB Name</th>
    <th>v6 TIB Old Oper State Quality</th>
    <th>v6 TIB Oper State Quality</th>
    <th>v6 TIB Oper State</th>
    <th>v6 TIB Pending</th>
    <th>v6 TIB Valid</th>
    <th>VPN ID</th>
  </tr>
</thead>
<tbody>
{%-     for context in data_to_template['imdata'] %}
  <tr>
    <td>{{ context.l3Ctx.attributes.name }}</td>
    <td>{{ context.l3Ctx.attributes.adminState }}</td>
    <td>{{ context.l3Ctx.attributes.bdEnforcedEnable }}</td>
    <td>{{ context.l3Ctx.attributes.bgpRd }}</td>
    <td>{{ context.l3Ctx.attributes.bgpRdDisp }}</td>
    <td>{{ context.l3Ctx.attributes.childAction }}</td>
    <td>{{ context.l3Ctx.attributes.createTs }}</td>
    <td>{{ context.l3Ctx.attributes.ctxPKey }}</td>
    <td>{{ context.l3Ctx.attributes.dn }}</td>
    <td>{{ context.l3Ctx.attributes.encap }}</td>
    <td>{{ context.l3Ctx.attributes.gsdbCtx }}</td>
    <td>{{ context.l3Ctx.attributes.hwResourceId }}</td>
    <td>{{ context.l3Ctx.attributes.id }}</td>
    <td>{{ context.l3Ctx.attributes.ipLearnDisable }}</td>
    <td>{{ context.l3Ctx.attributes.l3vmCfgFailedBmp }}</td>
    <td>{{ context.l3Ctx.attributes.l3vmCfgFailedTs }}</td>
    <td>{{ context.l3Ctx.attributes.l3vmCfgState }}</td>
    <td>{{ context.l3Ctx.attributes.lastChgdTs }}</td>
    <td>{{ context.l3Ctx.attributes.lcOwn }}</td>
    <td>{{ context.l3Ctx.attributes.mgmtPcTag }}</td>
    <td>{{ context.l3Ctx.attributes.modTs }}</td>
    <td>{{ context.l3Ctx.attributes.monPolDn }}</td>
    <td>{{ context.l3Ctx.attributes.ngAvs }}</td>
    <td>{{ context.l3Ctx.attributes.oldOperStQual }}</td>
    <td>{{ context.l3Ctx.attributes.operStQual }}</td>
    <td>{{ context.l3Ctx.attributes.operState }}</td>
    <td>{{ context.l3Ctx.attributes.oui }}</td>
    <td>{{ context.l3Ctx.attributes.pcEnfDir }}</td>
    <td>{{ context.l3Ctx.attributes.pcEnfPref }}</td>
    <td>{{ context.l3Ctx.attributes.pcTag }}</td>
    <td>{{ context.l3Ctx.attributes.pending }}</td>
    <td>{{ context.l3Ctx.attributes.prtclBmp }}</td>
    <td>{{ context.l3Ctx.attributes.resourceId }}</td>
    <td>{{ context.l3Ctx.attributes.scope }}</td>
    <td>{{ context.l3Ctx.attributes.status }}</td>
    <td>{{ context.l3Ctx.attributes.type }}</td>
    <td>{{ context.l3Ctx.attributes.v4TibId }}</td>
    <td>{{ context.l3Ctx.attributes.v4TibName }}</td>
    <td>{{ context.l3Ctx.attributes.v4TibOldOperStQual }}</td>
    <td>{{ context.l3Ctx.attributes.v4TibOperStQual }}</td>
    <td>{{ context.l3Ctx.attributes.v4TibOperState }}</td>
    <td>{{ context.l3Ctx.attributes.v4TibPending }}</td>
    <td>{{ context.l3Ctx.attributes.v4TibValid }}</td>
    <td>{{ context.l3Ctx.attributes.v6TibId }}</td>
    <td>{{ context.l3Ctx.attributes.v6TibName }}</td>
    <td>{{ context.l3Ctx.attributes.v6TibOldOperStQual }}</td>
    <td>{{ context.l3Ctx.attributes.v6TibOperStQual }}</td>
    <td>{{ context.l3Ctx.attributes.v6TibOperState }}</td>
    <td>{{ context.l3Ctx.attributes.v6TibPending }}</td>
    <td>{{ context.l3Ctx.attributes.v6TibValid }}</td>
    <td>{{ context.l3Ctx.attributes.vpnId }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3EncRtdIf" in api %}
<h1>L3 Subinterfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Bandwidth</th>
    <th>Child Action</th>
    <th>Delay</th>
    <th>Description</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>Ethernet PM Config Failed Bmp</th>
    <th>Ethernet PM Config Failed Timestamp</th>
    <th>Ethernet PM Config State</th>
    <th>ID</th>
    <th>Interface Connection DN</th>
    <th>Local Owner</th>
    <th>Link Log Enable</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>MTU</th>
    <th>MTU Inherit</th>
    <th>QOS Priority</th>
    <th>Router MAC</th>
    <th>Routed Out Def DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.l3EncRtdIf.attributes.name }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.adminSt }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.bw }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.childAction }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.delay }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.descr }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.dn }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.encap }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.ethpmCfgFailedBmp }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.ethpmCfgFailedTs }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.ethpmCfgState }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.id }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.ifConnDn }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.lcOwn }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.linkLogEn }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.modTs }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.monPolDn }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.mtu }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.mtuInherit }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.qosPrio }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.routerMac }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.rtdOutDefDn }}</td>
    <td>{{ interface.l3EncRtdIf.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3Inst" in api %}
<h1>L3 Instances</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>BGP RD</th>
    <th>BGP RD Display</th>
    <th>Child Action</th>
    <th>Created</th>
    <th>Context P Key</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>GSDB Context</th>
    <th>ID</th>
    <th>L3 VM Config Failed Bmp</th>
    <th>L3 VM Config Failed Timestamp</th>
    <th>L3 VM Config State</th>
    <th>Last Chaged</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Old Oper State Quality</th>
    <th>Oper State Quality</th>
    <th>Oper State</th>
    <th>OUI</th>
    <th>Pending</th>
    <th>Protocol Bmp</th>
    <th>Resource ID</th>
    <th>Scope</th>
    <th>Status</th>
    <th>v4 TIB ID</th>
    <th>v4 TIB Name</th>
    <th>v4 TIB Old Oper State Quality</th>
    <th>v4 TIB Oper State Quality</th>
    <th>v4 TIB Oper State</th>
    <th>v4 TIB Pending</th>
    <th>v4 TIB Valid</th>
    <th>v6 TIB ID</th>
    <th>v6 TIB Name</th>
    <th>v6 TIB Old Oper State Quality</th>
    <th>v6 TIB Oper State Quality</th>
    <th>v6 TIB Oper State</th>
    <th>v6 TIB Pending</th>
    <th>v6 TIB Valid</th>
    <th>VPN ID</th>
  </tr>
</thead>
<tbody>
{%-     for instance in data_to_template['imdata'] %}
  <tr>
    <td>{{ instance.l3Inst.attributes.name }}</td>
    <td>{{ instance.l3Inst.attributes.adminState }}</td>
    <td>{{ instance.l3Inst.attributes.bgpRd }}</td>
    <td>{{ instance.l3Inst.attributes.bgpRdDisp }}</td>
    <td>{{ instance.l3Inst.attributes.childAction }}</td>
    <td>{{ instance.l3Inst.attributes.createTs }}</td>
    <td>{{ instance.l3Inst.attributes.ctxPKey }}</td>
    <td>{{ instance.l3Inst.attributes.dn }}</td>
    <td>{{ instance.l3Inst.attributes.encap }}</td>
    <td>{{ instance.l3Inst.attributes.gsdbCtx }}</td>
    <td>{{ instance.l3Inst.attributes.id }}</td>
    <td>{{ instance.l3Inst.attributes.l3vmCfgFailedBmp }}</td>
    <td>{{ instance.l3Inst.attributes.l3vmCfgFailedTs }}</td>
    <td>{{ instance.l3Inst.attributes.l3vmCfgState }}</td>
    <td>{{ instance.l3Inst.attributes.lastChgdTs }}</td>
    <td>{{ instance.l3Inst.attributes.lcOwn }}</td>
    <td>{{ instance.l3Inst.attributes.modTs }}</td>
    <td>{{ instance.l3Inst.attributes.monPolDn }}</td>
    <td>{{ instance.l3Inst.attributes.oldOperStQual }}</td>
    <td>{{ instance.l3Inst.attributes.operStQual }}</td>
    <td>{{ instance.l3Inst.attributes.operState }}</td>
    <td>{{ instance.l3Inst.attributes.oui }}</td>
    <td>{{ instance.l3Inst.attributes.pending }}</td>
    <td>{{ instance.l3Inst.attributes.prtclBmp }}</td>
    <td>{{ instance.l3Inst.attributes.resourceId }}</td>
    <td>{{ instance.l3Inst.attributes.scope }}</td>
    <td>{{ instance.l3Inst.attributes.status }}</td>
    <td>{{ instance.l3Inst.attributes.v4TibId }}</td>
    <td>{{ instance.l3Inst.attributes.v4TibName }}</td>
    <td>{{ instance.l3Inst.attributes.v4TibOldOperStQual }}</td>
    <td>{{ instance.l3Inst.attributes.v4TibOperStQual }}</td>
    <td>{{ instance.l3Inst.attributes.v4TibOperState }}</td>
    <td>{{ instance.l3Inst.attributes.v4TibPending }}</td>
    <td>{{ instance.l3Inst.attributes.v4TibValid }}</td>
    <td>{{ instance.l3Inst.attributes.v6TibId }}</td>
    <td>{{ instance.l3Inst.attributes.v6TibName }}</td>
    <td>{{ instance.l3Inst.attributes.v6TibOldOperStQual }}</td>
    <td>{{ instance.l3Inst.attributes.v6TibOperStQual }}</td>
    <td>{{ instance.l3Inst.attributes.v6TibOperState }}</td>
    <td>{{ instance.l3Inst.attributes.v6TibPending }}</td>
    <td>{{ instance.l3Inst.attributes.v6TibValid }}</td>
    <td>{{ instance.l3Inst.attributes.vpnId }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3LbRtdIf" in api %}
<h1>L3 Routed Loopback Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Link Log</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>QOS Priority</th>
    <th>Routed Out Def DN</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for loopback in data_to_template['imdata'] %}
  <tr>
    <td>{{ loopback.l3LbRtdIf.attributes.name }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.adminSt }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.childAction }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.descr }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.dn }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.id }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.lcOwn }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.linkLog }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.modTs }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.monPolDn }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.qosPrio }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.rtdOutDefDn }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.status }}</td>
    <td>{{ loopback.l3LbRtdIf.attributes.type }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3RsEncPhysRtdConf" in api %}
<h1>L3 Physical Interface Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Parent S Key</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tSKey</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.dn }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.childAction }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.forceResolve }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.lcOwn }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.modTs }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.parentSKey }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.rType }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.state }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.stateQual }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.status }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.tCl }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.tDn }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.tSKey }}</td>
    <td>{{ interface.l3RsEncPhysRtdConf.attributes.tType }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3RtdIf" in api %}
<h1>L3 Routed Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>QOS Priority</th>
    <th>Routed Out Def DN</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.l3RtdIf.attributes.name }}</td>
    <td>{{ interface.l3RtdIf.attributes.adminSt }}</td>
    <td>{{ interface.l3RtdIf.attributes.childAction }}</td>
    <td>{{ interface.l3RtdIf.attributes.descr }}</td>
    <td>{{ interface.l3RtdIf.attributes.dn }}</td>
    <td>{{ interface.l3RtdIf.attributes.id }}</td>
    <td>{{ interface.l3RtdIf.attributes.lcOwn }}</td>
    <td>{{ interface.l3RtdIf.attributes.modTs }}</td>
    <td>{{ interface.l3RtdIf.attributes.monPolDn }}</td>
    <td>{{ interface.l3RtdIf.attributes.qosPrio }}</td>
    <td>{{ interface.l3RtdIf.attributes.rtdOutDefDn }}</td>
    <td>{{ interface.l3RtdIf.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extInstP" in api %}
<h1>L3Out Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Config Issues</th>
    <th>Config State</th>
    <th>Description</th>
    <th>DN</th>
    <th>Exception Tag</th>
    <th>Externally Managed By</th>
    <th>Flood On Encapsulation</th>
    <th>Is Shared Service Multisite EPG</th>
    <th>Local Owner</th>
    <th>Match Type</th>
    <th>Multicast</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>PC Tag</th>
    <th>Preferred Group Member</th>
    <th>Priority</th>
    <th>Scope</th>
    <th>Status</th>
    <th>Target DSCP</th>
    <th>Trigger State</th>
    <th>TX ID</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.l3extInstP.attributes.name }}</td>
    <td>{{ profile.l3extInstP.attributes.nameAlias }}</td>
    <td>{{ profile.l3extInstP.attributes.annotation }}</td>
    <td>{{ profile.l3extInstP.attributes.childAction }}</td>
    <td>{{ profile.l3extInstP.attributes.configIssues }}</td>
    <td>{{ profile.l3extInstP.attributes.configSt }}</td>
    <td>{{ profile.l3extInstP.attributes.descr }}</td>
    <td>{{ profile.l3extInstP.attributes.dn }}</td>
    <td>{{ profile.l3extInstP.attributes.exceptionTag }}</td>
    <td>{{ profile.l3extInstP.attributes.extMngdBy }}</td>
    <td>{{ profile.l3extInstP.attributes.floodOnEncap }}</td>
    <td>{{ profile.l3extInstP.attributes.isSharedSrvMsiteEPg }}</td>
    <td>{{ profile.l3extInstP.attributes.lcOwn }}</td>
    <td>{{ profile.l3extInstP.attributes.matchT }}</td>
    <td>{{ profile.l3extInstP.attributes.mcast }}</td>
    <td>{{ profile.l3extInstP.attributes.modTs }}</td>
    <td>{{ profile.l3extInstP.attributes.monPolDn }}</td>
    <td>{{ profile.l3extInstP.attributes.pcTag }}</td>
    <td>{{ profile.l3extInstP.attributes.prefGrMemb }}</td>
    <td>{{ profile.l3extInstP.attributes.prio }}</td>
    <td>{{ profile.l3extInstP.attributes.scope }}</td>
    <td>{{ profile.l3extInstP.attributes.status }}</td>
    <td>{{ profile.l3extInstP.attributes.targetDscp }}</td>
    <td>{{ profile.l3extInstP.attributes.triggerSt }}</td>
    <td>{{ profile.l3extInstP.attributes.txId }}</td>
    <td>{{ profile.l3extInstP.attributes.uid }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extIp" in api %}
<h1>L3Out IP Addresses</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Address</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>IPv6 DAD</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for ip in data_to_template['imdata'] %}
  <tr>
    <td>{{ ip.l3extIp.attributes.name }}</td>
    <td>{{ ip.l3extIp.attributes.nameAlias }}</td>
    <td>{{ ip.l3extIp.attributes.addr }}</td>
    <td>{{ ip.l3extIp.attributes.annotation }}</td>
    <td>{{ ip.l3extIp.attributes.childAction }}</td>
    <td>{{ ip.l3extIp.attributes.descr }}</td>
    <td>{{ ip.l3extIp.attributes.dn }}</td>
    <td>{{ ip.l3extIp.attributes.extMngdBy }}</td>
    <td>{{ ip.l3extIp.attributes.ipv6Dad }}</td>
    <td>{{ ip.l3extIp.attributes.lcOwn }}</td>
    <td>{{ ip.l3extIp.attributes.modTs }}</td>
    <td>{{ ip.l3extIp.attributes.monPolDn }}</td>
    <td>{{ ip.l3extIp.attributes.status }}</td>
    <td>{{ ip.l3extIp.attributes.uid }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extLIfP" in api %}
<h1>L3 Logical Interface Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Address</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Priority</th>
    <th>Status</th>
    <th>Tag</th>
    <th>Target DSCP</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.l3extLIfP.attributes.name }}</td>
    <td>{{ profile.l3extLIfP.attributes.nameAlias }}</td>
    <td>{{ profile.l3extLIfP.attributes.addr }}</td>
    <td>{{ profile.l3extLIfP.attributes.annotation }}</td>
    <td>{{ profile.l3extLIfP.attributes.childAction }}</td>
    <td>{{ profile.l3extLIfP.attributes.descr }}</td>
    <td>{{ profile.l3extLIfP.attributes.dn }}</td>
    <td>{{ profile.l3extLIfP.attributes.encap }}</td>
    <td>{{ profile.l3extLIfP.attributes.extMngdBy }}</td>
    <td>{{ profile.l3extLIfP.attributes.lcOwn }}</td>
    <td>{{ profile.l3extLIfP.attributes.modTs }}</td>
    <td>{{ profile.l3extLIfP.attributes.monPolDn }}</td>
    <td>{{ profile.l3extLIfP.attributes.ownerKey }}</td>
    <td>{{ profile.l3extLIfP.attributes.ownerTag }}</td>
    <td>{{ profile.l3extLIfP.attributes.prio }}</td>
    <td>{{ profile.l3extLIfP.attributes.status }}</td>
    <td>{{ profile.l3extLIfP.attributes.tag }}</td>
    <td>{{ profile.l3extLIfP.attributes.targetDscp }}</td>
    <td>{{ profile.l3extLIfP.attributes.uid }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extLNodeP" in api %}
<h1>L3 Logical Node Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Config Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>Tag</th>
    <th>Target DSCP</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.l3extLNodeP.attributes.name }}</td>
    <td>{{ profile.l3extLNodeP.attributes.nameAlias }}</td>
    <td>{{ profile.l3extLNodeP.attributes.annotation }}</td>
    <td>{{ profile.l3extLNodeP.attributes.childAction }}</td>
    <td>{{ profile.l3extLNodeP.attributes.configIssues }}</td>
    <td>{{ profile.l3extLNodeP.attributes.descr }}</td>
    <td>{{ profile.l3extLNodeP.attributes.dn }}</td>
    <td>{{ profile.l3extLNodeP.attributes.extMngdBy }}</td>
    <td>{{ profile.l3extLNodeP.attributes.lcOwn }}</td>
    <td>{{ profile.l3extLNodeP.attributes.modTs }}</td>
    <td>{{ profile.l3extLNodeP.attributes.monPolDn }}</td>
    <td>{{ profile.l3extLNodeP.attributes.ownerKey }}</td>
    <td>{{ profile.l3extLNodeP.attributes.ownerTag }}</td>
    <td>{{ profile.l3extLNodeP.attributes.status }}</td>
    <td>{{ profile.l3extLNodeP.attributes.tag }}</td>
    <td>{{ profile.l3extLNodeP.attributes.targetDscp }}</td>
    <td>{{ profile.l3extLNodeP.attributes.uid }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extMember" in api %}
<h1>L3Out Members</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Address</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>IPv6 DAD</th>
    <th>Local Owner</th>
    <th>Logical Link Address</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Side</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for member in data_to_template['imdata'] %}
  <tr>
    <td>{{ member.l3extMember.attributes.name }}</td>
    <td>{{ member.l3extMember.attributes.nameAlias }}</td>
    <td>{{ member.l3extMember.attributes.addr }}</td>
    <td>{{ member.l3extMember.attributes.annotation }}</td>
    <td>{{ member.l3extMember.attributes.childAction }}</td>
    <td>{{ member.l3extMember.attributes.descr }}</td>
    <td>{{ member.l3extMember.attributes.dn }}</td>
    <td>{{ member.l3extMember.attributes.extMngdBy }}</td>
    <td>{{ member.l3extMember.attributes.ipv6Dad }}</td>
    <td>{{ member.l3extMember.attributes.lcOwn }}</td>
    <td>{{ member.l3extMember.attributes.llAddr }}</td>
    <td>{{ member.l3extMember.attributes.modTs }}</td>
    <td>{{ member.l3extMember.attributes.monPolDn }}</td>
    <td>{{ member.l3extMember.attributes.side }}</td>
    <td>{{ member.l3extMember.attributes.status }}</td>
    <td>{{ member.l3extMember.attributes.uid }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extRsEctx" in api %}
<h1>L3 Context Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tContext DN</th>
    <th>tDN</th>
    <th>tRN</th>
    <th>tType</th>
    <th>tnFv Context Name</th>
  </tr>
</thead>
<tbody>
{%-     for context in data_to_template['imdata'] %}
  <tr>
    <td>{{ context.l3extRsEctx.attributes.uid }}</td>
    <td>{{ context.l3extRsEctx.attributes.annotation }}</td>
    <td>{{ context.l3extRsEctx.attributes.childAction }}</td>
    <td>{{ context.l3extRsEctx.attributes.dn }}</td>
    <td>{{ context.l3extRsEctx.attributes.extMngdBy }}</td>
    <td>{{ context.l3extRsEctx.attributes.forceResolve }}</td>
    <td>{{ context.l3extRsEctx.attributes.lcOwn }}</td>
    <td>{{ context.l3extRsEctx.attributes.modTs }}</td>
    <td>{{ context.l3extRsEctx.attributes.monPolDn }}</td>
    <td>{{ context.l3extRsEctx.attributes.rType }}</td>
    <td>{{ context.l3extRsEctx.attributes.state }}</td>
    <td>{{ context.l3extRsEctx.attributes.stateQual }}</td>
    <td>{{ context.l3extRsEctx.attributes.status }}</td>
    <td>{{ context.l3extRsEctx.attributes.tCl }}</td>
    <td>{{ context.l3extRsEctx.attributes.tContextDn }}</td>
    <td>{{ context.l3extRsEctx.attributes.tDn }}</td>
    <td>{{ context.l3extRsEctx.attributes.tRn }}</td>
    <td>{{ context.l3extRsEctx.attributes.tType }}</td>
    <td>{{ context.l3extRsEctx.attributes.tnFvCtxName }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extRsL3DomAtt" in api %}
<h1>L3 Domain Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>External Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDn</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.l3extRsL3DomAtt.attributes.uid }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.annotation }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.childAction }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.dn }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.extMngdBy }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.forceResolve }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.lcOwn }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.modTs }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.monPolDn }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.rType }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.state }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.stateQual }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.status }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.tCl }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.tDn }}</td>
    <td>{{ domain.l3extRsL3DomAtt.attributes.tType }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extRsNodeL3OutAtt" in api %}
<h1>L3Out Node Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Config Issues</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>Router ID</th>
    <th>Router ID Loopback</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDn</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for node in data_to_template['imdata'] %}
  <tr>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.uid }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.annotation }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.childAction }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.configIssues }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.dn }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.extMngdBy }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.forceResolve }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.lcOwn }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.modTs }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.monPolDn }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.rType }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.rtrId }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.rtrIdLoopBack }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.state }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.stateQual }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.status }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.tCl }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.tDn }}</td>
    <td>{{ node.l3extRsNodeL3OutAtt.attributes.tType }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extRsPathL3OutAtt" in api %}
<h1>L3Out Path Source Relationships</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>UID</th>
    <th>Address</th>
    <th>Annotation</th>
    <th>Auto State</th>
    <th>Child Action</th>
    <th>Config Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>Encapsulation Scope</th>
    <th>Externally Managed By</th>
    <th>Force Resolve</th>
    <th>Interface Instance Type</th>
    <th>IPv6 DAD</th>
    <th>Local Owner</th>
    <th>Link Local Address</th>
    <th>MAC</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>MTU</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tType</th>
    <th>Target DSCP</th>
  </tr>
</thead>
<tbody>
{%-     for path in data_to_template['imdata'] %}
  <tr>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.uid }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.addr }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.annotation }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.autostate }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.childAction }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.configIssues }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.descr }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.dn }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.encap }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.encapScope }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.extMngdBy }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.forceResolve }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.ifInstT }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.ipv6Dad }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.lcOwn }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.llAddr }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.mac }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.modTs }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.mode }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.monPolDn }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.mtu }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.rType }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.state }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.stateQual }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.status }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.tCl }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.tDn }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.tType }}</td>
    <td>{{ path.l3extRsPathL3OutAtt.attributes.targetDscp }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "l3extSubnet" in api %}
<h1>L3 Subnets</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Aggregate</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>IP</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Scope</th>
    <th>Status</th>
    <th>UID</th>
  </tr>
</thead>
<tbody>
{%-     for subnet in data_to_template['imdata'] %}
  <tr>
    <td>{{ subnet.l3extSubnet.attributes.name }}</td>
    <td>{{ subnet.l3extSubnet.attributes.nameAlias }}</td>
    <td>{{ subnet.l3extSubnet.attributes.aggregate }}</td>
    <td>{{ subnet.l3extSubnet.attributes.annotation }}</td>
    <td>{{ subnet.l3extSubnet.attributes.childAction }}</td>
    <td>{{ subnet.l3extSubnet.attributes.descr }}</td>
    <td>{{ subnet.l3extSubnet.attributes.dn }}</td>
    <td>{{ subnet.l3extSubnet.attributes.extMngdBy }}</td>
    <td>{{ subnet.l3extSubnet.attributes.ip }}</td>
    <td>{{ subnet.l3extSubnet.attributes.lcOwn }}</td>
    <td>{{ subnet.l3extSubnet.attributes.modTs }}</td>
    <td>{{ subnet.l3extSubnet.attributes.monPolDn }}</td>
    <td>{{ subnet.l3extSubnet.attributes.scope }}</td>
    <td>{{ subnet.l3extSubnet.attributes.status }}</td>
    <td>{{ subnet.l3extSubnet.attributes.uid }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "lacpEntity" in api %}
<h1>LACP Entities</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Oper Error</th>
    <th>Oper State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for entity in data_to_template['imdata'] %}
  <tr>
    <td>{{ entity.lacpEntity.attributes.name }}</td>
    <td>{{ entity.lacpEntity.attributes.adminSt }}</td>
    <td>{{ entity.lacpEntity.attributes.childAction }}</td>
    <td>{{ entity.lacpEntity.attributes.dn }}</td>
    <td>{{ entity.lacpEntity.attributes.lcOwn }}</td>
    <td>{{ entity.lacpEntity.attributes.modTs }}</td>
    <td>{{ entity.lacpEntity.attributes.operErr }}</td>
    <td>{{ entity.lacpEntity.attributes.openSt }}</td>
    <td>{{ entity.lacpEntity.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "lacpIf" in api %}
<h1>LACP Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Activity Flags</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>ID</th>
    <th>Key</th>
    <th>Last Active</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Priority</th>
    <th>Port</th>
    <th>Priority</th>
    <th>Status</th>
    <th>TX Rate</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.lacpIf.attributes.name }}</td>
    <td>{{ interface.lacpIf.attributes.activityFlags }}</td>
    <td>{{ interface.lacpIf.attributes.adminSt }}</td>
    <td>{{ interface.lacpIf.attributes.childAction }}</td>
    <td>{{ interface.lacpIf.attributes.descr }}</td>
    <td>{{ interface.lacpIf.attributes.dn }}</td>
    <td>{{ interface.lacpIf.attributes.id }}</td>
    <td>{{ interface.lacpIf.attributes.key }}</td>
    <td>{{ interface.lacpIf.attributes.lastActive }}</td>
    <td>{{ interface.lacpIf.attributes.lcOwn }}</td>
    <td>{{ interface.lacpIf.attributes.modTs }}</td>
    <td>{{ interface.lacpIf.attributes.monPolDn }}</td>
    <td>{{ interface.lacpIf.attributes.operPrio }}</td>
    <td>{{ interface.lacpIf.attributes.port }}</td>
    <td>{{ interface.lacpIf.attributes.prio }}</td>
    <td>{{ interface.lacpIf.attributes.status }}</td>
    <td>{{ interface.lacpIf.attributes.txRate }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "lacpInst" in api %}
<h1>LACP Instances</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin Priority</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Oper Priority</th>
    <th>Status</th>
    <th>System MAC</th>
  </tr>
</thead>
<tbody>
{%-     for instance in data_to_template['imdata'] %}
  <tr>
    <td>{{ instance.lacpInst.attributes.name }}</td>
    <td>{{ instance.lacpInst.attributes.adminPrio }}</td>
    <td>{{ instance.lacpInst.attributes.adminSt }}</td>
    <td>{{ instance.lacpInst.attributes.childAction }}</td>
    <td>{{ instance.lacpInst.attributes.ctrl }}</td>
    <td>{{ instance.lacpInst.attributes.dn }}</td>
    <td>{{ instance.lacpInst.attributes.lcOwn }}</td>
    <td>{{ instance.lacpInst.attributes.modTs }}</td>
    <td>{{ instance.lacpInst.attributes.monPolDn }}</td>
    <td>{{ instance.lacpInst.attributes.operErr }}</td>
    <td>{{ instance.lacpInst.attributes.operPrio }}</td>
    <td>{{ instance.lacpInst.attributes.status }}</td>
    <td>{{ instance.lacpInst.attributes.sysMac }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "leqptLooseNode" in api %}
<h1>External Unmanaged Nodes</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Edm Node DN</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Managed Loose Node</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Status</th>
    <th>System Description</th>
    <th>System Name</th>
  </tr>
</thead>
<tbody>
{%-     for node in data_to_template['imdata'] %}
  <tr>
    <td>{{ node.leqptLooseNode.attributes.name }}</td>
    <td>{{ node.leqptLooseNode.attributes.nameAlias }}</td>
    <td>{{ node.leqptLooseNode.attributes.childAction }}</td>
    <td>{{ node.leqptLooseNode.attributes.dn }}</td>
    <td>{{ node.leqptLooseNode.attributes.edmNodeDn }}</td>
    <td>{{ node.leqptLooseNode.attributes.id }}</td>
    <td>{{ node.leqptLooseNode.attributes.lcOwn }}</td>
    <td>{{ node.leqptLooseNode.attributes.managedLooseNode }}</td>
    <td>{{ node.leqptLooseNode.attributes.modTs }}</td>
    <td>{{ node.leqptLooseNode.attributes.monPolDn }}</td>
    <td>{{ node.leqptLooseNode.attributes.status }}</td>
    <td>{{ node.leqptLooseNode.attributes.sysDesc | replace("\n"," ") }}</td>
    <td>{{ node.leqptLooseNode.attributes.sysName }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "leqptRsLsNodeToIf" in api %}
<h1>External Unmanaged Nodes Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>DN</th>
    <th>Child Action</th>
    <th>Force Resolve</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>rType</th>
    <th>State</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>tCl</th>
    <th>tDN</th>
    <th>tSKey</th>
    <th>tType</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.dn }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.childAction }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.forceResolve }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.lcOwn }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.modTs }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.monPolDn }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.rType }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.state }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.stateQual }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.status }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.tCl }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.tDn }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.tSKey }}</td>
    <td>{{ interface.leqptRsLsNodeToIf.attributes.tType }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "lldpAdjEp" in api %}
<h1>LLDP Adjacency Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Capability</th>
    <th>Chassis ID Type</th>
    <th>Chassis ID Version</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>ID</th>
    <th>Management ID</th>
    <th>Management IP</th>
    <th>Management Port MAC</th>
    <th>Last Modified</th>
    <th>Monitoring Polily DN</th>
    <th>Port Description</th>
    <th>Port ID Type</th>
    <th>Port ID Version</th>
    <th>Port VLAN</th>
    <th>State Quality</th>
    <th>Status</th>
    <th>System Description</th>
    <th>System Name</th>
    <th>TTL</th>
  </tr>
</thead>
<tbody>
{%-     for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.lldpAdjEp.attributes.name }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.capability }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.chassisIdT }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.chassisIdV }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.childAction }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.dn }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.enCap }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.id }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.mgmtId }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.mgmtIp }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.mgmtPortMac }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.modTs }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.monPolDn }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.portDesc }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.portIdT }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.portIdV }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.portVlan }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.stQual }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.status }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.sysDesc | replace("\n"," ") }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.sysName }}</td>
    <td>{{ endpoint.lldpAdjEp.attributes.ttl }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "lldpEntity" in api %}
<h1>LLDP Entities</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Oper State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for entity in data_to_template['imdata'] %}
  <tr>
    <td>{{ entity.lldpEntity.attributes.name }}</td>
    <td>{{ entity.lldpEntity.attributes.adminSt }}</td>
    <td>{{ entity.lldpEntity.attributes.childAction }}</td>
    <td>{{ entity.lldpEntity.attributes.dn }}</td>
    <td>{{ entity.lldpEntity.attributes.lcOwn }}</td>
    <td>{{ entity.lldpEntity.attributes.modTs }}</td>
    <td>{{ entity.lldpEntity.attributes.monPolDn }}</td>
    <td>{{ entity.lldpEntity.attributes.operErr }}</td>
    <td>{{ entity.lldpEntity.attributes.operSt }}</td>
    <td>{{ entity.lldpEntity.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "lldpIf" in api %}
<h1>LLDP Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin RX State</th>
    <th>Admin State</th>
    <th>Admin TX State</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>MAC</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper RX State</th>
    <th>Oper TX State</th>
    <th>Port Description</th>
    <th>Port Mode</th>
    <th>Port VLAN</th>
    <th>Status</th>
    <th>System Description</th>
    <th>Wiring Issues</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.lldpIf.attributes.name }}</td>
    <td>{{ interface.lldpIf.attributes.adminRxSt }}</td>
    <td>{{ interface.lldpIf.attributes.adminSt }}</td>
    <td>{{ interface.lldpIf.attributes.adminTxSt }}</td>
    <td>{{ interface.lldpIf.attributes.childAction }}</td>
    <td>{{ interface.lldpIf.attributes.descr }}</td>
    <td>{{ interface.lldpIf.attributes.dn }}</td>
    <td>{{ interface.lldpIf.attributes.id }}</td>
    <td>{{ interface.lldpIf.attributes.lcOwn }}</td>
    <td>{{ interface.lldpIf.attributes.mac }}</td>
    <td>{{ interface.lldpIf.attributes.modTs }}</td>
    <td>{{ interface.lldpIf.attributes.monPolDn }}</td>
    <td>{{ interface.lldpIf.attributes.operRxSt }}</td>
    <td>{{ interface.lldpIf.attributes.operTxSt }}</td>
    <td>{{ interface.lldpIf.attributes.portDesc }}</td>
    <td>{{ interface.lldpIf.attributes.portMode }}</td>
    <td>{{ interface.lldpIf.attributes.portVlan }}</td>
    <td>{{ interface.lldpIf.attributes.status }}</td>
    <td>{{ interface.lldpIf.attributes.sysDesc }}</td>
    <td>{{ interface.lldpIf.attributes.wiringIssues }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "lldpInst" in api %}
<h1>LLDP Instances</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>DN</th>
    <th>Hold Time</th>
    <th>Infra VLAN</th>
    <th>Init Delay Time</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Opt Tlv Sel</th>
    <th>Status</th>
    <th>System Description</th>
    <th>TX Frequency</th>
  </tr>
</thead>
<tbody>
{%-     for instance in data_to_template['imdata'] %}
  <tr>
    <td>{{ instance.lldpInst.attributes.name }}</td>
    <td>{{ instance.lldpInst.attributes.adminSt }}</td>
    <td>{{ instance.lldpInst.attributes.childAction }}</td>
    <td>{{ instance.lldpInst.attributes.ctrl }}</td>
    <td>{{ instance.lldpInst.attributes.dn }}</td>
    <td>{{ instance.lldpInst.attributes.holdTime }}</td>
    <td>{{ instance.lldpInst.attributes.infraVlan }}</td>
    <td>{{ instance.lldpInst.attributes.initDelayTime }}</td>
    <td>{{ instance.lldpInst.attributes.lcOwn }}</td>
    <td>{{ instance.lldpInst.attributes.modTs }}</td>
    <td>{{ instance.lldpInst.attributes.monPolDn }}</td>
    <td>{{ instance.lldpInst.attributes.operErr }}</td>
    <td>{{ instance.lldpInst.attributes.optTlvSel }}</td>
    <td>{{ instance.lldpInst.attributes.status }}</td>
    <td>{{ instance.lldpInst.attributes.sysDesc }}</td>
    <td>{{ instance.lldpInst.attributes.txFreq }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "mgmtMgmtIf" in api %}
<h1>Management Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Auto Negotiate</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>FCOT Channel Number</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>MTU</th>
    <th>SNMP Trap State</th>
    <th>Speed</th>
    <th>Status</th>
    <th>Switching State</th>
  </tr>
</thead>
<tbody>
{%-     for interface in data_to_template['imdata'] %}
  <tr>
    <td>{{ interface.mgmtMgmtIf.attributes.name }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.adminSt }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.autoNeg }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.childAction }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.descr }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.dn }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.fcotChannelNumber }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.id }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.lcOwn }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.modTs }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.monPolDn }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.mtu }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.snmpTrapSt }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.speed }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.status }}</td>
    <td>{{ interface.mgmtMgmtIf.attributes.switchingSt }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "ospfAdjEp" in api %}
<h1>OSPF Adjacency Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Area</th>
    <th>BDR</th>
    <th>BFD State</th>
    <th>Child Action</th>
    <th>DBD Options</th>
    <th>DN</th>
    <th>DR</th>
    <th>Flags</th>
    <th>Hello Options</th>
    <th>ID</th>
    <th>Interface ID</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Peer IP</th>
    <th>Peer Name</th>
    <th>Priority</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.ospfAdjEp.attributes.name }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.area }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.bdr }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.bfdSt }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.childAction }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.dbdOptions }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.dn }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.dr }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.flags }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.helloOptions }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.id }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.ifId }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.modTs }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.monPolDn }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.operSt }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.peerIp }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.peerName }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.prio }}</td>
    <td>{{ endpoint.ospfAdjEp.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "ospfArea" in api %}
<h1>OSPF Areas</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>ASBR Count</th>
    <th>BR Count</th>
    <th>Child Action</th>
    <th>Cost</th>
    <th>Control</th>
    <th>DN</th>
    <th>ID</th>
    <th>Local Owner</th>
    <th>LSA Checksum Summary</th>
    <th>Last Modified</th>
    <th>NSSA Trans Role</th>
    <th>NSSA Trans State</th>
    <th>NSSA Trans Stable Interval</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for area in data_to_template['imdata'] %}
  <tr>
    <td>{{ area.ospfArea.attributes.name }}</td>
    <td>{{ area.ospfArea.attributes.asbrCnt }}</td>
    <td>{{ area.ospfArea.attributes.brCnt }}</td>
    <td>{{ area.ospfArea.attributes.childAction }}</td>
    <td>{{ area.ospfArea.attributes.cost }}</td>
    <td>{{ area.ospfArea.attributes.ctrl }}</td>
    <td>{{ area.ospfArea.attributes.dn }}</td>
    <td>{{ area.ospfArea.attributes.id }}</td>
    <td>{{ area.ospfArea.attributes.lcOwn }}</td>
    <td>{{ area.ospfArea.attributes.lsaCksumSum }}</td>
    <td>{{ area.ospfArea.attributes.modTs }}</td>
    <td>{{ area.ospfArea.attributes.nssaTransRole }}</td>
    <td>{{ area.ospfArea.attributes.nssaTransSt }}</td>
    <td>{{ area.ospfArea.attributes.nssaTransStabIntvl }}</td>
    <td>{{ area.ospfArea.attributes.status }}</td>
    <td>{{ area.ospfArea.attributes.type }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "ospfDb" in api %}
<h1>OSPF Database</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Last Modified</th>
    <th>Status</th>
    <th>Type</th>
  </tr>
</thead>
<tbody>
{%-     for database in data_to_template['imdata'] %}
  <tr>
    <td>{{ database.ospfDb.attributes.name }}</td>
    <td>{{ database.ospfDb.attributes.childAction }}</td>
    <td>{{ database.ospfDb.attributes.dn }}</td>
    <td>{{ database.ospfDb.attributes.modTs }}</td>
    <td>{{ database.ospfDb.attributes.status }}</td>
    <td>{{ database.ospfDb.attributes.type }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "ospfDom" in api %}
<h1>OSPF Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Bandwidth Reference</th>
    <th>Child Action</th>
    <th>Control</th>
    <th>Distance</th>
    <th>DN</th>
    <th>ECMP Oper State</th>
    <th>Fail State Quality</th>
    <th>Flags</th>
    <th>Local Owner</th>
    <th>Max ECMP</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper State</th>
    <th>Router ID</th>
    <th>Self Advertised Router Tag</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.ospfDom.attributes.name }}</td>
    <td>{{ domain.ospfDom.attributes.bwRef }}</td>
    <td>{{ domain.ospfDom.attributes.childAction }}</td>
    <td>{{ domain.ospfDom.attributes.ctrl }}</td>
    <td>{{ domain.ospfDom.attributes.dist }}</td>
    <td>{{ domain.ospfDom.attributes.dn }}</td>
    <td>{{ domain.ospfDom.attributes.ecmpOperSt }}</td>
    <td>{{ domain.ospfDom.attributes.failStQual }}</td>
    <td>{{ domain.ospfDom.attributes.flags }}</td>
    <td>{{ domain.ospfDom.attributes.lcOwn }}</td>
    <td>{{ domain.ospfDom.attributes.maxEcmp }}</td>
    <td>{{ domain.ospfDom.attributes.modTs }}</td>
    <td>{{ domain.ospfDom.attributes.monPolDn }}</td>
    <td>{{ domain.ospfDom.attributes.operSt }}</td>
    <td>{{ domain.ospfDom.attributes.rtrId }}</td>
    <td>{{ domain.ospfDom.attributes.selfAdvRtTag }}</td>
    <td>{{ domain.ospfDom.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- elif "ospfEntity" in api %}
<h1>OSPF Entities</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Admin State</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Oper Error</th>
    <th>Oper State</th>
    <th>Status</th>
  </tr>
</thead>
<tbody>
{%-     for entity in data_to_template['imdata'] %}
  <tr>
    <td>{{ entity.ospfEntity.attributes.name }}</td>
    <td>{{ entity.ospfEntity.attributes.adminSt }}</td>
    <td>{{ entity.ospfEntity.attributes.childAction }}</td>
    <td>{{ entity.ospfEntity.attributes.dn }}</td>
    <td>{{ entity.ospfEntity.attributes.lcOwn }}</td>
    <td>{{ entity.ospfEntity.attributes.modTs }}</td>
    <td>{{ entity.ospfEntity.attributes.monPolDn }}</td>
    <td>{{ entity.ospfEntity.attributes.operErr }}</td>
    <td>{{ entity.ospfEntity.attributes.operSt }}</td>
    <td>{{ entity.ospfEntity.attributes.status }}</td>
  </tr>
{%-          endfor %}
</tbody>
</table>
{%- endif %}
{%- include 'datatable_footer.j2' %}